@@ -402,48 +402,12 @@ impl<'a> CANDIS_W<'a> {
         self.w
     }
 }
-#[doc = "Field `TXDIS` reader - Transmit Disable"]
-pub struct TXDIS_R(crate::FieldReader<bool, bool>);
-impl TXDIS_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        TXDIS_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for TXDIS_R {
-    type Target = crate::FieldReader<bool, bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `TXDIS` writer - Transmit Disable"]
-pub struct TXDIS_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> TXDIS_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
-        self.w
-    }
-}
-#[doc = "Configuration Change Enable\n\nValue on reset: 1"]
+#[doc = "Configuration Change Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCE_A {
-    #[doc = "0: The Bit Timing Register, the Port Control Register, Error Counter Register may only be read. All attempts to modify them are ignored."]
+    #[doc = "0: The Bit Timing Register, the Port Control Register, and the Error Counter Register may only be read. All attempts to modify them are ignored."]
     VALUE1 = 0,
-    #[doc = "1: The Bit Timing Register, the Port Control Register, Error Counter Register may be read and written."]
+    #[doc = "1: The Bit Timing Register, the Port Control Register, and the Error Counter Register may be read and written."]
     VALUE2 = 1,
 }
 impl From<CCE_A> for bool {
@@ -494,12 +458,12 @@ impl<'a> CCE_W<'a> {
     pub fn variant(self, variant: CCE_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "The Bit Timing Register, the Port Control Register, Error Counter Register may only be read. All attempts to modify them are ignored."]
+    #[doc = "The Bit Timing Register, the Port Control Register, and the Error Counter Register may only be read. All attempts to modify them are ignored."]
     #[inline(always)]
     pub fn value1(self) -> &'a mut W {
         self.variant(CCE_A::VALUE1)
     }
-    #[doc = "The Bit Timing Register, the Port Control Register, Error Counter Register may be read and written."]
+    #[doc = "The Bit Timing Register, the Port Control Register, and the Error Counter Register may be read and written."]
     #[inline(always)]
     pub fn value2(self) -> &'a mut W {
         self.variant(CCE_A::VALUE2)
@@ -557,6 +521,89 @@ impl<'a> CALM_W<'a> {
         self.w
     }
 }
+#[doc = "Suspend Enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum SUSEN_A {
+    #[doc = "0: An OCDS suspend trigger is ignored by the CAN node."]
+    VALUE1 = 0,
+    #[doc = "1: An OCDS suspend trigger disables the CAN node: As soon as the CAN node becomes bus-idle or bus-off, bit INIT is internally forced to 1 to disable the CAN node. The actual value of bit INIT remains unchanged."]
+    VALUE2 = 1,
+}
+impl From<SUSEN_A> for bool {
+    #[inline(always)]
+    fn from(variant: SUSEN_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `SUSEN` reader - Suspend Enable"]
+pub struct SUSEN_R(crate::FieldReader<bool, SUSEN_A>);
+impl SUSEN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        SUSEN_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> SUSEN_A {
+        match self.bits {
+            false => SUSEN_A::VALUE1,
+            true => SUSEN_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == SUSEN_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == SUSEN_A::VALUE2
+    }
+}
+impl core::ops::Deref for SUSEN_R {
+    type Target = crate::FieldReader<bool, SUSEN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SUSEN` writer - Suspend Enable"]
+pub struct SUSEN_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> SUSEN_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: SUSEN_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "An OCDS suspend trigger is ignored by the CAN node."]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SUSEN_A::VALUE1)
+    }
+    #[doc = "An OCDS suspend trigger disables the CAN node: As soon as the CAN node becomes bus-idle or bus-off, bit INIT is internally forced to 1 to disable the CAN node. The actual value of bit INIT remains unchanged."]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SUSEN_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w
+    }
+}
 impl R {
     #[doc = "Bit 0 - Node Initialization"]
     #[inline(always)]
@@ -583,11 +630,6 @@ impl R {
     pub fn candis(&self) -> CANDIS_R {
         CANDIS_R::new(((self.bits >> 4) & 0x01) != 0)
     }
-    #[doc = "Bit 5 - Transmit Disable"]
-    #[inline(always)]
-    pub fn txdis(&self) -> TXDIS_R {
-        TXDIS_R::new(((self.bits >> 5) & 0x01) != 0)
-    }
     #[doc = "Bit 6 - Configuration Change Enable"]
     #[inline(always)]
     pub fn cce(&self) -> CCE_R {
@@ -598,6 +640,11 @@ impl R {
     pub fn calm(&self) -> CALM_R {
         CALM_R::new(((self.bits >> 7) & 0x01) != 0)
     }
+    #[doc = "Bit 8 - Suspend Enable"]
+    #[inline(always)]
+    pub fn susen(&self) -> SUSEN_R {
+        SUSEN_R::new(((self.bits >> 8) & 0x01) != 0)
+    }
 }
 impl W {
     #[doc = "Bit 0 - Node Initialization"]
@@ -625,11 +672,6 @@ impl W {
     pub fn candis(&mut self) -> CANDIS_W {
         CANDIS_W { w: self }
     }
-    #[doc = "Bit 5 - Transmit Disable"]
-    #[inline(always)]
-    pub fn txdis(&mut self) -> TXDIS_W {
-        TXDIS_W { w: self }
-    }
     #[doc = "Bit 6 - Configuration Change Enable"]
     #[inline(always)]
     pub fn cce(&mut self) -> CCE_W {
@@ -640,6 +682,11 @@ impl W {
     pub fn calm(&mut self) -> CALM_W {
         CALM_W { w: self }
     }
+    #[doc = "Bit 8 - Suspend Enable"]
+    #[inline(always)]
+    pub fn susen(&mut self) -> SUSEN_W {
+        SUSEN_W { w: self }
+    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
@@ -660,10 +707,10 @@ impl crate::Readable for NCR_SPEC {
 impl crate::Writable for NCR_SPEC {
     type Writer = W;
 }
-#[doc = "`reset()` method sets NCR to value 0x41"]
+#[doc = "`reset()` method sets NCR to value 0x01"]
 impl crate::Resettable for NCR_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x41
+        0x01
     }
 }
