@@ -402,89 +402,6 @@ impl core::ops::Deref for FIFOFUL_R {
         &self.0
     }
 }
-#[doc = "Negates the DAC1 output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum NEGATE_A {
-    #[doc = "0: DAC output not negated"]
-    VALUE1 = 0,
-    #[doc = "1: DAC output negated"]
-    VALUE2 = 1,
-}
-impl From<NEGATE_A> for bool {
-    #[inline(always)]
-    fn from(variant: NEGATE_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `NEGATE` reader - Negates the DAC1 output"]
-pub struct NEGATE_R(crate::FieldReader<bool, NEGATE_A>);
-impl NEGATE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        NEGATE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> NEGATE_A {
-        match self.bits {
-            false => NEGATE_A::VALUE1,
-            true => NEGATE_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == NEGATE_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == NEGATE_A::VALUE2
-    }
-}
-impl core::ops::Deref for NEGATE_R {
-    type Target = crate::FieldReader<bool, NEGATE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `NEGATE` writer - Negates the DAC1 output"]
-pub struct NEGATE_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> NEGATE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: NEGATE_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "DAC output not negated"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(NEGATE_A::VALUE1)
-    }
-    #[doc = "DAC output negated"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(NEGATE_A::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
-        self.w
-    }
-}
 #[doc = "Enable sign output of DAC1 pattern generator\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SIGNEN_A {
@@ -728,11 +645,6 @@ impl R {
     pub fn fifoful(&self) -> FIFOFUL_R {
         FIFOFUL_R::new(((self.bits >> 27) & 0x01) != 0)
     }
-    #[doc = "Bit 28 - Negates the DAC1 output"]
-    #[inline(always)]
-    pub fn negate(&self) -> NEGATE_R {
-        NEGATE_R::new(((self.bits >> 28) & 0x01) != 0)
-    }
     #[doc = "Bit 29 - Enable sign output of DAC1 pattern generator"]
     #[inline(always)]
     pub fn signen(&self) -> SIGNEN_R {
@@ -765,11 +677,6 @@ impl W {
     pub fn sign(&mut self) -> SIGN_W {
         SIGN_W { w: self }
     }
-    #[doc = "Bit 28 - Negates the DAC1 output"]
-    #[inline(always)]
-    pub fn negate(&mut self) -> NEGATE_W {
-        NEGATE_W { w: self }
-    }
     #[doc = "Bit 29 - Enable sign output of DAC1 pattern generator"]
     #[inline(always)]
     pub fn signen(&mut self) -> SIGNEN_W {
