@@ -7,7 +7,8 @@ pub struct RegisterBlock {
     pub ovrclr: crate::Reg<ovrclr::OVRCLR_SPEC>,
     #[doc = "0x08 - Service Request Selection 0"]
     pub srsel0: crate::Reg<srsel0::SRSEL0_SPEC>,
-    _reserved3: [u8; 0x04],
+    #[doc = "0x0c - Service Request Selection 1"]
+    pub srsel1: crate::Reg<srsel1::SRSEL1_SPEC>,
     #[doc = "0x10 - Line Enable"]
     pub lnen: crate::Reg<lnen::LNEN_SPEC>,
 }
@@ -23,6 +24,10 @@ pub mod ovrclr;
 pub type SRSEL0 = crate::Reg<srsel0::SRSEL0_SPEC>;
 #[doc = "Service Request Selection 0"]
 pub mod srsel0;
+#[doc = "SRSEL1 register accessor: an alias for `Reg<SRSEL1_SPEC>`"]
+pub type SRSEL1 = crate::Reg<srsel1::SRSEL1_SPEC>;
+#[doc = "Service Request Selection 1"]
+pub mod srsel1;
 #[doc = "LNEN register accessor: an alias for `Reg<LNEN_SPEC>`"]
 pub type LNEN = crate::Reg<lnen::LNEN_SPEC>;
 #[doc = "Line Enable"]
