@@ -38,9 +38,9 @@ impl From<crate::W<LNEN_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN0_A {
     #[doc = "0: Disables the line"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LN0_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl LN0_R {
     #[inline(always)]
     pub fn variant(&self) -> LN0_A {
         match self.bits {
-            false => LN0_A::CONST_0,
-            true => LN0_A::CONST_1,
+            false => LN0_A::VALUE1,
+            true => LN0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LN0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LN0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LN0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LN0_A::VALUE2
     }
 }
 impl core::ops::Deref for LN0_R {
@@ -92,13 +92,13 @@ impl<'a> LN0_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LN0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN0_A::VALUE1)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LN0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> LN0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN1_A {
     #[doc = "0: Disables the line"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LN1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl LN1_R {
     #[inline(always)]
     pub fn variant(&self) -> LN1_A {
         match self.bits {
-            false => LN1_A::CONST_0,
-            true => LN1_A::CONST_1,
+            false => LN1_A::VALUE1,
+            true => LN1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LN1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LN1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LN1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LN1_A::VALUE2
     }
 }
 impl core::ops::Deref for LN1_R {
@@ -175,13 +175,13 @@ impl<'a> LN1_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LN1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN1_A::VALUE1)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LN1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> LN1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN2_A {
     #[doc = "0: Disables the line"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LN2_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl LN2_R {
     #[inline(always)]
     pub fn variant(&self) -> LN2_A {
         match self.bits {
-            false => LN2_A::CONST_0,
-            true => LN2_A::CONST_1,
+            false => LN2_A::VALUE1,
+            true => LN2_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LN2_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LN2_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LN2_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LN2_A::VALUE2
     }
 }
 impl core::ops::Deref for LN2_R {
@@ -258,13 +258,13 @@ impl<'a> LN2_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LN2_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN2_A::VALUE1)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LN2_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN2_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> LN2_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN3_A {
     #[doc = "0: Disables the line"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LN3_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl LN3_R {
     #[inline(always)]
     pub fn variant(&self) -> LN3_A {
         match self.bits {
-            false => LN3_A::CONST_0,
-            true => LN3_A::CONST_1,
+            false => LN3_A::VALUE1,
+            true => LN3_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LN3_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LN3_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LN3_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LN3_A::VALUE2
     }
 }
 impl core::ops::Deref for LN3_R {
@@ -341,13 +341,13 @@ impl<'a> LN3_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LN3_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN3_A::VALUE1)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LN3_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN3_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> LN3_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN4_A {
     #[doc = "0: Disables the line"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LN4_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl LN4_R {
     #[inline(always)]
     pub fn variant(&self) -> LN4_A {
         match self.bits {
-            false => LN4_A::CONST_0,
-            true => LN4_A::CONST_1,
+            false => LN4_A::VALUE1,
+            true => LN4_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LN4_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LN4_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LN4_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LN4_A::VALUE2
     }
 }
 impl core::ops::Deref for LN4_R {
@@ -424,13 +424,13 @@ impl<'a> LN4_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LN4_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN4_A::VALUE1)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LN4_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN4_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> LN4_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN5_A {
     #[doc = "0: Disables the line"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LN5_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl LN5_R {
     #[inline(always)]
     pub fn variant(&self) -> LN5_A {
         match self.bits {
-            false => LN5_A::CONST_0,
-            true => LN5_A::CONST_1,
+            false => LN5_A::VALUE1,
+            true => LN5_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LN5_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LN5_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LN5_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LN5_A::VALUE2
     }
 }
 impl core::ops::Deref for LN5_R {
@@ -507,13 +507,13 @@ impl<'a> LN5_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LN5_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN5_A::VALUE1)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LN5_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN5_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> LN5_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN6_A {
     #[doc = "0: Disables the line"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LN6_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl LN6_R {
     #[inline(always)]
     pub fn variant(&self) -> LN6_A {
         match self.bits {
-            false => LN6_A::CONST_0,
-            true => LN6_A::CONST_1,
+            false => LN6_A::VALUE1,
+            true => LN6_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LN6_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LN6_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LN6_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LN6_A::VALUE2
     }
 }
 impl core::ops::Deref for LN6_R {
@@ -590,13 +590,13 @@ impl<'a> LN6_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LN6_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN6_A::VALUE1)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LN6_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN6_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +619,9 @@ impl<'a> LN6_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LN7_A {
     #[doc = "0: Disables the line"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enables the line and resets a pending request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LN7_A> for bool {
     #[inline(always)]
@@ -639,19 +639,19 @@ impl LN7_R {
     #[inline(always)]
     pub fn variant(&self) -> LN7_A {
         match self.bits {
-            false => LN7_A::CONST_0,
-            true => LN7_A::CONST_1,
+            false => LN7_A::VALUE1,
+            true => LN7_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LN7_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LN7_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LN7_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LN7_A::VALUE2
     }
 }
 impl core::ops::Deref for LN7_R {
@@ -673,13 +673,13 @@ impl<'a> LN7_W<'a> {
     }
     #[doc = "Disables the line"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LN7_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN7_A::VALUE1)
     }
     #[doc = "Enables the line and resets a pending request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LN7_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN7_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -698,6 +698,338 @@ impl<'a> LN7_W<'a> {
         self.w
     }
 }
+#[doc = "Line 8 Enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum LN8_A {
+    #[doc = "0: Disables the line"]
+    VALUE1 = 0,
+    #[doc = "1: Enables the line and resets a pending request"]
+    VALUE2 = 1,
+}
+impl From<LN8_A> for bool {
+    #[inline(always)]
+    fn from(variant: LN8_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `LN8` reader - Line 8 Enable"]
+pub struct LN8_R(crate::FieldReader<bool, LN8_A>);
+impl LN8_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        LN8_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> LN8_A {
+        match self.bits {
+            false => LN8_A::VALUE1,
+            true => LN8_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == LN8_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == LN8_A::VALUE2
+    }
+}
+impl core::ops::Deref for LN8_R {
+    type Target = crate::FieldReader<bool, LN8_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LN8` writer - Line 8 Enable"]
+pub struct LN8_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> LN8_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: LN8_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disables the line"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN8_A::VALUE1)
+    }
+    #[doc = "Enables the line and resets a pending request"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN8_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w
+    }
+}
+#[doc = "Line 9 Enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum LN9_A {
+    #[doc = "0: Disables the line"]
+    VALUE1 = 0,
+    #[doc = "1: Enables the line and resets a pending request"]
+    VALUE2 = 1,
+}
+impl From<LN9_A> for bool {
+    #[inline(always)]
+    fn from(variant: LN9_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `LN9` reader - Line 9 Enable"]
+pub struct LN9_R(crate::FieldReader<bool, LN9_A>);
+impl LN9_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        LN9_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> LN9_A {
+        match self.bits {
+            false => LN9_A::VALUE1,
+            true => LN9_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == LN9_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == LN9_A::VALUE2
+    }
+}
+impl core::ops::Deref for LN9_R {
+    type Target = crate::FieldReader<bool, LN9_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LN9` writer - Line 9 Enable"]
+pub struct LN9_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> LN9_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: LN9_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disables the line"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN9_A::VALUE1)
+    }
+    #[doc = "Enables the line and resets a pending request"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN9_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w
+    }
+}
+#[doc = "Line 10 Enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum LN10_A {
+    #[doc = "0: Disables the line"]
+    VALUE1 = 0,
+    #[doc = "1: Enables the line and resets a pending request"]
+    VALUE2 = 1,
+}
+impl From<LN10_A> for bool {
+    #[inline(always)]
+    fn from(variant: LN10_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `LN10` reader - Line 10 Enable"]
+pub struct LN10_R(crate::FieldReader<bool, LN10_A>);
+impl LN10_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        LN10_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> LN10_A {
+        match self.bits {
+            false => LN10_A::VALUE1,
+            true => LN10_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == LN10_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == LN10_A::VALUE2
+    }
+}
+impl core::ops::Deref for LN10_R {
+    type Target = crate::FieldReader<bool, LN10_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LN10` writer - Line 10 Enable"]
+pub struct LN10_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> LN10_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: LN10_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disables the line"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN10_A::VALUE1)
+    }
+    #[doc = "Enables the line and resets a pending request"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN10_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w
+    }
+}
+#[doc = "Line 11 Enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum LN11_A {
+    #[doc = "0: Disables the line"]
+    VALUE1 = 0,
+    #[doc = "1: Enables the line and resets a pending request"]
+    VALUE2 = 1,
+}
+impl From<LN11_A> for bool {
+    #[inline(always)]
+    fn from(variant: LN11_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `LN11` reader - Line 11 Enable"]
+pub struct LN11_R(crate::FieldReader<bool, LN11_A>);
+impl LN11_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        LN11_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> LN11_A {
+        match self.bits {
+            false => LN11_A::VALUE1,
+            true => LN11_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == LN11_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == LN11_A::VALUE2
+    }
+}
+impl core::ops::Deref for LN11_R {
+    type Target = crate::FieldReader<bool, LN11_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LN11` writer - Line 11 Enable"]
+pub struct LN11_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> LN11_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: LN11_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disables the line"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LN11_A::VALUE1)
+    }
+    #[doc = "Enables the line and resets a pending request"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LN11_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w
+    }
+}
 impl R {
     #[doc = "Bit 0 - Line 0 Enable"]
     #[inline(always)]
@@ -739,6 +1071,26 @@ impl R {
     pub fn ln7(&self) -> LN7_R {
         LN7_R::new(((self.bits >> 7) & 0x01) != 0)
     }
+    #[doc = "Bit 8 - Line 8 Enable"]
+    #[inline(always)]
+    pub fn ln8(&self) -> LN8_R {
+        LN8_R::new(((self.bits >> 8) & 0x01) != 0)
+    }
+    #[doc = "Bit 9 - Line 9 Enable"]
+    #[inline(always)]
+    pub fn ln9(&self) -> LN9_R {
+        LN9_R::new(((self.bits >> 9) & 0x01) != 0)
+    }
+    #[doc = "Bit 10 - Line 10 Enable"]
+    #[inline(always)]
+    pub fn ln10(&self) -> LN10_R {
+        LN10_R::new(((self.bits >> 10) & 0x01) != 0)
+    }
+    #[doc = "Bit 11 - Line 11 Enable"]
+    #[inline(always)]
+    pub fn ln11(&self) -> LN11_R {
+        LN11_R::new(((self.bits >> 11) & 0x01) != 0)
+    }
 }
 impl W {
     #[doc = "Bit 0 - Line 0 Enable"]
@@ -781,6 +1133,26 @@ impl W {
     pub fn ln7(&mut self) -> LN7_W {
         LN7_W { w: self }
     }
+    #[doc = "Bit 8 - Line 8 Enable"]
+    #[inline(always)]
+    pub fn ln8(&mut self) -> LN8_W {
+        LN8_W { w: self }
+    }
+    #[doc = "Bit 9 - Line 9 Enable"]
+    #[inline(always)]
+    pub fn ln9(&mut self) -> LN9_W {
+        LN9_W { w: self }
+    }
+    #[doc = "Bit 10 - Line 10 Enable"]
+    #[inline(always)]
+    pub fn ln10(&mut self) -> LN10_W {
+        LN10_W { w: self }
+    }
+    #[doc = "Bit 11 - Line 11 Enable"]
+    #[inline(always)]
+    pub fn ln11(&mut self) -> LN11_W {
+        LN11_W { w: self }
+    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
