@@ -249,7 +249,9 @@ pub struct RegisterBlock {
     pub system_time_higher_word_seconds: crate::Reg<system_time_higher_word_seconds::SYSTEM_TIME_HIGHER_WORD_SECONDS_SPEC>,
     #[doc = "0x728 - Timestamp Status Register"]
     pub timestamp_status: crate::Reg<timestamp_status::TIMESTAMP_STATUS_SPEC>,
-    _reserved120: [u8; 0x08d4],
+    #[doc = "0x72c - PPS Control Register"]
+    pub pps_control: crate::Reg<pps_control::PPS_CONTROL_SPEC>,
+    _reserved121: [u8; 0x08d0],
     #[doc = "0x1000 - Bus Mode Register"]
     pub bus_mode: crate::Reg<bus_mode::BUS_MODE_SPEC>,
     #[doc = "0x1004 - Transmit Poll Demand Register"]
@@ -270,10 +272,10 @@ pub struct RegisterBlock {
     pub missed_frame_and_buffer_overflow_counter: crate::Reg<missed_frame_and_buffer_overflow_counter::MISSED_FRAME_AND_BUFFER_OVERFLOW_COUNTER_SPEC>,
     #[doc = "0x1024 - Receive Interrupt Watchdog Timer Register"]
     pub receive_interrupt_watchdog_timer: crate::Reg<receive_interrupt_watchdog_timer::RECEIVE_INTERRUPT_WATCHDOG_TIMER_SPEC>,
-    _reserved130: [u8; 0x04],
+    _reserved131: [u8; 0x04],
     #[doc = "0x102c - AHB Status Register"]
     pub ahb_status: crate::Reg<ahb_status::AHB_STATUS_SPEC>,
-    _reserved131: [u8; 0x18],
+    _reserved132: [u8; 0x18],
     #[doc = "0x1048 - Current Host Transmit Descriptor Register"]
     pub current_host_transmit_descriptor: crate::Reg<current_host_transmit_descriptor::CURRENT_HOST_TRANSMIT_DESCRIPTOR_SPEC>,
     #[doc = "0x104c - Current Host Receive Descriptor Register"]
@@ -765,6 +767,10 @@ pub mod system_time_higher_word_seconds;
 pub type TIMESTAMP_STATUS = crate::Reg<timestamp_status::TIMESTAMP_STATUS_SPEC>;
 #[doc = "Timestamp Status Register"]
 pub mod timestamp_status;
+#[doc = "PPS_CONTROL register accessor: an alias for `Reg<PPS_CONTROL_SPEC>`"]
+pub type PPS_CONTROL = crate::Reg<pps_control::PPS_CONTROL_SPEC>;
+#[doc = "PPS Control Register"]
+pub mod pps_control;
 #[doc = "BUS_MODE register accessor: an alias for `Reg<BUS_MODE_SPEC>`"]
 pub type BUS_MODE = crate::Reg<bus_mode::BUS_MODE_SPEC>;
 #[doc = "Bus Mode Register"]
