@@ -17,9 +17,9 @@ impl From<crate::R<PROCON0_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S0L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S0L_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl S0L_R {
     #[inline(always)]
     pub fn variant(&self) -> S0L_A {
         match self.bits {
-            false => S0L_A::CONST_0,
-            true => S0L_A::CONST_1,
+            false => S0L_A::VALUE1,
+            true => S0L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S0L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S0L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S0L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S0L_A::VALUE2
     }
 }
 impl core::ops::Deref for S0L_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for S0L_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S1L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S1L_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl S1L_R {
     #[inline(always)]
     pub fn variant(&self) -> S1L_A {
         match self.bits {
-            false => S1L_A::CONST_0,
-            true => S1L_A::CONST_1,
+            false => S1L_A::VALUE1,
+            true => S1L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S1L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S1L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S1L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S1L_A::VALUE2
     }
 }
 impl core::ops::Deref for S1L_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for S1L_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S2L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S2L_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl S2L_R {
     #[inline(always)]
     pub fn variant(&self) -> S2L_A {
         match self.bits {
-            false => S2L_A::CONST_0,
-            true => S2L_A::CONST_1,
+            false => S2L_A::VALUE1,
+            true => S2L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S2L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S2L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S2L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S2L_A::VALUE2
     }
 }
 impl core::ops::Deref for S2L_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for S2L_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S3L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S3L_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl S3L_R {
     #[inline(always)]
     pub fn variant(&self) -> S3L_A {
         match self.bits {
-            false => S3L_A::CONST_0,
-            true => S3L_A::CONST_1,
+            false => S3L_A::VALUE1,
+            true => S3L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S3L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S3L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S3L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S3L_A::VALUE2
     }
 }
 impl core::ops::Deref for S3L_R {
@@ -201,9 +201,9 @@ impl core::ops::Deref for S3L_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S4L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S4L_A> for bool {
     #[inline(always)]
@@ -221,19 +221,19 @@ impl S4L_R {
     #[inline(always)]
     pub fn variant(&self) -> S4L_A {
         match self.bits {
-            false => S4L_A::CONST_0,
-            true => S4L_A::CONST_1,
+            false => S4L_A::VALUE1,
+            true => S4L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S4L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S4L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S4L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S4L_A::VALUE2
     }
 }
 impl core::ops::Deref for S4L_R {
@@ -247,9 +247,9 @@ impl core::ops::Deref for S4L_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S5L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S5L_A> for bool {
     #[inline(always)]
@@ -267,19 +267,19 @@ impl S5L_R {
     #[inline(always)]
     pub fn variant(&self) -> S5L_A {
         match self.bits {
-            false => S5L_A::CONST_0,
-            true => S5L_A::CONST_1,
+            false => S5L_A::VALUE1,
+            true => S5L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S5L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S5L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S5L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S5L_A::VALUE2
     }
 }
 impl core::ops::Deref for S5L_R {
@@ -293,9 +293,9 @@ impl core::ops::Deref for S5L_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S6L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S6L_A> for bool {
     #[inline(always)]
@@ -313,19 +313,19 @@ impl S6L_R {
     #[inline(always)]
     pub fn variant(&self) -> S6L_A {
         match self.bits {
-            false => S6L_A::CONST_0,
-            true => S6L_A::CONST_1,
+            false => S6L_A::VALUE1,
+            true => S6L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S6L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S6L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S6L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S6L_A::VALUE2
     }
 }
 impl core::ops::Deref for S6L_R {
@@ -339,9 +339,9 @@ impl core::ops::Deref for S6L_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S7L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S7L_A> for bool {
     #[inline(always)]
@@ -359,19 +359,19 @@ impl S7L_R {
     #[inline(always)]
     pub fn variant(&self) -> S7L_A {
         match self.bits {
-            false => S7L_A::CONST_0,
-            true => S7L_A::CONST_1,
+            false => S7L_A::VALUE1,
+            true => S7L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S7L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S7L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S7L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S7L_A::VALUE2
     }
 }
 impl core::ops::Deref for S7L_R {
@@ -385,9 +385,9 @@ impl core::ops::Deref for S7L_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S8L_A {
     #[doc = "0: No write protection is configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Write protection is configured for sector n."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S8L_A> for bool {
     #[inline(always)]
@@ -405,19 +405,19 @@ impl S8L_R {
     #[inline(always)]
     pub fn variant(&self) -> S8L_A {
         match self.bits {
-            false => S8L_A::CONST_0,
-            true => S8L_A::CONST_1,
+            false => S8L_A::VALUE1,
+            true => S8L_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S8L_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S8L_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S8L_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S8L_A::VALUE2
     }
 }
 impl core::ops::Deref for S8L_R {
@@ -427,13 +427,105 @@ impl core::ops::Deref for S8L_R {
         &self.0
     }
 }
+#[doc = "Sector 9 Locked for Write Protection by User 0\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S9L_A {
+    #[doc = "0: No write protection is configured for sector n."]
+    VALUE1 = 0,
+    #[doc = "1: Write protection is configured for sector n."]
+    VALUE2 = 1,
+}
+impl From<S9L_A> for bool {
+    #[inline(always)]
+    fn from(variant: S9L_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S9L` reader - Sector 9 Locked for Write Protection by User 0"]
+pub struct S9L_R(crate::FieldReader<bool, S9L_A>);
+impl S9L_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S9L_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S9L_A {
+        match self.bits {
+            false => S9L_A::VALUE1,
+            true => S9L_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S9L_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S9L_A::VALUE2
+    }
+}
+impl core::ops::Deref for S9L_R {
+    type Target = crate::FieldReader<bool, S9L_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Sectors 10 and 11 Locked for Write Protection by User 0\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S10_S11L_A {
+    #[doc = "0: No write protection is configured for sectors 10+11."]
+    VALUE1 = 0,
+    #[doc = "1: Write protection is configured for sectors 10+11."]
+    VALUE2 = 1,
+}
+impl From<S10_S11L_A> for bool {
+    #[inline(always)]
+    fn from(variant: S10_S11L_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S10_S11L` reader - Sectors 10 and 11 Locked for Write Protection by User 0"]
+pub struct S10_S11L_R(crate::FieldReader<bool, S10_S11L_A>);
+impl S10_S11L_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S10_S11L_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S10_S11L_A {
+        match self.bits {
+            false => S10_S11L_A::VALUE1,
+            true => S10_S11L_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S10_S11L_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S10_S11L_A::VALUE2
+    }
+}
+impl core::ops::Deref for S10_S11L_R {
+    type Target = crate::FieldReader<bool, S10_S11L_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Read Protection Configuration\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RPRO_A {
     #[doc = "0: No read protection configured"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Read protection and global write protection is configured by user 0 (master user)"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RPRO_A> for bool {
     #[inline(always)]
@@ -451,19 +543,19 @@ impl RPRO_R {
     #[inline(always)]
     pub fn variant(&self) -> RPRO_A {
         match self.bits {
-            false => RPRO_A::CONST_0,
-            true => RPRO_A::CONST_1,
+            false => RPRO_A::VALUE1,
+            true => RPRO_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RPRO_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RPRO_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RPRO_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RPRO_A::VALUE2
     }
 }
 impl core::ops::Deref for RPRO_R {
@@ -519,6 +611,16 @@ impl R {
     pub fn s8l(&self) -> S8L_R {
         S8L_R::new(((self.bits >> 8) & 0x01) != 0)
     }
+    #[doc = "Bit 9 - Sector 9 Locked for Write Protection by User 0"]
+    #[inline(always)]
+    pub fn s9l(&self) -> S9L_R {
+        S9L_R::new(((self.bits >> 9) & 0x01) != 0)
+    }
+    #[doc = "Bit 10 - Sectors 10 and 11 Locked for Write Protection by User 0"]
+    #[inline(always)]
+    pub fn s10_s11l(&self) -> S10_S11L_R {
+        S10_S11L_R::new(((self.bits >> 10) & 0x01) != 0)
+    }
     #[doc = "Bit 15 - Read Protection Configuration"]
     #[inline(always)]
     pub fn rpro(&self) -> RPRO_R {
