@@ -17,9 +17,9 @@ impl From<crate::R<PROCON2_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S0ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S0ROM_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl S0ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S0ROM_A {
         match self.bits {
-            false => S0ROM_A::CONST_0,
-            true => S0ROM_A::CONST_1,
+            false => S0ROM_A::VALUE1,
+            true => S0ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S0ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S0ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S0ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S0ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S0ROM_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for S0ROM_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S1ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S1ROM_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl S1ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S1ROM_A {
         match self.bits {
-            false => S1ROM_A::CONST_0,
-            true => S1ROM_A::CONST_1,
+            false => S1ROM_A::VALUE1,
+            true => S1ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S1ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S1ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S1ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S1ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S1ROM_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for S1ROM_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S2ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S2ROM_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl S2ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S2ROM_A {
         match self.bits {
-            false => S2ROM_A::CONST_0,
-            true => S2ROM_A::CONST_1,
+            false => S2ROM_A::VALUE1,
+            true => S2ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S2ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S2ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S2ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S2ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S2ROM_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for S2ROM_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S3ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S3ROM_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl S3ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S3ROM_A {
         match self.bits {
-            false => S3ROM_A::CONST_0,
-            true => S3ROM_A::CONST_1,
+            false => S3ROM_A::VALUE1,
+            true => S3ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S3ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S3ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S3ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S3ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S3ROM_R {
@@ -201,9 +201,9 @@ impl core::ops::Deref for S3ROM_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S4ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S4ROM_A> for bool {
     #[inline(always)]
@@ -221,19 +221,19 @@ impl S4ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S4ROM_A {
         match self.bits {
-            false => S4ROM_A::CONST_0,
-            true => S4ROM_A::CONST_1,
+            false => S4ROM_A::VALUE1,
+            true => S4ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S4ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S4ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S4ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S4ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S4ROM_R {
@@ -247,9 +247,9 @@ impl core::ops::Deref for S4ROM_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S5ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S5ROM_A> for bool {
     #[inline(always)]
@@ -267,19 +267,19 @@ impl S5ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S5ROM_A {
         match self.bits {
-            false => S5ROM_A::CONST_0,
-            true => S5ROM_A::CONST_1,
+            false => S5ROM_A::VALUE1,
+            true => S5ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S5ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S5ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S5ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S5ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S5ROM_R {
@@ -293,9 +293,9 @@ impl core::ops::Deref for S5ROM_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S6ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S6ROM_A> for bool {
     #[inline(always)]
@@ -313,19 +313,19 @@ impl S6ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S6ROM_A {
         match self.bits {
-            false => S6ROM_A::CONST_0,
-            true => S6ROM_A::CONST_1,
+            false => S6ROM_A::VALUE1,
+            true => S6ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S6ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S6ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S6ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S6ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S6ROM_R {
@@ -339,9 +339,9 @@ impl core::ops::Deref for S6ROM_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S7ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S7ROM_A> for bool {
     #[inline(always)]
@@ -359,19 +359,19 @@ impl S7ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S7ROM_A {
         match self.bits {
-            false => S7ROM_A::CONST_0,
-            true => S7ROM_A::CONST_1,
+            false => S7ROM_A::VALUE1,
+            true => S7ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S7ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S7ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S7ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S7ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S7ROM_R {
@@ -385,9 +385,9 @@ impl core::ops::Deref for S7ROM_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum S8ROM_A {
     #[doc = "0: No ROM functionality configured for sector n."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<S8ROM_A> for bool {
     #[inline(always)]
@@ -405,19 +405,19 @@ impl S8ROM_R {
     #[inline(always)]
     pub fn variant(&self) -> S8ROM_A {
         match self.bits {
-            false => S8ROM_A::CONST_0,
-            true => S8ROM_A::CONST_1,
+            false => S8ROM_A::VALUE1,
+            true => S8ROM_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == S8ROM_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == S8ROM_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == S8ROM_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == S8ROM_A::VALUE2
     }
 }
 impl core::ops::Deref for S8ROM_R {
@@ -427,6 +427,98 @@ impl core::ops::Deref for S8ROM_R {
         &self.0
     }
 }
+#[doc = "Sector 9 Locked Forever by User 2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S9ROM_A {
+    #[doc = "0: No ROM functionality configured for sector n."]
+    VALUE1 = 0,
+    #[doc = "1: ROM functionality is configured for sector n. Re-programming of this sector is no longer possible."]
+    VALUE2 = 1,
+}
+impl From<S9ROM_A> for bool {
+    #[inline(always)]
+    fn from(variant: S9ROM_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S9ROM` reader - Sector 9 Locked Forever by User 2"]
+pub struct S9ROM_R(crate::FieldReader<bool, S9ROM_A>);
+impl S9ROM_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S9ROM_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S9ROM_A {
+        match self.bits {
+            false => S9ROM_A::VALUE1,
+            true => S9ROM_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S9ROM_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S9ROM_A::VALUE2
+    }
+}
+impl core::ops::Deref for S9ROM_R {
+    type Target = crate::FieldReader<bool, S9ROM_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Sectors 10 and 11 Locked Forever by User 2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S10_S11ROM_A {
+    #[doc = "0: No ROM functionality is configured for sectors 10+11."]
+    VALUE1 = 0,
+    #[doc = "1: ROM functionality is configured for sectors 10+11."]
+    VALUE2 = 1,
+}
+impl From<S10_S11ROM_A> for bool {
+    #[inline(always)]
+    fn from(variant: S10_S11ROM_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S10_S11ROM` reader - Sectors 10 and 11 Locked Forever by User 2"]
+pub struct S10_S11ROM_R(crate::FieldReader<bool, S10_S11ROM_A>);
+impl S10_S11ROM_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S10_S11ROM_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S10_S11ROM_A {
+        match self.bits {
+            false => S10_S11ROM_A::VALUE1,
+            true => S10_S11ROM_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S10_S11ROM_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S10_S11ROM_A::VALUE2
+    }
+}
+impl core::ops::Deref for S10_S11ROM_R {
+    type Target = crate::FieldReader<bool, S10_S11ROM_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 impl R {
     #[doc = "Bit 0 - Sector 0 Locked Forever by User 2"]
     #[inline(always)]
@@ -473,6 +565,16 @@ impl R {
     pub fn s8rom(&self) -> S8ROM_R {
         S8ROM_R::new(((self.bits >> 8) & 0x01) != 0)
     }
+    #[doc = "Bit 9 - Sector 9 Locked Forever by User 2"]
+    #[inline(always)]
+    pub fn s9rom(&self) -> S9ROM_R {
+        S9ROM_R::new(((self.bits >> 9) & 0x01) != 0)
+    }
+    #[doc = "Bit 10 - Sectors 10 and 11 Locked Forever by User 2"]
+    #[inline(always)]
+    pub fn s10_s11rom(&self) -> S10_S11ROM_R {
+        S10_S11ROM_R::new(((self.bits >> 10) & 0x01) != 0)
+    }
 }
 #[doc = "Flash Protection Configuration Register User 2\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [procon2](index.html) module"]
 pub struct PROCON2_SPEC;
