@@ -17,9 +17,9 @@ impl From<crate::R<IN_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P0_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P0_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl P0_R {
     #[inline(always)]
     pub fn variant(&self) -> P0_A {
         match self.bits {
-            false => P0_A::CONST_0,
-            true => P0_A::CONST_1,
+            false => P0_A::VALUE1,
+            true => P0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P0_A::VALUE2
     }
 }
 impl core::ops::Deref for P0_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for P0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P1_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P1_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl P1_R {
     #[inline(always)]
     pub fn variant(&self) -> P1_A {
         match self.bits {
-            false => P1_A::CONST_0,
-            true => P1_A::CONST_1,
+            false => P1_A::VALUE1,
+            true => P1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P1_A::VALUE2
     }
 }
 impl core::ops::Deref for P1_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for P1_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P2_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P2_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl P2_R {
     #[inline(always)]
     pub fn variant(&self) -> P2_A {
         match self.bits {
-            false => P2_A::CONST_0,
-            true => P2_A::CONST_1,
+            false => P2_A::VALUE1,
+            true => P2_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P2_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P2_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P2_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P2_A::VALUE2
     }
 }
 impl core::ops::Deref for P2_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for P2_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P3_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P3_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl P3_R {
     #[inline(always)]
     pub fn variant(&self) -> P3_A {
         match self.bits {
-            false => P3_A::CONST_0,
-            true => P3_A::CONST_1,
+            false => P3_A::VALUE1,
+            true => P3_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P3_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P3_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P3_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P3_A::VALUE2
     }
 }
 impl core::ops::Deref for P3_R {
@@ -201,9 +201,9 @@ impl core::ops::Deref for P3_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P4_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P4_A> for bool {
     #[inline(always)]
@@ -221,19 +221,19 @@ impl P4_R {
     #[inline(always)]
     pub fn variant(&self) -> P4_A {
         match self.bits {
-            false => P4_A::CONST_0,
-            true => P4_A::CONST_1,
+            false => P4_A::VALUE1,
+            true => P4_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P4_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P4_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P4_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P4_A::VALUE2
     }
 }
 impl core::ops::Deref for P4_R {
@@ -247,9 +247,9 @@ impl core::ops::Deref for P4_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P5_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P5_A> for bool {
     #[inline(always)]
@@ -267,19 +267,19 @@ impl P5_R {
     #[inline(always)]
     pub fn variant(&self) -> P5_A {
         match self.bits {
-            false => P5_A::CONST_0,
-            true => P5_A::CONST_1,
+            false => P5_A::VALUE1,
+            true => P5_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P5_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P5_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P5_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P5_A::VALUE2
     }
 }
 impl core::ops::Deref for P5_R {
@@ -293,9 +293,9 @@ impl core::ops::Deref for P5_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P6_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P6_A> for bool {
     #[inline(always)]
@@ -313,19 +313,19 @@ impl P6_R {
     #[inline(always)]
     pub fn variant(&self) -> P6_A {
         match self.bits {
-            false => P6_A::CONST_0,
-            true => P6_A::CONST_1,
+            false => P6_A::VALUE1,
+            true => P6_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P6_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P6_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P6_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P6_A::VALUE2
     }
 }
 impl core::ops::Deref for P6_R {
@@ -339,9 +339,9 @@ impl core::ops::Deref for P6_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P7_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P7_A> for bool {
     #[inline(always)]
@@ -359,19 +359,19 @@ impl P7_R {
     #[inline(always)]
     pub fn variant(&self) -> P7_A {
         match self.bits {
-            false => P7_A::CONST_0,
-            true => P7_A::CONST_1,
+            false => P7_A::VALUE1,
+            true => P7_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P7_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P7_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P7_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P7_A::VALUE2
     }
 }
 impl core::ops::Deref for P7_R {
@@ -385,9 +385,9 @@ impl core::ops::Deref for P7_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P8_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P8_A> for bool {
     #[inline(always)]
@@ -405,19 +405,19 @@ impl P8_R {
     #[inline(always)]
     pub fn variant(&self) -> P8_A {
         match self.bits {
-            false => P8_A::CONST_0,
-            true => P8_A::CONST_1,
+            false => P8_A::VALUE1,
+            true => P8_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P8_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P8_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P8_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P8_A::VALUE2
     }
 }
 impl core::ops::Deref for P8_R {
@@ -431,9 +431,9 @@ impl core::ops::Deref for P8_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P9_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P9_A> for bool {
     #[inline(always)]
@@ -451,19 +451,19 @@ impl P9_R {
     #[inline(always)]
     pub fn variant(&self) -> P9_A {
         match self.bits {
-            false => P9_A::CONST_0,
-            true => P9_A::CONST_1,
+            false => P9_A::VALUE1,
+            true => P9_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P9_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P9_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P9_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P9_A::VALUE2
     }
 }
 impl core::ops::Deref for P9_R {
@@ -477,9 +477,9 @@ impl core::ops::Deref for P9_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P10_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P10_A> for bool {
     #[inline(always)]
@@ -497,19 +497,19 @@ impl P10_R {
     #[inline(always)]
     pub fn variant(&self) -> P10_A {
         match self.bits {
-            false => P10_A::CONST_0,
-            true => P10_A::CONST_1,
+            false => P10_A::VALUE1,
+            true => P10_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P10_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P10_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P10_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P10_A::VALUE2
     }
 }
 impl core::ops::Deref for P10_R {
@@ -523,9 +523,9 @@ impl core::ops::Deref for P10_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P11_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P11_A> for bool {
     #[inline(always)]
@@ -543,19 +543,19 @@ impl P11_R {
     #[inline(always)]
     pub fn variant(&self) -> P11_A {
         match self.bits {
-            false => P11_A::CONST_0,
-            true => P11_A::CONST_1,
+            false => P11_A::VALUE1,
+            true => P11_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P11_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P11_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P11_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P11_A::VALUE2
     }
 }
 impl core::ops::Deref for P11_R {
@@ -569,9 +569,9 @@ impl core::ops::Deref for P11_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P12_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P12_A> for bool {
     #[inline(always)]
@@ -589,19 +589,19 @@ impl P12_R {
     #[inline(always)]
     pub fn variant(&self) -> P12_A {
         match self.bits {
-            false => P12_A::CONST_0,
-            true => P12_A::CONST_1,
+            false => P12_A::VALUE1,
+            true => P12_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P12_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P12_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P12_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P12_A::VALUE2
     }
 }
 impl core::ops::Deref for P12_R {
@@ -615,9 +615,9 @@ impl core::ops::Deref for P12_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P13_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P13_A> for bool {
     #[inline(always)]
@@ -635,19 +635,19 @@ impl P13_R {
     #[inline(always)]
     pub fn variant(&self) -> P13_A {
         match self.bits {
-            false => P13_A::CONST_0,
-            true => P13_A::CONST_1,
+            false => P13_A::VALUE1,
+            true => P13_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P13_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P13_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P13_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P13_A::VALUE2
     }
 }
 impl core::ops::Deref for P13_R {
@@ -661,9 +661,9 @@ impl core::ops::Deref for P13_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P14_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P14_A> for bool {
     #[inline(always)]
@@ -681,19 +681,19 @@ impl P14_R {
     #[inline(always)]
     pub fn variant(&self) -> P14_A {
         match self.bits {
-            false => P14_A::CONST_0,
-            true => P14_A::CONST_1,
+            false => P14_A::VALUE1,
+            true => P14_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P14_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P14_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P14_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P14_A::VALUE2
     }
 }
 impl core::ops::Deref for P14_R {
@@ -707,9 +707,9 @@ impl core::ops::Deref for P14_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P15_A {
     #[doc = "0: The input level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The input level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P15_A> for bool {
     #[inline(always)]
@@ -727,19 +727,19 @@ impl P15_R {
     #[inline(always)]
     pub fn variant(&self) -> P15_A {
         match self.bits {
-            false => P15_A::CONST_0,
-            true => P15_A::CONST_1,
+            false => P15_A::VALUE1,
+            true => P15_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P15_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P15_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P15_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P15_A::VALUE2
     }
 }
 impl core::ops::Deref for P15_R {
