@@ -38,9 +38,9 @@ impl From<crate::W<OUT_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P0_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P0_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl P0_R {
     #[inline(always)]
     pub fn variant(&self) -> P0_A {
         match self.bits {
-            false => P0_A::CONST_0,
-            true => P0_A::CONST_1,
+            false => P0_A::VALUE1,
+            true => P0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P0_A::VALUE2
     }
 }
 impl core::ops::Deref for P0_R {
@@ -92,13 +92,13 @@ impl<'a> P0_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P0_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> P0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P1_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl P1_R {
     #[inline(always)]
     pub fn variant(&self) -> P1_A {
         match self.bits {
-            false => P1_A::CONST_0,
-            true => P1_A::CONST_1,
+            false => P1_A::VALUE1,
+            true => P1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P1_A::VALUE2
     }
 }
 impl core::ops::Deref for P1_R {
@@ -175,13 +175,13 @@ impl<'a> P1_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P1_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> P1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P2_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P2_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl P2_R {
     #[inline(always)]
     pub fn variant(&self) -> P2_A {
         match self.bits {
-            false => P2_A::CONST_0,
-            true => P2_A::CONST_1,
+            false => P2_A::VALUE1,
+            true => P2_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P2_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P2_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P2_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P2_A::VALUE2
     }
 }
 impl core::ops::Deref for P2_R {
@@ -258,13 +258,13 @@ impl<'a> P2_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P2_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P2_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P2_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P2_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> P2_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P3_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P3_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl P3_R {
     #[inline(always)]
     pub fn variant(&self) -> P3_A {
         match self.bits {
-            false => P3_A::CONST_0,
-            true => P3_A::CONST_1,
+            false => P3_A::VALUE1,
+            true => P3_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P3_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P3_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P3_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P3_A::VALUE2
     }
 }
 impl core::ops::Deref for P3_R {
@@ -341,13 +341,13 @@ impl<'a> P3_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P3_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P3_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P3_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P3_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> P3_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P4_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P4_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl P4_R {
     #[inline(always)]
     pub fn variant(&self) -> P4_A {
         match self.bits {
-            false => P4_A::CONST_0,
-            true => P4_A::CONST_1,
+            false => P4_A::VALUE1,
+            true => P4_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P4_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P4_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P4_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P4_A::VALUE2
     }
 }
 impl core::ops::Deref for P4_R {
@@ -424,13 +424,13 @@ impl<'a> P4_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P4_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P4_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P4_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P4_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> P4_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P5_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P5_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl P5_R {
     #[inline(always)]
     pub fn variant(&self) -> P5_A {
         match self.bits {
-            false => P5_A::CONST_0,
-            true => P5_A::CONST_1,
+            false => P5_A::VALUE1,
+            true => P5_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P5_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P5_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P5_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P5_A::VALUE2
     }
 }
 impl core::ops::Deref for P5_R {
@@ -507,13 +507,13 @@ impl<'a> P5_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P5_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P5_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P5_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P5_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> P5_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P6_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P6_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl P6_R {
     #[inline(always)]
     pub fn variant(&self) -> P6_A {
         match self.bits {
-            false => P6_A::CONST_0,
-            true => P6_A::CONST_1,
+            false => P6_A::VALUE1,
+            true => P6_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P6_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P6_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P6_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P6_A::VALUE2
     }
 }
 impl core::ops::Deref for P6_R {
@@ -590,13 +590,13 @@ impl<'a> P6_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P6_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P6_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P6_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P6_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +619,9 @@ impl<'a> P6_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P7_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P7_A> for bool {
     #[inline(always)]
@@ -639,19 +639,19 @@ impl P7_R {
     #[inline(always)]
     pub fn variant(&self) -> P7_A {
         match self.bits {
-            false => P7_A::CONST_0,
-            true => P7_A::CONST_1,
+            false => P7_A::VALUE1,
+            true => P7_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P7_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P7_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P7_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P7_A::VALUE2
     }
 }
 impl core::ops::Deref for P7_R {
@@ -673,13 +673,13 @@ impl<'a> P7_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P7_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P7_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P7_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P7_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +702,9 @@ impl<'a> P7_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P8_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P8_A> for bool {
     #[inline(always)]
@@ -722,19 +722,19 @@ impl P8_R {
     #[inline(always)]
     pub fn variant(&self) -> P8_A {
         match self.bits {
-            false => P8_A::CONST_0,
-            true => P8_A::CONST_1,
+            false => P8_A::VALUE1,
+            true => P8_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P8_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P8_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P8_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P8_A::VALUE2
     }
 }
 impl core::ops::Deref for P8_R {
@@ -756,13 +756,13 @@ impl<'a> P8_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P8_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P8_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P8_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P8_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +785,9 @@ impl<'a> P8_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P9_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P9_A> for bool {
     #[inline(always)]
@@ -805,19 +805,19 @@ impl P9_R {
     #[inline(always)]
     pub fn variant(&self) -> P9_A {
         match self.bits {
-            false => P9_A::CONST_0,
-            true => P9_A::CONST_1,
+            false => P9_A::VALUE1,
+            true => P9_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P9_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P9_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P9_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P9_A::VALUE2
     }
 }
 impl core::ops::Deref for P9_R {
@@ -839,13 +839,13 @@ impl<'a> P9_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P9_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P9_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P9_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P9_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +868,9 @@ impl<'a> P9_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P10_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P10_A> for bool {
     #[inline(always)]
@@ -888,19 +888,19 @@ impl P10_R {
     #[inline(always)]
     pub fn variant(&self) -> P10_A {
         match self.bits {
-            false => P10_A::CONST_0,
-            true => P10_A::CONST_1,
+            false => P10_A::VALUE1,
+            true => P10_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P10_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P10_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P10_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P10_A::VALUE2
     }
 }
 impl core::ops::Deref for P10_R {
@@ -922,13 +922,13 @@ impl<'a> P10_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P10_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P10_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P10_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P10_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -951,9 +951,9 @@ impl<'a> P10_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P11_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P11_A> for bool {
     #[inline(always)]
@@ -971,19 +971,19 @@ impl P11_R {
     #[inline(always)]
     pub fn variant(&self) -> P11_A {
         match self.bits {
-            false => P11_A::CONST_0,
-            true => P11_A::CONST_1,
+            false => P11_A::VALUE1,
+            true => P11_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P11_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P11_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P11_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P11_A::VALUE2
     }
 }
 impl core::ops::Deref for P11_R {
@@ -1005,13 +1005,13 @@ impl<'a> P11_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P11_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P11_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P11_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P11_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1034,9 +1034,9 @@ impl<'a> P11_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P12_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P12_A> for bool {
     #[inline(always)]
@@ -1054,19 +1054,19 @@ impl P12_R {
     #[inline(always)]
     pub fn variant(&self) -> P12_A {
         match self.bits {
-            false => P12_A::CONST_0,
-            true => P12_A::CONST_1,
+            false => P12_A::VALUE1,
+            true => P12_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P12_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P12_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P12_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P12_A::VALUE2
     }
 }
 impl core::ops::Deref for P12_R {
@@ -1088,13 +1088,13 @@ impl<'a> P12_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P12_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P12_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P12_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P12_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1117,9 +1117,9 @@ impl<'a> P12_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P13_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P13_A> for bool {
     #[inline(always)]
@@ -1137,19 +1137,19 @@ impl P13_R {
     #[inline(always)]
     pub fn variant(&self) -> P13_A {
         match self.bits {
-            false => P13_A::CONST_0,
-            true => P13_A::CONST_1,
+            false => P13_A::VALUE1,
+            true => P13_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P13_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P13_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P13_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P13_A::VALUE2
     }
 }
 impl core::ops::Deref for P13_R {
@@ -1171,13 +1171,13 @@ impl<'a> P13_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P13_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P13_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P13_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P13_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1200,9 +1200,9 @@ impl<'a> P13_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P14_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P14_A> for bool {
     #[inline(always)]
@@ -1220,19 +1220,19 @@ impl P14_R {
     #[inline(always)]
     pub fn variant(&self) -> P14_A {
         match self.bits {
-            false => P14_A::CONST_0,
-            true => P14_A::CONST_1,
+            false => P14_A::VALUE1,
+            true => P14_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P14_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P14_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P14_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P14_A::VALUE2
     }
 }
 impl core::ops::Deref for P14_R {
@@ -1254,13 +1254,13 @@ impl<'a> P14_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P14_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P14_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P14_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P14_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1283,9 +1283,9 @@ impl<'a> P14_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum P15_A {
     #[doc = "0: The output level of Pn.x is 0."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: The output level of Pn.x is 1."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<P15_A> for bool {
     #[inline(always)]
@@ -1303,19 +1303,19 @@ impl P15_R {
     #[inline(always)]
     pub fn variant(&self) -> P15_A {
         match self.bits {
-            false => P15_A::CONST_0,
-            true => P15_A::CONST_1,
+            false => P15_A::VALUE1,
+            true => P15_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == P15_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == P15_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == P15_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == P15_A::VALUE2
     }
 }
 impl core::ops::Deref for P15_R {
@@ -1337,13 +1337,13 @@ impl<'a> P15_W<'a> {
     }
     #[doc = "The output level of Pn.x is 0."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(P15_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(P15_A::VALUE1)
     }
     #[doc = "The output level of Pn.x is 1."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(P15_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(P15_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
