@@ -38,9 +38,9 @@ impl From<crate::W<PCON_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum IBYP_A {
     #[doc = "0: Instruction prefetch buffer not bypassed."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Instruction prefetch buffer bypassed."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<IBYP_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl IBYP_R {
     #[inline(always)]
     pub fn variant(&self) -> IBYP_A {
         match self.bits {
-            false => IBYP_A::CONST_0,
-            true => IBYP_A::CONST_1,
+            false => IBYP_A::VALUE1,
+            true => IBYP_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == IBYP_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == IBYP_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == IBYP_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == IBYP_A::VALUE2
     }
 }
 impl core::ops::Deref for IBYP_R {
@@ -92,13 +92,13 @@ impl<'a> IBYP_W<'a> {
     }
     #[doc = "Instruction prefetch buffer not bypassed."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(IBYP_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(IBYP_A::VALUE1)
     }
     #[doc = "Instruction prefetch buffer bypassed."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(IBYP_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(IBYP_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> IBYP_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum IINV_AW {
     #[doc = "0: No effect."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Initiate invalidation of entire instruction cache."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<IINV_AW> for bool {
     #[inline(always)]
@@ -143,13 +143,13 @@ impl<'a> IINV_W<'a> {
     }
     #[doc = "No effect."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(IINV_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(IINV_AW::VALUE1)
     }
     #[doc = "Initiate invalidation of entire instruction cache."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(IINV_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(IINV_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -168,100 +168,12 @@ impl<'a> IINV_W<'a> {
         self.w
     }
 }
-#[doc = "Data Buffer Bypass\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum DBYP_A {
-    #[doc = "0: Prefetch Data buffer not bypassed."]
-    VALUE1 = 0,
-    #[doc = "1: Prefetch Data buffer bypassed."]
-    VALUE2 = 1,
-}
-impl From<DBYP_A> for bool {
-    #[inline(always)]
-    fn from(variant: DBYP_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `DBYP` reader - Data Buffer Bypass"]
-pub struct DBYP_R(crate::FieldReader<bool, DBYP_A>);
-impl DBYP_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        DBYP_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> DBYP_A {
-        match self.bits {
-            false => DBYP_A::VALUE1,
-            true => DBYP_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == DBYP_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == DBYP_A::VALUE2
-    }
-}
-impl core::ops::Deref for DBYP_R {
-    type Target = crate::FieldReader<bool, DBYP_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `DBYP` writer - Data Buffer Bypass"]
-pub struct DBYP_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> DBYP_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DBYP_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "Prefetch Data buffer not bypassed."]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(DBYP_A::VALUE1)
-    }
-    #[doc = "Prefetch Data buffer bypassed."]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(DBYP_A::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
-        self.w
-    }
-}
 impl R {
     #[doc = "Bit 0 - Instruction Prefetch Buffer Bypass"]
     #[inline(always)]
     pub fn ibyp(&self) -> IBYP_R {
         IBYP_R::new((self.bits & 0x01) != 0)
     }
-    #[doc = "Bit 4 - Data Buffer Bypass"]
-    #[inline(always)]
-    pub fn dbyp(&self) -> DBYP_R {
-        DBYP_R::new(((self.bits >> 4) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bit 0 - Instruction Prefetch Buffer Bypass"]
@@ -274,11 +186,6 @@ impl W {
     pub fn iinv(&mut self) -> IINV_W {
         IINV_W { w: self }
     }
-    #[doc = "Bit 4 - Data Buffer Bypass"]
-    #[inline(always)]
-    pub fn dbyp(&mut self) -> DBYP_W {
-        DBYP_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
