@@ -23,9 +23,9 @@ impl From<crate::W<CLKSET_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBCEN_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBCEN_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> USBCEN_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USBCEN_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USBCEN_AW::VALUE1)
     }
     #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USBCEN_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USBCEN_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> USBCEN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MMCCEN_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MMCCEN_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> MMCCEN_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MMCCEN_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MMCCEN_AW::VALUE1)
     }
     #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MMCCEN_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MMCCEN_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> MMCCEN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0CEN_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ETH0CEN_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> ETH0CEN_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ETH0CEN_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ETH0CEN_AW::VALUE1)
     }
     #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ETH0CEN_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ETH0CEN_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -172,13 +172,64 @@ impl<'a> ETH0CEN_W<'a> {
         self.w
     }
 }
+#[doc = "EBU Clock Enable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum EBUCEN_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
+}
+impl From<EBUCEN_AW> for bool {
+    #[inline(always)]
+    fn from(variant: EBUCEN_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `EBUCEN` writer - EBU Clock Enable"]
+pub struct EBUCEN_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> EBUCEN_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: EBUCEN_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(EBUCEN_AW::VALUE1)
+    }
+    #[doc = "Enable"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(EBUCEN_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w
+    }
+}
 #[doc = "CCU Clock Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCUCEN_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<CCUCEN_AW> for bool {
     #[inline(always)]
@@ -198,13 +249,13 @@ impl<'a> CCUCEN_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CCUCEN_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCUCEN_AW::VALUE1)
     }
     #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CCUCEN_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCUCEN_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -227,9 +278,9 @@ impl<'a> CCUCEN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDTCEN_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WDTCEN_AW> for bool {
     #[inline(always)]
@@ -249,13 +300,13 @@ impl<'a> WDTCEN_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WDTCEN_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WDTCEN_AW::VALUE1)
     }
     #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WDTCEN_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WDTCEN_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -290,6 +341,11 @@ impl W {
     pub fn eth0cen(&mut self) -> ETH0CEN_W {
         ETH0CEN_W { w: self }
     }
+    #[doc = "Bit 3 - EBU Clock Enable"]
+    #[inline(always)]
+    pub fn ebucen(&mut self) -> EBUCEN_W {
+        EBUCEN_W { w: self }
+    }
     #[doc = "Bit 4 - CCU Clock Enable"]
     #[inline(always)]
     pub fn ccucen(&mut self) -> CCUCEN_W {
