@@ -36,45 +36,47 @@ impl From<crate::W<DSLEEPCR_SPEC>> for W {
 }
 #[doc = "System Clock Selection Value\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
+#[repr(u8)]
 pub enum SYSSEL_A {
     #[doc = "0: fOFI clock"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: fPLL clock"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
-impl From<SYSSEL_A> for bool {
+impl From<SYSSEL_A> for u8 {
     #[inline(always)]
     fn from(variant: SYSSEL_A) -> Self {
-        variant as u8 != 0
+        variant as _
     }
 }
 #[doc = "Field `SYSSEL` reader - System Clock Selection Value"]
-pub struct SYSSEL_R(crate::FieldReader<bool, SYSSEL_A>);
+pub struct SYSSEL_R(crate::FieldReader<u8, SYSSEL_A>);
 impl SYSSEL_R {
-    pub(crate) fn new(bits: bool) -> Self {
+    pub(crate) fn new(bits: u8) -> Self {
         SYSSEL_R(crate::FieldReader::new(bits))
     }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> SYSSEL_A {
+    pub fn variant(&self) -> Option<SYSSEL_A> {
         match self.bits {
-            false => SYSSEL_A::CONST_0,
-            true => SYSSEL_A::CONST_1,
+            0 => Some(SYSSEL_A::VALUE1),
+            1 => Some(SYSSEL_A::VALUE2),
+            _ => None,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SYSSEL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SYSSEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SYSSEL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SYSSEL_A::VALUE2
     }
 }
 impl core::ops::Deref for SYSSEL_R {
-    type Target = crate::FieldReader<bool, SYSSEL_A>;
+    type Target = crate::FieldReader<u8, SYSSEL_A>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -88,32 +90,22 @@ impl<'a> SYSSEL_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: SYSSEL_A) -> &'a mut W {
-        self.bit(variant.into())
+        unsafe { self.bits(variant.into()) }
     }
     #[doc = "fOFI clock"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SYSSEL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SYSSEL_A::VALUE1)
     }
     #[doc = "fPLL clock"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SYSSEL_A::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SYSSEL_A::VALUE2)
     }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+    pub unsafe fn bits(self, value: u8) -> &'a mut W {
+        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
         self.w
     }
 }
@@ -121,9 +113,9 @@ impl<'a> SYSSEL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FPDN_A {
     #[doc = "1: Flash power down module"]
-    CONST_1 = 1,
+    VALUE1 = 1,
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE2 = 0,
 }
 impl From<FPDN_A> for bool {
     #[inline(always)]
@@ -141,19 +133,19 @@ impl FPDN_R {
     #[inline(always)]
     pub fn variant(&self) -> FPDN_A {
         match self.bits {
-            true => FPDN_A::CONST_1,
-            false => FPDN_A::CONST_0,
+            true => FPDN_A::VALUE1,
+            false => FPDN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == FPDN_A::CONST_1
+    pub fn is_value1(&self) -> bool {
+        **self == FPDN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == FPDN_A::CONST_0
+    pub fn is_value2(&self) -> bool {
+        **self == FPDN_A::VALUE2
     }
 }
 impl core::ops::Deref for FPDN_R {
@@ -175,13 +167,13 @@ impl<'a> FPDN_W<'a> {
     }
     #[doc = "Flash power down module"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(FPDN_A::CONST_1)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(FPDN_A::VALUE1)
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(FPDN_A::CONST_0)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(FPDN_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +196,9 @@ impl<'a> FPDN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PLLPDN_A {
     #[doc = "1: Switch off main PLL"]
-    CONST_1 = 1,
+    VALUE1 = 1,
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE2 = 0,
 }
 impl From<PLLPDN_A> for bool {
     #[inline(always)]
@@ -224,19 +216,19 @@ impl PLLPDN_R {
     #[inline(always)]
     pub fn variant(&self) -> PLLPDN_A {
         match self.bits {
-            true => PLLPDN_A::CONST_1,
-            false => PLLPDN_A::CONST_0,
+            true => PLLPDN_A::VALUE1,
+            false => PLLPDN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PLLPDN_A::CONST_1
+    pub fn is_value1(&self) -> bool {
+        **self == PLLPDN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PLLPDN_A::CONST_0
+    pub fn is_value2(&self) -> bool {
+        **self == PLLPDN_A::VALUE2
     }
 }
 impl core::ops::Deref for PLLPDN_R {
@@ -258,13 +250,13 @@ impl<'a> PLLPDN_W<'a> {
     }
     #[doc = "Switch off main PLL"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PLLPDN_A::CONST_1)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PLLPDN_A::VALUE1)
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PLLPDN_A::CONST_0)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PLLPDN_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +279,9 @@ impl<'a> PLLPDN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum VCOPDN_A {
     #[doc = "1: Switch off VCO of main PLL"]
-    CONST_1 = 1,
+    VALUE1 = 1,
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE2 = 0,
 }
 impl From<VCOPDN_A> for bool {
     #[inline(always)]
@@ -307,19 +299,19 @@ impl VCOPDN_R {
     #[inline(always)]
     pub fn variant(&self) -> VCOPDN_A {
         match self.bits {
-            true => VCOPDN_A::CONST_1,
-            false => VCOPDN_A::CONST_0,
+            true => VCOPDN_A::VALUE1,
+            false => VCOPDN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == VCOPDN_A::CONST_1
+    pub fn is_value1(&self) -> bool {
+        **self == VCOPDN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == VCOPDN_A::CONST_0
+    pub fn is_value2(&self) -> bool {
+        **self == VCOPDN_A::VALUE2
     }
 }
 impl core::ops::Deref for VCOPDN_R {
@@ -341,13 +333,13 @@ impl<'a> VCOPDN_W<'a> {
     }
     #[doc = "Switch off VCO of main PLL"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(VCOPDN_A::CONST_1)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(VCOPDN_A::VALUE1)
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(VCOPDN_A::CONST_0)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(VCOPDN_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -366,13 +358,13 @@ impl<'a> VCOPDN_W<'a> {
         self.w
     }
 }
-#[doc = "USB Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
+#[doc = "USB Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBCR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<USBCR_A> for bool {
     #[inline(always)]
@@ -380,7 +372,7 @@ impl From<USBCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `USBCR` reader - USB Clock Control in Deep Sleep Mode"]
+#[doc = "Field `USBCR` reader - USB Clock Control"]
 pub struct USBCR_R(crate::FieldReader<bool, USBCR_A>);
 impl USBCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -390,19 +382,19 @@ impl USBCR_R {
     #[inline(always)]
     pub fn variant(&self) -> USBCR_A {
         match self.bits {
-            false => USBCR_A::CONST_0,
-            true => USBCR_A::CONST_1,
+            false => USBCR_A::VALUE1,
+            true => USBCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USBCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USBCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USBCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USBCR_A::VALUE2
     }
 }
 impl core::ops::Deref for USBCR_R {
@@ -412,7 +404,7 @@ impl core::ops::Deref for USBCR_R {
         &self.0
     }
 }
-#[doc = "Field `USBCR` writer - USB Clock Control in Deep Sleep Mode"]
+#[doc = "Field `USBCR` writer - USB Clock Control"]
 pub struct USBCR_W<'a> {
     w: &'a mut W,
 }
@@ -422,15 +414,15 @@ impl<'a> USBCR_W<'a> {
     pub fn variant(self, variant: USBCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USBCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USBCR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USBCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USBCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -449,13 +441,13 @@ impl<'a> USBCR_W<'a> {
         self.w
     }
 }
-#[doc = "MMC Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
+#[doc = "MMC Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MMCCR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<MMCCR_A> for bool {
     #[inline(always)]
@@ -463,7 +455,7 @@ impl From<MMCCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `MMCCR` reader - MMC Clock Control in Deep Sleep Mode"]
+#[doc = "Field `MMCCR` reader - MMC Clock Control"]
 pub struct MMCCR_R(crate::FieldReader<bool, MMCCR_A>);
 impl MMCCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -473,19 +465,19 @@ impl MMCCR_R {
     #[inline(always)]
     pub fn variant(&self) -> MMCCR_A {
         match self.bits {
-            false => MMCCR_A::CONST_0,
-            true => MMCCR_A::CONST_1,
+            false => MMCCR_A::VALUE1,
+            true => MMCCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MMCCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MMCCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MMCCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MMCCR_A::VALUE2
     }
 }
 impl core::ops::Deref for MMCCR_R {
@@ -495,7 +487,7 @@ impl core::ops::Deref for MMCCR_R {
         &self.0
     }
 }
-#[doc = "Field `MMCCR` writer - MMC Clock Control in Deep Sleep Mode"]
+#[doc = "Field `MMCCR` writer - MMC Clock Control"]
 pub struct MMCCR_W<'a> {
     w: &'a mut W,
 }
@@ -505,15 +497,15 @@ impl<'a> MMCCR_W<'a> {
     pub fn variant(self, variant: MMCCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MMCCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MMCCR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MMCCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MMCCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -532,13 +524,13 @@ impl<'a> MMCCR_W<'a> {
         self.w
     }
 }
-#[doc = "Ethernet Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
+#[doc = "Ethernet Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0CR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<ETH0CR_A> for bool {
     #[inline(always)]
@@ -546,7 +538,7 @@ impl From<ETH0CR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `ETH0CR` reader - Ethernet Clock Control in Deep Sleep Mode"]
+#[doc = "Field `ETH0CR` reader - Ethernet Clock Control"]
 pub struct ETH0CR_R(crate::FieldReader<bool, ETH0CR_A>);
 impl ETH0CR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -556,19 +548,19 @@ impl ETH0CR_R {
     #[inline(always)]
     pub fn variant(&self) -> ETH0CR_A {
         match self.bits {
-            false => ETH0CR_A::CONST_0,
-            true => ETH0CR_A::CONST_1,
+            false => ETH0CR_A::VALUE1,
+            true => ETH0CR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ETH0CR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ETH0CR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ETH0CR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ETH0CR_A::VALUE2
     }
 }
 impl core::ops::Deref for ETH0CR_R {
@@ -578,7 +570,7 @@ impl core::ops::Deref for ETH0CR_R {
         &self.0
     }
 }
-#[doc = "Field `ETH0CR` writer - Ethernet Clock Control in Deep Sleep Mode"]
+#[doc = "Field `ETH0CR` writer - Ethernet Clock Control"]
 pub struct ETH0CR_W<'a> {
     w: &'a mut W,
 }
@@ -588,15 +580,15 @@ impl<'a> ETH0CR_W<'a> {
     pub fn variant(self, variant: ETH0CR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ETH0CR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ETH0CR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ETH0CR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ETH0CR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -615,13 +607,96 @@ impl<'a> ETH0CR_W<'a> {
         self.w
     }
 }
-#[doc = "CCU Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
+#[doc = "EBU Clock Control\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum EBUCR_A {
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
+}
+impl From<EBUCR_A> for bool {
+    #[inline(always)]
+    fn from(variant: EBUCR_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `EBUCR` reader - EBU Clock Control"]
+pub struct EBUCR_R(crate::FieldReader<bool, EBUCR_A>);
+impl EBUCR_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EBUCR_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> EBUCR_A {
+        match self.bits {
+            false => EBUCR_A::VALUE1,
+            true => EBUCR_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == EBUCR_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == EBUCR_A::VALUE2
+    }
+}
+impl core::ops::Deref for EBUCR_R {
+    type Target = crate::FieldReader<bool, EBUCR_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EBUCR` writer - EBU Clock Control"]
+pub struct EBUCR_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> EBUCR_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: EBUCR_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disable"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(EBUCR_A::VALUE1)
+    }
+    #[doc = "Enable"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(EBUCR_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w
+    }
+}
+#[doc = "CCU Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCUCR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<CCUCR_A> for bool {
     #[inline(always)]
@@ -629,7 +704,7 @@ impl From<CCUCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `CCUCR` reader - CCU Clock Control in Deep Sleep Mode"]
+#[doc = "Field `CCUCR` reader - CCU Clock Control"]
 pub struct CCUCR_R(crate::FieldReader<bool, CCUCR_A>);
 impl CCUCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -639,19 +714,19 @@ impl CCUCR_R {
     #[inline(always)]
     pub fn variant(&self) -> CCUCR_A {
         match self.bits {
-            false => CCUCR_A::CONST_0,
-            true => CCUCR_A::CONST_1,
+            false => CCUCR_A::VALUE1,
+            true => CCUCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == CCUCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == CCUCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == CCUCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == CCUCR_A::VALUE2
     }
 }
 impl core::ops::Deref for CCUCR_R {
@@ -661,7 +736,7 @@ impl core::ops::Deref for CCUCR_R {
         &self.0
     }
 }
-#[doc = "Field `CCUCR` writer - CCU Clock Control in Deep Sleep Mode"]
+#[doc = "Field `CCUCR` writer - CCU Clock Control"]
 pub struct CCUCR_W<'a> {
     w: &'a mut W,
 }
@@ -671,15 +746,15 @@ impl<'a> CCUCR_W<'a> {
     pub fn variant(self, variant: CCUCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CCUCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCUCR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CCUCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCUCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -698,13 +773,13 @@ impl<'a> CCUCR_W<'a> {
         self.w
     }
 }
-#[doc = "WDT Clock Control in Deep Sleep Mode\n\nValue on reset: 0"]
+#[doc = "WDT Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDTCR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<WDTCR_A> for bool {
     #[inline(always)]
@@ -712,7 +787,7 @@ impl From<WDTCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `WDTCR` reader - WDT Clock Control in Deep Sleep Mode"]
+#[doc = "Field `WDTCR` reader - WDT Clock Control"]
 pub struct WDTCR_R(crate::FieldReader<bool, WDTCR_A>);
 impl WDTCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -722,19 +797,19 @@ impl WDTCR_R {
     #[inline(always)]
     pub fn variant(&self) -> WDTCR_A {
         match self.bits {
-            false => WDTCR_A::CONST_0,
-            true => WDTCR_A::CONST_1,
+            false => WDTCR_A::VALUE1,
+            true => WDTCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == WDTCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == WDTCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == WDTCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == WDTCR_A::VALUE2
     }
 }
 impl core::ops::Deref for WDTCR_R {
@@ -744,7 +819,7 @@ impl core::ops::Deref for WDTCR_R {
         &self.0
     }
 }
-#[doc = "Field `WDTCR` writer - WDT Clock Control in Deep Sleep Mode"]
+#[doc = "Field `WDTCR` writer - WDT Clock Control"]
 pub struct WDTCR_W<'a> {
     w: &'a mut W,
 }
@@ -754,15 +829,15 @@ impl<'a> WDTCR_W<'a> {
     pub fn variant(self, variant: WDTCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WDTCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WDTCR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WDTCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WDTCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -782,10 +857,10 @@ impl<'a> WDTCR_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bit 0 - System Clock Selection Value"]
+    #[doc = "Bits 0:1 - System Clock Selection Value"]
     #[inline(always)]
     pub fn syssel(&self) -> SYSSEL_R {
-        SYSSEL_R::new((self.bits & 0x01) != 0)
+        SYSSEL_R::new((self.bits & 0x03) as u8)
     }
     #[doc = "Bit 11 - Flash Power Down"]
     #[inline(always)]
@@ -802,34 +877,39 @@ impl R {
     pub fn vcopdn(&self) -> VCOPDN_R {
         VCOPDN_R::new(((self.bits >> 13) & 0x01) != 0)
     }
-    #[doc = "Bit 16 - USB Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 16 - USB Clock Control"]
     #[inline(always)]
     pub fn usbcr(&self) -> USBCR_R {
         USBCR_R::new(((self.bits >> 16) & 0x01) != 0)
     }
-    #[doc = "Bit 17 - MMC Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 17 - MMC Clock Control"]
     #[inline(always)]
     pub fn mmccr(&self) -> MMCCR_R {
         MMCCR_R::new(((self.bits >> 17) & 0x01) != 0)
     }
-    #[doc = "Bit 18 - Ethernet Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 18 - Ethernet Clock Control"]
     #[inline(always)]
     pub fn eth0cr(&self) -> ETH0CR_R {
         ETH0CR_R::new(((self.bits >> 18) & 0x01) != 0)
     }
-    #[doc = "Bit 20 - CCU Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 19 - EBU Clock Control"]
+    #[inline(always)]
+    pub fn ebucr(&self) -> EBUCR_R {
+        EBUCR_R::new(((self.bits >> 19) & 0x01) != 0)
+    }
+    #[doc = "Bit 20 - CCU Clock Control"]
     #[inline(always)]
     pub fn ccucr(&self) -> CCUCR_R {
         CCUCR_R::new(((self.bits >> 20) & 0x01) != 0)
     }
-    #[doc = "Bit 21 - WDT Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 21 - WDT Clock Control"]
     #[inline(always)]
     pub fn wdtcr(&self) -> WDTCR_R {
         WDTCR_R::new(((self.bits >> 21) & 0x01) != 0)
     }
 }
 impl W {
-    #[doc = "Bit 0 - System Clock Selection Value"]
+    #[doc = "Bits 0:1 - System Clock Selection Value"]
     #[inline(always)]
     pub fn syssel(&mut self) -> SYSSEL_W {
         SYSSEL_W { w: self }
@@ -849,27 +929,32 @@ impl W {
     pub fn vcopdn(&mut self) -> VCOPDN_W {
         VCOPDN_W { w: self }
     }
-    #[doc = "Bit 16 - USB Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 16 - USB Clock Control"]
     #[inline(always)]
     pub fn usbcr(&mut self) -> USBCR_W {
         USBCR_W { w: self }
     }
-    #[doc = "Bit 17 - MMC Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 17 - MMC Clock Control"]
     #[inline(always)]
     pub fn mmccr(&mut self) -> MMCCR_W {
         MMCCR_W { w: self }
     }
-    #[doc = "Bit 18 - Ethernet Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 18 - Ethernet Clock Control"]
     #[inline(always)]
     pub fn eth0cr(&mut self) -> ETH0CR_W {
         ETH0CR_W { w: self }
     }
-    #[doc = "Bit 20 - CCU Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 19 - EBU Clock Control"]
+    #[inline(always)]
+    pub fn ebucr(&mut self) -> EBUCR_W {
+        EBUCR_W { w: self }
+    }
+    #[doc = "Bit 20 - CCU Clock Control"]
     #[inline(always)]
     pub fn ccucr(&mut self) -> CCUCR_W {
         CCUCR_W { w: self }
     }
-    #[doc = "Bit 21 - WDT Clock Control in Deep Sleep Mode"]
+    #[doc = "Bit 21 - WDT Clock Control"]
     #[inline(always)]
     pub fn wdtcr(&mut self) -> WDTCR_W {
         WDTCR_W { w: self }
