@@ -38,9 +38,9 @@ impl From<crate::W<SLEEPCR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SYSSEL_A {
     #[doc = "0: fOFI clock"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: fPLL clock"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SYSSEL_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl SYSSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> SYSSEL_A {
         match self.bits {
-            false => SYSSEL_A::CONST_0,
-            true => SYSSEL_A::CONST_1,
+            false => SYSSEL_A::VALUE1,
+            true => SYSSEL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SYSSEL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SYSSEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SYSSEL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SYSSEL_A::VALUE2
     }
 }
 impl core::ops::Deref for SYSSEL_R {
@@ -92,13 +92,13 @@ impl<'a> SYSSEL_W<'a> {
     }
     #[doc = "fOFI clock"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SYSSEL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SYSSEL_A::VALUE1)
     }
     #[doc = "fPLL clock"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SYSSEL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SYSSEL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -117,13 +117,13 @@ impl<'a> SYSSEL_W<'a> {
         self.w
     }
 }
-#[doc = "USB Clock Control in Sleep Mode\n\nValue on reset: 0"]
+#[doc = "USB Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBCR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<USBCR_A> for bool {
     #[inline(always)]
@@ -131,7 +131,7 @@ impl From<USBCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `USBCR` reader - USB Clock Control in Sleep Mode"]
+#[doc = "Field `USBCR` reader - USB Clock Control"]
 pub struct USBCR_R(crate::FieldReader<bool, USBCR_A>);
 impl USBCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -141,19 +141,19 @@ impl USBCR_R {
     #[inline(always)]
     pub fn variant(&self) -> USBCR_A {
         match self.bits {
-            false => USBCR_A::CONST_0,
-            true => USBCR_A::CONST_1,
+            false => USBCR_A::VALUE1,
+            true => USBCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USBCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USBCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USBCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USBCR_A::VALUE2
     }
 }
 impl core::ops::Deref for USBCR_R {
@@ -163,7 +163,7 @@ impl core::ops::Deref for USBCR_R {
         &self.0
     }
 }
-#[doc = "Field `USBCR` writer - USB Clock Control in Sleep Mode"]
+#[doc = "Field `USBCR` writer - USB Clock Control"]
 pub struct USBCR_W<'a> {
     w: &'a mut W,
 }
@@ -173,15 +173,15 @@ impl<'a> USBCR_W<'a> {
     pub fn variant(self, variant: USBCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USBCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USBCR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USBCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USBCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -200,13 +200,13 @@ impl<'a> USBCR_W<'a> {
         self.w
     }
 }
-#[doc = "MMC Clock Control in Sleep Mode\n\nValue on reset: 0"]
+#[doc = "MMC Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MMCCR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<MMCCR_A> for bool {
     #[inline(always)]
@@ -214,7 +214,7 @@ impl From<MMCCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `MMCCR` reader - MMC Clock Control in Sleep Mode"]
+#[doc = "Field `MMCCR` reader - MMC Clock Control"]
 pub struct MMCCR_R(crate::FieldReader<bool, MMCCR_A>);
 impl MMCCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -224,19 +224,19 @@ impl MMCCR_R {
     #[inline(always)]
     pub fn variant(&self) -> MMCCR_A {
         match self.bits {
-            false => MMCCR_A::CONST_0,
-            true => MMCCR_A::CONST_1,
+            false => MMCCR_A::VALUE1,
+            true => MMCCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MMCCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MMCCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MMCCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MMCCR_A::VALUE2
     }
 }
 impl core::ops::Deref for MMCCR_R {
@@ -246,7 +246,7 @@ impl core::ops::Deref for MMCCR_R {
         &self.0
     }
 }
-#[doc = "Field `MMCCR` writer - MMC Clock Control in Sleep Mode"]
+#[doc = "Field `MMCCR` writer - MMC Clock Control"]
 pub struct MMCCR_W<'a> {
     w: &'a mut W,
 }
@@ -256,15 +256,15 @@ impl<'a> MMCCR_W<'a> {
     pub fn variant(self, variant: MMCCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MMCCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MMCCR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MMCCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MMCCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -283,13 +283,13 @@ impl<'a> MMCCR_W<'a> {
         self.w
     }
 }
-#[doc = "Ethernet Clock Control in Sleep Mode\n\nValue on reset: 0"]
+#[doc = "Ethernet Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0CR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<ETH0CR_A> for bool {
     #[inline(always)]
@@ -297,7 +297,7 @@ impl From<ETH0CR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `ETH0CR` reader - Ethernet Clock Control in Sleep Mode"]
+#[doc = "Field `ETH0CR` reader - Ethernet Clock Control"]
 pub struct ETH0CR_R(crate::FieldReader<bool, ETH0CR_A>);
 impl ETH0CR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -307,19 +307,19 @@ impl ETH0CR_R {
     #[inline(always)]
     pub fn variant(&self) -> ETH0CR_A {
         match self.bits {
-            false => ETH0CR_A::CONST_0,
-            true => ETH0CR_A::CONST_1,
+            false => ETH0CR_A::VALUE1,
+            true => ETH0CR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ETH0CR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ETH0CR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ETH0CR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ETH0CR_A::VALUE2
     }
 }
 impl core::ops::Deref for ETH0CR_R {
@@ -329,7 +329,7 @@ impl core::ops::Deref for ETH0CR_R {
         &self.0
     }
 }
-#[doc = "Field `ETH0CR` writer - Ethernet Clock Control in Sleep Mode"]
+#[doc = "Field `ETH0CR` writer - Ethernet Clock Control"]
 pub struct ETH0CR_W<'a> {
     w: &'a mut W,
 }
@@ -339,15 +339,15 @@ impl<'a> ETH0CR_W<'a> {
     pub fn variant(self, variant: ETH0CR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ETH0CR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ETH0CR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ETH0CR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ETH0CR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -366,13 +366,96 @@ impl<'a> ETH0CR_W<'a> {
         self.w
     }
 }
-#[doc = "CCU Clock Control in Sleep Mode\n\nValue on reset: 0"]
+#[doc = "EBU Clock Control\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum EBUCR_A {
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
+}
+impl From<EBUCR_A> for bool {
+    #[inline(always)]
+    fn from(variant: EBUCR_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `EBUCR` reader - EBU Clock Control"]
+pub struct EBUCR_R(crate::FieldReader<bool, EBUCR_A>);
+impl EBUCR_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EBUCR_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> EBUCR_A {
+        match self.bits {
+            false => EBUCR_A::VALUE1,
+            true => EBUCR_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == EBUCR_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == EBUCR_A::VALUE2
+    }
+}
+impl core::ops::Deref for EBUCR_R {
+    type Target = crate::FieldReader<bool, EBUCR_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EBUCR` writer - EBU Clock Control"]
+pub struct EBUCR_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> EBUCR_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: EBUCR_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disable"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(EBUCR_A::VALUE1)
+    }
+    #[doc = "Enable"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(EBUCR_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w
+    }
+}
+#[doc = "CCU Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCUCR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<CCUCR_A> for bool {
     #[inline(always)]
@@ -380,7 +463,7 @@ impl From<CCUCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `CCUCR` reader - CCU Clock Control in Sleep Mode"]
+#[doc = "Field `CCUCR` reader - CCU Clock Control"]
 pub struct CCUCR_R(crate::FieldReader<bool, CCUCR_A>);
 impl CCUCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -390,19 +473,19 @@ impl CCUCR_R {
     #[inline(always)]
     pub fn variant(&self) -> CCUCR_A {
         match self.bits {
-            false => CCUCR_A::CONST_0,
-            true => CCUCR_A::CONST_1,
+            false => CCUCR_A::VALUE1,
+            true => CCUCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == CCUCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == CCUCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == CCUCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == CCUCR_A::VALUE2
     }
 }
 impl core::ops::Deref for CCUCR_R {
@@ -412,7 +495,7 @@ impl core::ops::Deref for CCUCR_R {
         &self.0
     }
 }
-#[doc = "Field `CCUCR` writer - CCU Clock Control in Sleep Mode"]
+#[doc = "Field `CCUCR` writer - CCU Clock Control"]
 pub struct CCUCR_W<'a> {
     w: &'a mut W,
 }
@@ -422,15 +505,15 @@ impl<'a> CCUCR_W<'a> {
     pub fn variant(self, variant: CCUCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CCUCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCUCR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CCUCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCUCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -449,13 +532,13 @@ impl<'a> CCUCR_W<'a> {
         self.w
     }
 }
-#[doc = "WDT Clock Control in Sleep Mode\n\nValue on reset: 0"]
+#[doc = "WDT Clock Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDTCR_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    #[doc = "0: Disable"]
+    VALUE1 = 0,
+    #[doc = "1: Enable"]
+    VALUE2 = 1,
 }
 impl From<WDTCR_A> for bool {
     #[inline(always)]
@@ -463,7 +546,7 @@ impl From<WDTCR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Field `WDTCR` reader - WDT Clock Control in Sleep Mode"]
+#[doc = "Field `WDTCR` reader - WDT Clock Control"]
 pub struct WDTCR_R(crate::FieldReader<bool, WDTCR_A>);
 impl WDTCR_R {
     pub(crate) fn new(bits: bool) -> Self {
@@ -473,19 +556,19 @@ impl WDTCR_R {
     #[inline(always)]
     pub fn variant(&self) -> WDTCR_A {
         match self.bits {
-            false => WDTCR_A::CONST_0,
-            true => WDTCR_A::CONST_1,
+            false => WDTCR_A::VALUE1,
+            true => WDTCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == WDTCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == WDTCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == WDTCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == WDTCR_A::VALUE2
     }
 }
 impl core::ops::Deref for WDTCR_R {
@@ -495,7 +578,7 @@ impl core::ops::Deref for WDTCR_R {
         &self.0
     }
 }
-#[doc = "Field `WDTCR` writer - WDT Clock Control in Sleep Mode"]
+#[doc = "Field `WDTCR` writer - WDT Clock Control"]
 pub struct WDTCR_W<'a> {
     w: &'a mut W,
 }
@@ -505,15 +588,15 @@ impl<'a> WDTCR_W<'a> {
     pub fn variant(self, variant: WDTCR_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Disabled"]
+    #[doc = "Disable"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WDTCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WDTCR_A::VALUE1)
     }
-    #[doc = "Enabled"]
+    #[doc = "Enable"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WDTCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WDTCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -538,27 +621,32 @@ impl R {
     pub fn syssel(&self) -> SYSSEL_R {
         SYSSEL_R::new((self.bits & 0x01) != 0)
     }
-    #[doc = "Bit 16 - USB Clock Control in Sleep Mode"]
+    #[doc = "Bit 16 - USB Clock Control"]
     #[inline(always)]
     pub fn usbcr(&self) -> USBCR_R {
         USBCR_R::new(((self.bits >> 16) & 0x01) != 0)
     }
-    #[doc = "Bit 17 - MMC Clock Control in Sleep Mode"]
+    #[doc = "Bit 17 - MMC Clock Control"]
     #[inline(always)]
     pub fn mmccr(&self) -> MMCCR_R {
         MMCCR_R::new(((self.bits >> 17) & 0x01) != 0)
     }
-    #[doc = "Bit 18 - Ethernet Clock Control in Sleep Mode"]
+    #[doc = "Bit 18 - Ethernet Clock Control"]
     #[inline(always)]
     pub fn eth0cr(&self) -> ETH0CR_R {
         ETH0CR_R::new(((self.bits >> 18) & 0x01) != 0)
     }
-    #[doc = "Bit 20 - CCU Clock Control in Sleep Mode"]
+    #[doc = "Bit 19 - EBU Clock Control"]
+    #[inline(always)]
+    pub fn ebucr(&self) -> EBUCR_R {
+        EBUCR_R::new(((self.bits >> 19) & 0x01) != 0)
+    }
+    #[doc = "Bit 20 - CCU Clock Control"]
     #[inline(always)]
     pub fn ccucr(&self) -> CCUCR_R {
         CCUCR_R::new(((self.bits >> 20) & 0x01) != 0)
     }
-    #[doc = "Bit 21 - WDT Clock Control in Sleep Mode"]
+    #[doc = "Bit 21 - WDT Clock Control"]
     #[inline(always)]
     pub fn wdtcr(&self) -> WDTCR_R {
         WDTCR_R::new(((self.bits >> 21) & 0x01) != 0)
@@ -570,27 +658,32 @@ impl W {
     pub fn syssel(&mut self) -> SYSSEL_W {
         SYSSEL_W { w: self }
     }
-    #[doc = "Bit 16 - USB Clock Control in Sleep Mode"]
+    #[doc = "Bit 16 - USB Clock Control"]
     #[inline(always)]
     pub fn usbcr(&mut self) -> USBCR_W {
         USBCR_W { w: self }
     }
-    #[doc = "Bit 17 - MMC Clock Control in Sleep Mode"]
+    #[doc = "Bit 17 - MMC Clock Control"]
     #[inline(always)]
     pub fn mmccr(&mut self) -> MMCCR_W {
         MMCCR_W { w: self }
     }
-    #[doc = "Bit 18 - Ethernet Clock Control in Sleep Mode"]
+    #[doc = "Bit 18 - Ethernet Clock Control"]
     #[inline(always)]
     pub fn eth0cr(&mut self) -> ETH0CR_W {
         ETH0CR_W { w: self }
     }
-    #[doc = "Bit 20 - CCU Clock Control in Sleep Mode"]
+    #[doc = "Bit 19 - EBU Clock Control"]
+    #[inline(always)]
+    pub fn ebucr(&mut self) -> EBUCR_W {
+        EBUCR_W { w: self }
+    }
+    #[doc = "Bit 20 - CCU Clock Control"]
     #[inline(always)]
     pub fn ccucr(&mut self) -> CCUCR_W {
         CCUCR_W { w: self }
     }
-    #[doc = "Bit 21 - WDT Clock Control in Sleep Mode"]
+    #[doc = "Bit 21 - WDT Clock Control"]
     #[inline(always)]
     pub fn wdtcr(&mut self) -> WDTCR_W {
         WDTCR_W { w: self }
