@@ -81,10 +81,10 @@ impl crate::RegisterSpec for ID_SPEC {
 impl crate::Readable for ID_SPEC {
     type Reader = R;
 }
-#[doc = "`reset()` method sets ID to value 0x0090_c000"]
+#[doc = "`reset()` method sets ID to value 0x00a0_c000"]
 impl crate::Resettable for ID_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x0090_c000
+        0x00a0_c000
     }
 }
