@@ -23,9 +23,9 @@ impl From<crate::W<HDCLR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum EPEV_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear wake-up event"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<EPEV_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> EPEV_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(EPEV_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(EPEV_AW::VALUE1)
     }
     #[doc = "Clear wake-up event"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(EPEV_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(EPEV_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> EPEV_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ENEV_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear wake-up event"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ENEV_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> ENEV_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ENEV_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ENEV_AW::VALUE1)
     }
     #[doc = "Clear wake-up event"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ENEV_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ENEV_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> ENEV_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTCEV_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear wake-up event"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTCEV_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> RTCEV_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTCEV_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTCEV_AW::VALUE1)
     }
     #[doc = "Clear wake-up event"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTCEV_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTCEV_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -176,9 +176,9 @@ impl<'a> RTCEV_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ULPWDG_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear watchdog alarm"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ULPWDG_AW> for bool {
     #[inline(always)]
@@ -198,13 +198,13 @@ impl<'a> ULPWDG_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ULPWDG_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ULPWDG_AW::VALUE1)
     }
     #[doc = "Clear watchdog alarm"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ULPWDG_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ULPWDG_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
