@@ -38,9 +38,9 @@ impl From<crate::W<HDCR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WKPEP_A {
     #[doc = "0: Wake-up event disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Wake-up event enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WKPEP_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl WKPEP_R {
     #[inline(always)]
     pub fn variant(&self) -> WKPEP_A {
         match self.bits {
-            false => WKPEP_A::CONST_0,
-            true => WKPEP_A::CONST_1,
+            false => WKPEP_A::VALUE1,
+            true => WKPEP_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == WKPEP_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == WKPEP_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == WKPEP_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == WKPEP_A::VALUE2
     }
 }
 impl core::ops::Deref for WKPEP_R {
@@ -92,13 +92,13 @@ impl<'a> WKPEP_W<'a> {
     }
     #[doc = "Wake-up event disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WKPEP_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WKPEP_A::VALUE1)
     }
     #[doc = "Wake-up event enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WKPEP_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WKPEP_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> WKPEP_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WKPEN_A {
     #[doc = "0: Wake-up event disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Wake-up event enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WKPEN_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl WKPEN_R {
     #[inline(always)]
     pub fn variant(&self) -> WKPEN_A {
         match self.bits {
-            false => WKPEN_A::CONST_0,
-            true => WKPEN_A::CONST_1,
+            false => WKPEN_A::VALUE1,
+            true => WKPEN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == WKPEN_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == WKPEN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == WKPEN_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == WKPEN_A::VALUE2
     }
 }
 impl core::ops::Deref for WKPEN_R {
@@ -175,13 +175,13 @@ impl<'a> WKPEN_W<'a> {
     }
     #[doc = "Wake-up event disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WKPEN_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WKPEN_A::VALUE1)
     }
     #[doc = "Wake-up event enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WKPEN_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WKPEN_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> WKPEN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTCE_A {
     #[doc = "0: Wake-up event disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Wake-up event enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTCE_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl RTCE_R {
     #[inline(always)]
     pub fn variant(&self) -> RTCE_A {
         match self.bits {
-            false => RTCE_A::CONST_0,
-            true => RTCE_A::CONST_1,
+            false => RTCE_A::VALUE1,
+            true => RTCE_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTCE_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTCE_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTCE_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTCE_A::VALUE2
     }
 }
 impl core::ops::Deref for RTCE_R {
@@ -258,13 +258,13 @@ impl<'a> RTCE_W<'a> {
     }
     #[doc = "Wake-up event disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTCE_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTCE_A::VALUE1)
     }
     #[doc = "Wake-up event enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTCE_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTCE_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> RTCE_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ULPWDGEN_A {
     #[doc = "0: Wake-up event disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Wake-up event enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ULPWDGEN_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl ULPWDGEN_R {
     #[inline(always)]
     pub fn variant(&self) -> ULPWDGEN_A {
         match self.bits {
-            false => ULPWDGEN_A::CONST_0,
-            true => ULPWDGEN_A::CONST_1,
+            false => ULPWDGEN_A::VALUE1,
+            true => ULPWDGEN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ULPWDGEN_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ULPWDGEN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ULPWDGEN_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ULPWDGEN_A::VALUE2
     }
 }
 impl core::ops::Deref for ULPWDGEN_R {
@@ -341,13 +341,13 @@ impl<'a> ULPWDGEN_W<'a> {
     }
     #[doc = "Wake-up event disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ULPWDGEN_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ULPWDGEN_A::VALUE1)
     }
     #[doc = "Wake-up event enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ULPWDGEN_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ULPWDGEN_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> ULPWDGEN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HIB_A {
     #[doc = "0: External hibernate request inactive"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: External hibernate request active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HIB_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl HIB_R {
     #[inline(always)]
     pub fn variant(&self) -> HIB_A {
         match self.bits {
-            false => HIB_A::CONST_0,
-            true => HIB_A::CONST_1,
+            false => HIB_A::VALUE1,
+            true => HIB_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HIB_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HIB_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HIB_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HIB_A::VALUE2
     }
 }
 impl core::ops::Deref for HIB_R {
@@ -424,13 +424,13 @@ impl<'a> HIB_W<'a> {
     }
     #[doc = "External hibernate request inactive"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HIB_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HIB_A::VALUE1)
     }
     #[doc = "External hibernate request active"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HIB_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HIB_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> HIB_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RCS_A {
     #[doc = "0: fOSI selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: fULP selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RCS_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl RCS_R {
     #[inline(always)]
     pub fn variant(&self) -> RCS_A {
         match self.bits {
-            false => RCS_A::CONST_0,
-            true => RCS_A::CONST_1,
+            false => RCS_A::VALUE1,
+            true => RCS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RCS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RCS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RCS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RCS_A::VALUE2
     }
 }
 impl core::ops::Deref for RCS_R {
@@ -507,13 +507,13 @@ impl<'a> RCS_W<'a> {
     }
     #[doc = "fOSI selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RCS_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RCS_A::VALUE1)
     }
     #[doc = "fULP selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RCS_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RCS_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> RCS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum STDBYSEL_A {
     #[doc = "0: fOSI selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: fULP selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<STDBYSEL_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl STDBYSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> STDBYSEL_A {
         match self.bits {
-            false => STDBYSEL_A::CONST_0,
-            true => STDBYSEL_A::CONST_1,
+            false => STDBYSEL_A::VALUE1,
+            true => STDBYSEL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == STDBYSEL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == STDBYSEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == STDBYSEL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == STDBYSEL_A::VALUE2
     }
 }
 impl core::ops::Deref for STDBYSEL_R {
@@ -590,13 +590,13 @@ impl<'a> STDBYSEL_W<'a> {
     }
     #[doc = "fOSI selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(STDBYSEL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(STDBYSEL_A::VALUE1)
     }
     #[doc = "fULP selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(STDBYSEL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(STDBYSEL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +619,9 @@ impl<'a> STDBYSEL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WKUPSEL_A {
     #[doc = "0: HIB_IO_1 pin selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: HIB_IO_0 pin selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WKUPSEL_A> for bool {
     #[inline(always)]
@@ -639,19 +639,19 @@ impl WKUPSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> WKUPSEL_A {
         match self.bits {
-            false => WKUPSEL_A::CONST_0,
-            true => WKUPSEL_A::CONST_1,
+            false => WKUPSEL_A::VALUE1,
+            true => WKUPSEL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == WKUPSEL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == WKUPSEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == WKUPSEL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == WKUPSEL_A::VALUE2
     }
 }
 impl core::ops::Deref for WKUPSEL_R {
@@ -673,13 +673,13 @@ impl<'a> WKUPSEL_W<'a> {
     }
     #[doc = "HIB_IO_1 pin selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WKUPSEL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WKUPSEL_A::VALUE1)
     }
     #[doc = "HIB_IO_0 pin selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WKUPSEL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WKUPSEL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -701,10 +701,10 @@ impl<'a> WKUPSEL_W<'a> {
 #[doc = "General Purpose Input 0 Selection\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum GPI0SEL_A {
-    #[doc = "0: #0"]
-    CONST_0 = 0,
+    #[doc = "0: HIB_IO_1 pin selected"]
+    VALUE1 = 0,
     #[doc = "1: HIB_IO_0 pin selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<GPI0SEL_A> for bool {
     #[inline(always)]
@@ -722,19 +722,19 @@ impl GPI0SEL_R {
     #[inline(always)]
     pub fn variant(&self) -> GPI0SEL_A {
         match self.bits {
-            false => GPI0SEL_A::CONST_0,
-            true => GPI0SEL_A::CONST_1,
+            false => GPI0SEL_A::VALUE1,
+            true => GPI0SEL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == GPI0SEL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == GPI0SEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == GPI0SEL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == GPI0SEL_A::VALUE2
     }
 }
 impl core::ops::Deref for GPI0SEL_R {
@@ -754,15 +754,15 @@ impl<'a> GPI0SEL_W<'a> {
     pub fn variant(self, variant: GPI0SEL_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "#0"]
+    #[doc = "HIB_IO_1 pin selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(GPI0SEL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(GPI0SEL_A::VALUE1)
     }
     #[doc = "HIB_IO_0 pin selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(GPI0SEL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(GPI0SEL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +785,9 @@ impl<'a> GPI0SEL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HIBIO0POL_A {
     #[doc = "0: Direct value"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Inverted value"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HIBIO0POL_A> for bool {
     #[inline(always)]
@@ -805,19 +805,19 @@ impl HIBIO0POL_R {
     #[inline(always)]
     pub fn variant(&self) -> HIBIO0POL_A {
         match self.bits {
-            false => HIBIO0POL_A::CONST_0,
-            true => HIBIO0POL_A::CONST_1,
+            false => HIBIO0POL_A::VALUE1,
+            true => HIBIO0POL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HIBIO0POL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HIBIO0POL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HIBIO0POL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HIBIO0POL_A::VALUE2
     }
 }
 impl core::ops::Deref for HIBIO0POL_R {
@@ -839,13 +839,13 @@ impl<'a> HIBIO0POL_W<'a> {
     }
     #[doc = "Direct value"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HIBIO0POL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HIBIO0POL_A::VALUE1)
     }
     #[doc = "Inverted value"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HIBIO0POL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HIBIO0POL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +868,9 @@ impl<'a> HIBIO0POL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HIBIO1POL_A {
     #[doc = "0: Direct value"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Inverted value"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HIBIO1POL_A> for bool {
     #[inline(always)]
@@ -888,19 +888,19 @@ impl HIBIO1POL_R {
     #[inline(always)]
     pub fn variant(&self) -> HIBIO1POL_A {
         match self.bits {
-            false => HIBIO1POL_A::CONST_0,
-            true => HIBIO1POL_A::CONST_1,
+            false => HIBIO1POL_A::VALUE1,
+            true => HIBIO1POL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HIBIO1POL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HIBIO1POL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HIBIO1POL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HIBIO1POL_A::VALUE2
     }
 }
 impl core::ops::Deref for HIBIO1POL_R {
@@ -922,13 +922,13 @@ impl<'a> HIBIO1POL_W<'a> {
     }
     #[doc = "Direct value"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HIBIO1POL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HIBIO1POL_A::VALUE1)
     }
     #[doc = "Inverted value"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HIBIO1POL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HIBIO1POL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -952,25 +952,23 @@ impl<'a> HIBIO1POL_W<'a> {
 #[repr(u8)]
 pub enum HIBIO0SEL_A {
     #[doc = "0: Direct input, No input pull device connected"]
-    CONST_0000 = 0,
+    VALUE1 = 0,
     #[doc = "1: Direct input, Input pull-down device connected"]
-    CONST_0001 = 1,
+    VALUE2 = 1,
     #[doc = "2: Direct input, Input pull-up device connected"]
-    CONST_0010 = 2,
+    VALUE3 = 2,
     #[doc = "8: Push-pull HIB Control output"]
-    CONST_1000 = 8,
+    VALUE4 = 8,
     #[doc = "9: Push-pull WDT service output"]
-    CONST_1001 = 9,
+    VALUE5 = 9,
     #[doc = "10: Push-pull GPIO output"]
-    CONST_1010 = 10,
+    VALUE6 = 10,
     #[doc = "12: Open-drain HIB Control output"]
-    CONST_1100 = 12,
+    VALUE7 = 12,
     #[doc = "13: Open-drain WDT service output"]
-    CONST_1101 = 13,
+    VALUE8 = 13,
     #[doc = "14: Open-drain GPIO output"]
-    CONST_1110 = 14,
-    #[doc = "15: #1111"]
-    CONST_1111 = 15,
+    VALUE9 = 14,
 }
 impl From<HIBIO0SEL_A> for u8 {
     #[inline(always)]
@@ -988,68 +986,62 @@ impl HIBIO0SEL_R {
     #[inline(always)]
     pub fn variant(&self) -> Option<HIBIO0SEL_A> {
         match self.bits {
-            0 => Some(HIBIO0SEL_A::CONST_0000),
-            1 => Some(HIBIO0SEL_A::CONST_0001),
-            2 => Some(HIBIO0SEL_A::CONST_0010),
-            8 => Some(HIBIO0SEL_A::CONST_1000),
-            9 => Some(HIBIO0SEL_A::CONST_1001),
-            10 => Some(HIBIO0SEL_A::CONST_1010),
-            12 => Some(HIBIO0SEL_A::CONST_1100),
-            13 => Some(HIBIO0SEL_A::CONST_1101),
-            14 => Some(HIBIO0SEL_A::CONST_1110),
-            15 => Some(HIBIO0SEL_A::CONST_1111),
+            0 => Some(HIBIO0SEL_A::VALUE1),
+            1 => Some(HIBIO0SEL_A::VALUE2),
+            2 => Some(HIBIO0SEL_A::VALUE3),
+            8 => Some(HIBIO0SEL_A::VALUE4),
+            9 => Some(HIBIO0SEL_A::VALUE5),
+            10 => Some(HIBIO0SEL_A::VALUE6),
+            12 => Some(HIBIO0SEL_A::VALUE7),
+            13 => Some(HIBIO0SEL_A::VALUE8),
+            14 => Some(HIBIO0SEL_A::VALUE9),
             _ => None,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0000`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0000(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_0000
+    pub fn is_value1(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_0001`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_0001(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_0001
+    pub fn is_value2(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE2
     }
-    #[doc = "Checks if the value of the field is `CONST_0010`"]
+    #[doc = "Checks if the value of the field is `VALUE3`"]
     #[inline(always)]
-    pub fn is_const_0010(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_0010
+    pub fn is_value3(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE3
     }
-    #[doc = "Checks if the value of the field is `CONST_1000`"]
+    #[doc = "Checks if the value of the field is `VALUE4`"]
     #[inline(always)]
-    pub fn is_const_1000(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_1000
+    pub fn is_value4(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE4
     }
-    #[doc = "Checks if the value of the field is `CONST_1001`"]
+    #[doc = "Checks if the value of the field is `VALUE5`"]
     #[inline(always)]
-    pub fn is_const_1001(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_1001
+    pub fn is_value5(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE5
     }
-    #[doc = "Checks if the value of the field is `CONST_1010`"]
+    #[doc = "Checks if the value of the field is `VALUE6`"]
     #[inline(always)]
-    pub fn is_const_1010(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_1010
+    pub fn is_value6(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE6
     }
-    #[doc = "Checks if the value of the field is `CONST_1100`"]
+    #[doc = "Checks if the value of the field is `VALUE7`"]
     #[inline(always)]
-    pub fn is_const_1100(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_1100
+    pub fn is_value7(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE7
     }
-    #[doc = "Checks if the value of the field is `CONST_1101`"]
+    #[doc = "Checks if the value of the field is `VALUE8`"]
     #[inline(always)]
-    pub fn is_const_1101(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_1101
+    pub fn is_value8(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE8
     }
-    #[doc = "Checks if the value of the field is `CONST_1110`"]
+    #[doc = "Checks if the value of the field is `VALUE9`"]
     #[inline(always)]
-    pub fn is_const_1110(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_1110
-    }
-    #[doc = "Checks if the value of the field is `CONST_1111`"]
-    #[inline(always)]
-    pub fn is_const_1111(&self) -> bool {
-        **self == HIBIO0SEL_A::CONST_1111
+    pub fn is_value9(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE9
     }
 }
 impl core::ops::Deref for HIBIO0SEL_R {
@@ -1071,53 +1063,48 @@ impl<'a> HIBIO0SEL_W<'a> {
     }
     #[doc = "Direct input, No input pull device connected"]
     #[inline(always)]
-    pub fn const_0000(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_0000)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE1)
     }
     #[doc = "Direct input, Input pull-down device connected"]
     #[inline(always)]
-    pub fn const_0001(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_0001)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE2)
     }
     #[doc = "Direct input, Input pull-up device connected"]
     #[inline(always)]
-    pub fn const_0010(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_0010)
+    pub fn value3(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE3)
     }
     #[doc = "Push-pull HIB Control output"]
     #[inline(always)]
-    pub fn const_1000(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_1000)
+    pub fn value4(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE4)
     }
     #[doc = "Push-pull WDT service output"]
     #[inline(always)]
-    pub fn const_1001(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_1001)
+    pub fn value5(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE5)
     }
     #[doc = "Push-pull GPIO output"]
     #[inline(always)]
-    pub fn const_1010(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_1010)
+    pub fn value6(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE6)
     }
     #[doc = "Open-drain HIB Control output"]
     #[inline(always)]
-    pub fn const_1100(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_1100)
+    pub fn value7(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE7)
     }
     #[doc = "Open-drain WDT service output"]
     #[inline(always)]
-    pub fn const_1101(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_1101)
+    pub fn value8(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE8)
     }
     #[doc = "Open-drain GPIO output"]
     #[inline(always)]
-    pub fn const_1110(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_1110)
-    }
-    #[doc = "#1111"]
-    #[inline(always)]
-    pub fn const_1111(self) -> &'a mut W {
-        self.variant(HIBIO0SEL_A::CONST_1111)
+    pub fn value9(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE9)
     }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
@@ -1131,25 +1118,23 @@ impl<'a> HIBIO0SEL_W<'a> {
 #[repr(u8)]
 pub enum HIBIO1SEL_A {
     #[doc = "0: Direct input, No input pull device connected"]
-    CONST_0000 = 0,
+    VALUE1 = 0,
     #[doc = "1: Direct input, Input pull-down device connected"]
-    CONST_0001 = 1,
+    VALUE2 = 1,
     #[doc = "2: Direct input, Input pull-up device connected"]
-    CONST_0010 = 2,
+    VALUE3 = 2,
     #[doc = "8: Push-pull HIB Control output"]
-    CONST_1000 = 8,
+    VALUE4 = 8,
     #[doc = "9: Push-pull WDT service output"]
-    CONST_1001 = 9,
+    VALUE5 = 9,
     #[doc = "10: Push-pull GPIO output"]
-    CONST_1010 = 10,
+    VALUE6 = 10,
     #[doc = "12: Open-drain HIB Control output"]
-    CONST_1100 = 12,
+    VALUE7 = 12,
     #[doc = "13: Open-drain WDT service output"]
-    CONST_1101 = 13,
+    VALUE8 = 13,
     #[doc = "14: Open-drain GPIO output"]
-    CONST_1110 = 14,
-    #[doc = "15: #1111"]
-    CONST_1111 = 15,
+    VALUE9 = 14,
 }
 impl From<HIBIO1SEL_A> for u8 {
     #[inline(always)]
@@ -1167,68 +1152,62 @@ impl HIBIO1SEL_R {
     #[inline(always)]
     pub fn variant(&self) -> Option<HIBIO1SEL_A> {
         match self.bits {
-            0 => Some(HIBIO1SEL_A::CONST_0000),
-            1 => Some(HIBIO1SEL_A::CONST_0001),
-            2 => Some(HIBIO1SEL_A::CONST_0010),
-            8 => Some(HIBIO1SEL_A::CONST_1000),
-            9 => Some(HIBIO1SEL_A::CONST_1001),
-            10 => Some(HIBIO1SEL_A::CONST_1010),
-            12 => Some(HIBIO1SEL_A::CONST_1100),
-            13 => Some(HIBIO1SEL_A::CONST_1101),
-            14 => Some(HIBIO1SEL_A::CONST_1110),
-            15 => Some(HIBIO1SEL_A::CONST_1111),
+            0 => Some(HIBIO1SEL_A::VALUE1),
+            1 => Some(HIBIO1SEL_A::VALUE2),
+            2 => Some(HIBIO1SEL_A::VALUE3),
+            8 => Some(HIBIO1SEL_A::VALUE4),
+            9 => Some(HIBIO1SEL_A::VALUE5),
+            10 => Some(HIBIO1SEL_A::VALUE6),
+            12 => Some(HIBIO1SEL_A::VALUE7),
+            13 => Some(HIBIO1SEL_A::VALUE8),
+            14 => Some(HIBIO1SEL_A::VALUE9),
             _ => None,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0000`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0000(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_0000
+    pub fn is_value1(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_0001`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_0001(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_0001
+    pub fn is_value2(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE2
     }
-    #[doc = "Checks if the value of the field is `CONST_0010`"]
+    #[doc = "Checks if the value of the field is `VALUE3`"]
     #[inline(always)]
-    pub fn is_const_0010(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_0010
+    pub fn is_value3(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE3
     }
-    #[doc = "Checks if the value of the field is `CONST_1000`"]
+    #[doc = "Checks if the value of the field is `VALUE4`"]
     #[inline(always)]
-    pub fn is_const_1000(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_1000
+    pub fn is_value4(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE4
     }
-    #[doc = "Checks if the value of the field is `CONST_1001`"]
+    #[doc = "Checks if the value of the field is `VALUE5`"]
     #[inline(always)]
-    pub fn is_const_1001(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_1001
+    pub fn is_value5(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE5
     }
-    #[doc = "Checks if the value of the field is `CONST_1010`"]
+    #[doc = "Checks if the value of the field is `VALUE6`"]
     #[inline(always)]
-    pub fn is_const_1010(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_1010
+    pub fn is_value6(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE6
     }
-    #[doc = "Checks if the value of the field is `CONST_1100`"]
+    #[doc = "Checks if the value of the field is `VALUE7`"]
     #[inline(always)]
-    pub fn is_const_1100(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_1100
+    pub fn is_value7(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE7
     }
-    #[doc = "Checks if the value of the field is `CONST_1101`"]
+    #[doc = "Checks if the value of the field is `VALUE8`"]
     #[inline(always)]
-    pub fn is_const_1101(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_1101
+    pub fn is_value8(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE8
     }
-    #[doc = "Checks if the value of the field is `CONST_1110`"]
+    #[doc = "Checks if the value of the field is `VALUE9`"]
     #[inline(always)]
-    pub fn is_const_1110(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_1110
-    }
-    #[doc = "Checks if the value of the field is `CONST_1111`"]
-    #[inline(always)]
-    pub fn is_const_1111(&self) -> bool {
-        **self == HIBIO1SEL_A::CONST_1111
+    pub fn is_value9(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE9
     }
 }
 impl core::ops::Deref for HIBIO1SEL_R {
@@ -1250,53 +1229,48 @@ impl<'a> HIBIO1SEL_W<'a> {
     }
     #[doc = "Direct input, No input pull device connected"]
     #[inline(always)]
-    pub fn const_0000(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_0000)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE1)
     }
     #[doc = "Direct input, Input pull-down device connected"]
     #[inline(always)]
-    pub fn const_0001(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_0001)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE2)
     }
     #[doc = "Direct input, Input pull-up device connected"]
     #[inline(always)]
-    pub fn const_0010(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_0010)
+    pub fn value3(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE3)
     }
     #[doc = "Push-pull HIB Control output"]
     #[inline(always)]
-    pub fn const_1000(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_1000)
+    pub fn value4(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE4)
     }
     #[doc = "Push-pull WDT service output"]
     #[inline(always)]
-    pub fn const_1001(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_1001)
+    pub fn value5(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE5)
     }
     #[doc = "Push-pull GPIO output"]
     #[inline(always)]
-    pub fn const_1010(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_1010)
+    pub fn value6(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE6)
     }
     #[doc = "Open-drain HIB Control output"]
     #[inline(always)]
-    pub fn const_1100(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_1100)
+    pub fn value7(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE7)
     }
     #[doc = "Open-drain WDT service output"]
     #[inline(always)]
-    pub fn const_1101(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_1101)
+    pub fn value8(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE8)
     }
     #[doc = "Open-drain GPIO output"]
     #[inline(always)]
-    pub fn const_1110(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_1110)
-    }
-    #[doc = "#1111"]
-    #[inline(always)]
-    pub fn const_1111(self) -> &'a mut W {
-        self.variant(HIBIO1SEL_A::CONST_1111)
+    pub fn value9(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE9)
     }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
