@@ -17,9 +17,9 @@ impl From<crate::R<HDSTAT_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum EPEV_A {
     #[doc = "0: Wake-up on positive edge pin event inactive"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Wake-up on positive edge pin event active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<EPEV_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl EPEV_R {
     #[inline(always)]
     pub fn variant(&self) -> EPEV_A {
         match self.bits {
-            false => EPEV_A::CONST_0,
-            true => EPEV_A::CONST_1,
+            false => EPEV_A::VALUE1,
+            true => EPEV_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == EPEV_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == EPEV_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == EPEV_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == EPEV_A::VALUE2
     }
 }
 impl core::ops::Deref for EPEV_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for EPEV_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ENEV_A {
     #[doc = "0: Wake-up on negative edge pin event inactive"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Wake-up on negative edge pin event active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ENEV_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl ENEV_R {
     #[inline(always)]
     pub fn variant(&self) -> ENEV_A {
         match self.bits {
-            false => ENEV_A::CONST_0,
-            true => ENEV_A::CONST_1,
+            false => ENEV_A::VALUE1,
+            true => ENEV_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ENEV_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ENEV_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ENEV_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ENEV_A::VALUE2
     }
 }
 impl core::ops::Deref for ENEV_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for ENEV_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTCEV_A {
     #[doc = "0: Wake-up on RTC event inactive"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Wake-up on RTC event active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTCEV_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl RTCEV_R {
     #[inline(always)]
     pub fn variant(&self) -> RTCEV_A {
         match self.bits {
-            false => RTCEV_A::CONST_0,
-            true => RTCEV_A::CONST_1,
+            false => RTCEV_A::VALUE1,
+            true => RTCEV_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTCEV_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTCEV_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTCEV_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTCEV_A::VALUE2
     }
 }
 impl core::ops::Deref for RTCEV_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for RTCEV_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ULPWDG_A {
     #[doc = "0: Watchdog alarm did not occur"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Watchdog alarm occurred"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ULPWDG_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl ULPWDG_R {
     #[inline(always)]
     pub fn variant(&self) -> ULPWDG_A {
         match self.bits {
-            false => ULPWDG_A::CONST_0,
-            true => ULPWDG_A::CONST_1,
+            false => ULPWDG_A::VALUE1,
+            true => ULPWDG_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ULPWDG_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ULPWDG_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ULPWDG_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ULPWDG_A::VALUE2
     }
 }
 impl core::ops::Deref for ULPWDG_R {
@@ -201,9 +201,9 @@ impl core::ops::Deref for ULPWDG_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HIBNOUT_A {
     #[doc = "0: Hibernate not driven active to pads"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Hibernate driven active to pads"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HIBNOUT_A> for bool {
     #[inline(always)]
@@ -221,19 +221,19 @@ impl HIBNOUT_R {
     #[inline(always)]
     pub fn variant(&self) -> HIBNOUT_A {
         match self.bits {
-            false => HIBNOUT_A::CONST_0,
-            true => HIBNOUT_A::CONST_1,
+            false => HIBNOUT_A::VALUE1,
+            true => HIBNOUT_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HIBNOUT_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HIBNOUT_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HIBNOUT_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HIBNOUT_A::VALUE2
     }
 }
 impl core::ops::Deref for HIBNOUT_R {
