@@ -23,9 +23,9 @@ impl From<crate::W<SRCLR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PRWARN_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PRWARN_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> PRWARN_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PRWARN_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PRWARN_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PRWARN_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PRWARN_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> PRWARN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PI_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PI_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> PI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PI_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PI_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PI_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PI_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> PI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum AI_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<AI_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> AI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(AI_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(AI_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(AI_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(AI_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -176,9 +176,9 @@ impl<'a> AI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DLROVR_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DLROVR_AW> for bool {
     #[inline(always)]
@@ -198,13 +198,13 @@ impl<'a> DLROVR_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(DLROVR_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DLROVR_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(DLROVR_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DLROVR_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -227,9 +227,9 @@ impl<'a> DLROVR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCLR_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDCLR_AW> for bool {
     #[inline(always)]
@@ -249,13 +249,13 @@ impl<'a> HDCLR_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HDCLR_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HDCLR_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HDCLR_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HDCLR_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -278,9 +278,9 @@ impl<'a> HDCLR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDSET_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDSET_AW> for bool {
     #[inline(always)]
@@ -300,13 +300,13 @@ impl<'a> HDSET_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HDSET_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HDSET_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HDSET_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HDSET_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -329,9 +329,9 @@ impl<'a> HDSET_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCR_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDCR_AW> for bool {
     #[inline(always)]
@@ -351,13 +351,13 @@ impl<'a> HDCR_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HDCR_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HDCR_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HDCR_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HDCR_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -380,9 +380,9 @@ impl<'a> HDCR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCSICTRL_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<OSCSICTRL_AW> for bool {
     #[inline(always)]
@@ -402,13 +402,13 @@ impl<'a> OSCSICTRL_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(OSCSICTRL_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(OSCSICTRL_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(OSCSICTRL_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(OSCSICTRL_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -431,9 +431,9 @@ impl<'a> OSCSICTRL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCULCTRL_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<OSCULCTRL_AW> for bool {
     #[inline(always)]
@@ -453,13 +453,13 @@ impl<'a> OSCULCTRL_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(OSCULCTRL_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(OSCULCTRL_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(OSCULCTRL_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(OSCULCTRL_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -482,9 +482,9 @@ impl<'a> OSCULCTRL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_CTR_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_CTR_AW> for bool {
     #[inline(always)]
@@ -504,13 +504,13 @@ impl<'a> RTC_CTR_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_CTR_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_CTR_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_CTR_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_CTR_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -533,9 +533,9 @@ impl<'a> RTC_CTR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM0_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_ATIM0_AW> for bool {
     #[inline(always)]
@@ -555,13 +555,13 @@ impl<'a> RTC_ATIM0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_ATIM0_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_ATIM0_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_ATIM0_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_ATIM0_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -584,9 +584,9 @@ impl<'a> RTC_ATIM0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM1_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_ATIM1_AW> for bool {
     #[inline(always)]
@@ -606,13 +606,13 @@ impl<'a> RTC_ATIM1_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_ATIM1_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_ATIM1_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_ATIM1_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_ATIM1_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -635,9 +635,9 @@ impl<'a> RTC_ATIM1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM0_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_TIM0_AW> for bool {
     #[inline(always)]
@@ -657,13 +657,13 @@ impl<'a> RTC_TIM0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_TIM0_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_TIM0_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_TIM0_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_TIM0_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -686,9 +686,9 @@ impl<'a> RTC_TIM0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM1_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_TIM1_AW> for bool {
     #[inline(always)]
@@ -708,13 +708,13 @@ impl<'a> RTC_TIM1_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_TIM1_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_TIM1_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_TIM1_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_TIM1_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -737,9 +737,9 @@ impl<'a> RTC_TIM1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RMX_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear the status bit"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RMX_AW> for bool {
     #[inline(always)]
@@ -759,13 +759,13 @@ impl<'a> RMX_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RMX_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RMX_AW::VALUE1)
     }
     #[doc = "Clear the status bit"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RMX_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RMX_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
