@@ -17,9 +17,9 @@ impl From<crate::R<SRSTAT_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PRWARN_A {
     #[doc = "0: Inactive"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PRWARN_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl PRWARN_R {
     #[inline(always)]
     pub fn variant(&self) -> PRWARN_A {
         match self.bits {
-            false => PRWARN_A::CONST_0,
-            true => PRWARN_A::CONST_1,
+            false => PRWARN_A::VALUE1,
+            true => PRWARN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PRWARN_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PRWARN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PRWARN_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PRWARN_A::VALUE2
     }
 }
 impl core::ops::Deref for PRWARN_R {
@@ -105,9 +105,9 @@ impl core::ops::Deref for DLROVR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCLR_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDCLR_A> for bool {
     #[inline(always)]
@@ -125,19 +125,19 @@ impl HDCLR_R {
     #[inline(always)]
     pub fn variant(&self) -> HDCLR_A {
         match self.bits {
-            false => HDCLR_A::CONST_0,
-            true => HDCLR_A::CONST_1,
+            false => HDCLR_A::VALUE1,
+            true => HDCLR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDCLR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDCLR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDCLR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDCLR_A::VALUE2
     }
 }
 impl core::ops::Deref for HDCLR_R {
@@ -151,9 +151,9 @@ impl core::ops::Deref for HDCLR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDSET_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDSET_A> for bool {
     #[inline(always)]
@@ -171,19 +171,19 @@ impl HDSET_R {
     #[inline(always)]
     pub fn variant(&self) -> HDSET_A {
         match self.bits {
-            false => HDSET_A::CONST_0,
-            true => HDSET_A::CONST_1,
+            false => HDSET_A::VALUE1,
+            true => HDSET_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDSET_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDSET_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDSET_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDSET_A::VALUE2
     }
 }
 impl core::ops::Deref for HDSET_R {
@@ -197,9 +197,9 @@ impl core::ops::Deref for HDSET_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCR_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDCR_A> for bool {
     #[inline(always)]
@@ -217,19 +217,19 @@ impl HDCR_R {
     #[inline(always)]
     pub fn variant(&self) -> HDCR_A {
         match self.bits {
-            false => HDCR_A::CONST_0,
-            true => HDCR_A::CONST_1,
+            false => HDCR_A::VALUE1,
+            true => HDCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDCR_A::VALUE2
     }
 }
 impl core::ops::Deref for HDCR_R {
@@ -243,9 +243,9 @@ impl core::ops::Deref for HDCR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCSICTRL_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<OSCSICTRL_A> for bool {
     #[inline(always)]
@@ -263,19 +263,19 @@ impl OSCSICTRL_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCSICTRL_A {
         match self.bits {
-            false => OSCSICTRL_A::CONST_0,
-            true => OSCSICTRL_A::CONST_1,
+            false => OSCSICTRL_A::VALUE1,
+            true => OSCSICTRL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == OSCSICTRL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == OSCSICTRL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == OSCSICTRL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == OSCSICTRL_A::VALUE2
     }
 }
 impl core::ops::Deref for OSCSICTRL_R {
@@ -289,9 +289,9 @@ impl core::ops::Deref for OSCSICTRL_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCULCTRL_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<OSCULCTRL_A> for bool {
     #[inline(always)]
@@ -309,19 +309,19 @@ impl OSCULCTRL_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCULCTRL_A {
         match self.bits {
-            false => OSCULCTRL_A::CONST_0,
-            true => OSCULCTRL_A::CONST_1,
+            false => OSCULCTRL_A::VALUE1,
+            true => OSCULCTRL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == OSCULCTRL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == OSCULCTRL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == OSCULCTRL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == OSCULCTRL_A::VALUE2
     }
 }
 impl core::ops::Deref for OSCULCTRL_R {
@@ -335,9 +335,9 @@ impl core::ops::Deref for OSCULCTRL_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_CTR_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_CTR_A> for bool {
     #[inline(always)]
@@ -355,19 +355,19 @@ impl RTC_CTR_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_CTR_A {
         match self.bits {
-            false => RTC_CTR_A::CONST_0,
-            true => RTC_CTR_A::CONST_1,
+            false => RTC_CTR_A::VALUE1,
+            true => RTC_CTR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_CTR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_CTR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_CTR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_CTR_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_CTR_R {
@@ -381,9 +381,9 @@ impl core::ops::Deref for RTC_CTR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM0_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_ATIM0_A> for bool {
     #[inline(always)]
@@ -401,19 +401,19 @@ impl RTC_ATIM0_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_ATIM0_A {
         match self.bits {
-            false => RTC_ATIM0_A::CONST_0,
-            true => RTC_ATIM0_A::CONST_1,
+            false => RTC_ATIM0_A::VALUE1,
+            true => RTC_ATIM0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_ATIM0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_ATIM0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_ATIM0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_ATIM0_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_ATIM0_R {
@@ -427,9 +427,9 @@ impl core::ops::Deref for RTC_ATIM0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM1_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_ATIM1_A> for bool {
     #[inline(always)]
@@ -447,19 +447,19 @@ impl RTC_ATIM1_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_ATIM1_A {
         match self.bits {
-            false => RTC_ATIM1_A::CONST_0,
-            true => RTC_ATIM1_A::CONST_1,
+            false => RTC_ATIM1_A::VALUE1,
+            true => RTC_ATIM1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_ATIM1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_ATIM1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_ATIM1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_ATIM1_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_ATIM1_R {
@@ -473,9 +473,9 @@ impl core::ops::Deref for RTC_ATIM1_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM0_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_TIM0_A> for bool {
     #[inline(always)]
@@ -493,19 +493,19 @@ impl RTC_TIM0_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_TIM0_A {
         match self.bits {
-            false => RTC_TIM0_A::CONST_0,
-            true => RTC_TIM0_A::CONST_1,
+            false => RTC_TIM0_A::VALUE1,
+            true => RTC_TIM0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_TIM0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_TIM0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_TIM0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_TIM0_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_TIM0_R {
@@ -519,9 +519,9 @@ impl core::ops::Deref for RTC_TIM0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM1_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_TIM1_A> for bool {
     #[inline(always)]
@@ -539,19 +539,19 @@ impl RTC_TIM1_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_TIM1_A {
         match self.bits {
-            false => RTC_TIM1_A::CONST_0,
-            true => RTC_TIM1_A::CONST_1,
+            false => RTC_TIM1_A::VALUE1,
+            true => RTC_TIM1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_TIM1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_TIM1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_TIM1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_TIM1_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_TIM1_R {
@@ -565,9 +565,9 @@ impl core::ops::Deref for RTC_TIM1_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RMX_A {
     #[doc = "0: Not updated"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Update completed"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RMX_A> for bool {
     #[inline(always)]
@@ -585,19 +585,19 @@ impl RMX_R {
     #[inline(always)]
     pub fn variant(&self) -> RMX_A {
         match self.bits {
-            false => RMX_A::CONST_0,
-            true => RMX_A::CONST_1,
+            false => RMX_A::VALUE1,
+            true => RMX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RMX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RMX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RMX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RMX_A::VALUE2
     }
 }
 impl core::ops::Deref for RMX_R {
