@@ -38,9 +38,9 @@ impl From<crate::W<PEEN_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENPS_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENPS_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl PEENPS_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENPS_A {
         match self.bits {
-            false => PEENPS_A::CONST_0,
-            true => PEENPS_A::CONST_1,
+            false => PEENPS_A::VALUE1,
+            true => PEENPS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENPS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENPS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENPS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENPS_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENPS_R {
@@ -92,13 +92,13 @@ impl<'a> PEENPS_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENPS_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENPS_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENPS_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENPS_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> PEENPS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENDS1_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENDS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl PEENDS1_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENDS1_A {
         match self.bits {
-            false => PEENDS1_A::CONST_0,
-            true => PEENDS1_A::CONST_1,
+            false => PEENDS1_A::VALUE1,
+            true => PEENDS1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENDS1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENDS1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENDS1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENDS1_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENDS1_R {
@@ -175,13 +175,13 @@ impl<'a> PEENDS1_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENDS1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENDS1_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENDS1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENDS1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -200,13 +200,96 @@ impl<'a> PEENDS1_W<'a> {
         self.w
     }
 }
+#[doc = "Parity Error Enable for DSRAM2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PEENDS2_A {
+    #[doc = "0: Disabled"]
+    VALUE1 = 0,
+    #[doc = "1: Enabled"]
+    VALUE2 = 1,
+}
+impl From<PEENDS2_A> for bool {
+    #[inline(always)]
+    fn from(variant: PEENDS2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PEENDS2` reader - Parity Error Enable for DSRAM2"]
+pub struct PEENDS2_R(crate::FieldReader<bool, PEENDS2_A>);
+impl PEENDS2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PEENDS2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PEENDS2_A {
+        match self.bits {
+            false => PEENDS2_A::VALUE1,
+            true => PEENDS2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == PEENDS2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == PEENDS2_A::VALUE2
+    }
+}
+impl core::ops::Deref for PEENDS2_R {
+    type Target = crate::FieldReader<bool, PEENDS2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PEENDS2` writer - Parity Error Enable for DSRAM2"]
+pub struct PEENDS2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PEENDS2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PEENDS2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disabled"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENDS2_A::VALUE1)
+    }
+    #[doc = "Enabled"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENDS2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w
+    }
+}
 #[doc = "Parity Error Enable for USIC0 Memory\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENU0_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENU0_A> for bool {
     #[inline(always)]
@@ -224,19 +307,19 @@ impl PEENU0_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENU0_A {
         match self.bits {
-            false => PEENU0_A::CONST_0,
-            true => PEENU0_A::CONST_1,
+            false => PEENU0_A::VALUE1,
+            true => PEENU0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENU0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENU0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENU0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENU0_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENU0_R {
@@ -258,13 +341,13 @@ impl<'a> PEENU0_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENU0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENU0_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENU0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENU0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +370,9 @@ impl<'a> PEENU0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENU1_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENU1_A> for bool {
     #[inline(always)]
@@ -307,19 +390,19 @@ impl PEENU1_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENU1_A {
         match self.bits {
-            false => PEENU1_A::CONST_0,
-            true => PEENU1_A::CONST_1,
+            false => PEENU1_A::VALUE1,
+            true => PEENU1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENU1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENU1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENU1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENU1_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENU1_R {
@@ -341,13 +424,13 @@ impl<'a> PEENU1_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENU1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENU1_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENU1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENU1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -366,13 +449,96 @@ impl<'a> PEENU1_W<'a> {
         self.w
     }
 }
+#[doc = "Parity Error Enable for USIC2 Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PEENU2_A {
+    #[doc = "0: Disabled"]
+    VALUE1 = 0,
+    #[doc = "1: Enabled"]
+    VALUE2 = 1,
+}
+impl From<PEENU2_A> for bool {
+    #[inline(always)]
+    fn from(variant: PEENU2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PEENU2` reader - Parity Error Enable for USIC2 Memory"]
+pub struct PEENU2_R(crate::FieldReader<bool, PEENU2_A>);
+impl PEENU2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PEENU2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PEENU2_A {
+        match self.bits {
+            false => PEENU2_A::VALUE1,
+            true => PEENU2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == PEENU2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == PEENU2_A::VALUE2
+    }
+}
+impl core::ops::Deref for PEENU2_R {
+    type Target = crate::FieldReader<bool, PEENU2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PEENU2` writer - Parity Error Enable for USIC2 Memory"]
+pub struct PEENU2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PEENU2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PEENU2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disabled"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENU2_A::VALUE1)
+    }
+    #[doc = "Enabled"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENU2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w
+    }
+}
 #[doc = "Parity Error Enable for MultiCAN Memory\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENMC_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENMC_A> for bool {
     #[inline(always)]
@@ -390,19 +556,19 @@ impl PEENMC_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENMC_A {
         match self.bits {
-            false => PEENMC_A::CONST_0,
-            true => PEENMC_A::CONST_1,
+            false => PEENMC_A::VALUE1,
+            true => PEENMC_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENMC_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENMC_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENMC_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENMC_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENMC_R {
@@ -424,13 +590,13 @@ impl<'a> PEENMC_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENMC_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENMC_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENMC_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENMC_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +619,9 @@ impl<'a> PEENMC_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENPPRF_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENPPRF_A> for bool {
     #[inline(always)]
@@ -473,19 +639,19 @@ impl PEENPPRF_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENPPRF_A {
         match self.bits {
-            false => PEENPPRF_A::CONST_0,
-            true => PEENPPRF_A::CONST_1,
+            false => PEENPPRF_A::VALUE1,
+            true => PEENPPRF_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENPPRF_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENPPRF_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENPPRF_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENPPRF_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENPPRF_R {
@@ -507,13 +673,13 @@ impl<'a> PEENPPRF_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENPPRF_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENPPRF_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENPPRF_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENPPRF_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +702,9 @@ impl<'a> PEENPPRF_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENUSB_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENUSB_A> for bool {
     #[inline(always)]
@@ -556,19 +722,19 @@ impl PEENUSB_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENUSB_A {
         match self.bits {
-            false => PEENUSB_A::CONST_0,
-            true => PEENUSB_A::CONST_1,
+            false => PEENUSB_A::VALUE1,
+            true => PEENUSB_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENUSB_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENUSB_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENUSB_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENUSB_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENUSB_R {
@@ -590,13 +756,13 @@ impl<'a> PEENUSB_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENUSB_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENUSB_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENUSB_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENUSB_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +785,9 @@ impl<'a> PEENUSB_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENETH0TX_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENETH0TX_A> for bool {
     #[inline(always)]
@@ -639,19 +805,19 @@ impl PEENETH0TX_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENETH0TX_A {
         match self.bits {
-            false => PEENETH0TX_A::CONST_0,
-            true => PEENETH0TX_A::CONST_1,
+            false => PEENETH0TX_A::VALUE1,
+            true => PEENETH0TX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENETH0TX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENETH0TX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENETH0TX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENETH0TX_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENETH0TX_R {
@@ -673,13 +839,13 @@ impl<'a> PEENETH0TX_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENETH0TX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENETH0TX_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENETH0TX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENETH0TX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +868,9 @@ impl<'a> PEENETH0TX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENETH0RX_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENETH0RX_A> for bool {
     #[inline(always)]
@@ -722,19 +888,19 @@ impl PEENETH0RX_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENETH0RX_A {
         match self.bits {
-            false => PEENETH0RX_A::CONST_0,
-            true => PEENETH0RX_A::CONST_1,
+            false => PEENETH0RX_A::VALUE1,
+            true => PEENETH0RX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENETH0RX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENETH0RX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENETH0RX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENETH0RX_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENETH0RX_R {
@@ -756,13 +922,13 @@ impl<'a> PEENETH0RX_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENETH0RX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENETH0RX_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENETH0RX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENETH0RX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +951,9 @@ impl<'a> PEENETH0RX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENSD0_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENSD0_A> for bool {
     #[inline(always)]
@@ -805,19 +971,19 @@ impl PEENSD0_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENSD0_A {
         match self.bits {
-            false => PEENSD0_A::CONST_0,
-            true => PEENSD0_A::CONST_1,
+            false => PEENSD0_A::VALUE1,
+            true => PEENSD0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENSD0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENSD0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENSD0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENSD0_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENSD0_R {
@@ -839,13 +1005,13 @@ impl<'a> PEENSD0_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENSD0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENSD0_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENSD0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENSD0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +1034,9 @@ impl<'a> PEENSD0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEENSD1_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEENSD1_A> for bool {
     #[inline(always)]
@@ -888,19 +1054,19 @@ impl PEENSD1_R {
     #[inline(always)]
     pub fn variant(&self) -> PEENSD1_A {
         match self.bits {
-            false => PEENSD1_A::CONST_0,
-            true => PEENSD1_A::CONST_1,
+            false => PEENSD1_A::VALUE1,
+            true => PEENSD1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENSD1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEENSD1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENSD1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEENSD1_A::VALUE2
     }
 }
 impl core::ops::Deref for PEENSD1_R {
@@ -922,13 +1088,13 @@ impl<'a> PEENSD1_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENSD1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEENSD1_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENSD1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEENSD1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -947,89 +1113,6 @@ impl<'a> PEENSD1_W<'a> {
         self.w
     }
 }
-#[doc = "Parity Error Enable for ECAT0 Memory\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum PEENECAT0_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
-}
-impl From<PEENECAT0_A> for bool {
-    #[inline(always)]
-    fn from(variant: PEENECAT0_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `PEENECAT0` reader - Parity Error Enable for ECAT0 Memory"]
-pub struct PEENECAT0_R(crate::FieldReader<bool, PEENECAT0_A>);
-impl PEENECAT0_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        PEENECAT0_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> PEENECAT0_A {
-        match self.bits {
-            false => PEENECAT0_A::CONST_0,
-            true => PEENECAT0_A::CONST_1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
-    #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEENECAT0_A::CONST_0
-    }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
-    #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEENECAT0_A::CONST_1
-    }
-}
-impl core::ops::Deref for PEENECAT0_R {
-    type Target = crate::FieldReader<bool, PEENECAT0_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `PEENECAT0` writer - Parity Error Enable for ECAT0 Memory"]
-pub struct PEENECAT0_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PEENECAT0_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PEENECAT0_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "Disabled"]
-    #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEENECAT0_A::CONST_0)
-    }
-    #[doc = "Enabled"]
-    #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEENECAT0_A::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
-        self.w
-    }
-}
 impl R {
     #[doc = "Bit 0 - Parity Error Enable for PSRAM"]
     #[inline(always)]
@@ -1041,6 +1124,11 @@ impl R {
     pub fn peends1(&self) -> PEENDS1_R {
         PEENDS1_R::new(((self.bits >> 1) & 0x01) != 0)
     }
+    #[doc = "Bit 2 - Parity Error Enable for DSRAM2"]
+    #[inline(always)]
+    pub fn peends2(&self) -> PEENDS2_R {
+        PEENDS2_R::new(((self.bits >> 2) & 0x01) != 0)
+    }
     #[doc = "Bit 8 - Parity Error Enable for USIC0 Memory"]
     #[inline(always)]
     pub fn peenu0(&self) -> PEENU0_R {
@@ -1051,6 +1139,11 @@ impl R {
     pub fn peenu1(&self) -> PEENU1_R {
         PEENU1_R::new(((self.bits >> 9) & 0x01) != 0)
     }
+    #[doc = "Bit 10 - Parity Error Enable for USIC2 Memory"]
+    #[inline(always)]
+    pub fn peenu2(&self) -> PEENU2_R {
+        PEENU2_R::new(((self.bits >> 10) & 0x01) != 0)
+    }
     #[doc = "Bit 12 - Parity Error Enable for MultiCAN Memory"]
     #[inline(always)]
     pub fn peenmc(&self) -> PEENMC_R {
@@ -1086,11 +1179,6 @@ impl R {
     pub fn peensd1(&self) -> PEENSD1_R {
         PEENSD1_R::new(((self.bits >> 20) & 0x01) != 0)
     }
-    #[doc = "Bit 24 - Parity Error Enable for ECAT0 Memory"]
-    #[inline(always)]
-    pub fn peenecat0(&self) -> PEENECAT0_R {
-        PEENECAT0_R::new(((self.bits >> 24) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bit 0 - Parity Error Enable for PSRAM"]
@@ -1103,6 +1191,11 @@ impl W {
     pub fn peends1(&mut self) -> PEENDS1_W {
         PEENDS1_W { w: self }
     }
+    #[doc = "Bit 2 - Parity Error Enable for DSRAM2"]
+    #[inline(always)]
+    pub fn peends2(&mut self) -> PEENDS2_W {
+        PEENDS2_W { w: self }
+    }
     #[doc = "Bit 8 - Parity Error Enable for USIC0 Memory"]
     #[inline(always)]
     pub fn peenu0(&mut self) -> PEENU0_W {
@@ -1113,6 +1206,11 @@ impl W {
     pub fn peenu1(&mut self) -> PEENU1_W {
         PEENU1_W { w: self }
     }
+    #[doc = "Bit 10 - Parity Error Enable for USIC2 Memory"]
+    #[inline(always)]
+    pub fn peenu2(&mut self) -> PEENU2_W {
+        PEENU2_W { w: self }
+    }
     #[doc = "Bit 12 - Parity Error Enable for MultiCAN Memory"]
     #[inline(always)]
     pub fn peenmc(&mut self) -> PEENMC_W {
@@ -1148,11 +1246,6 @@ impl W {
     pub fn peensd1(&mut self) -> PEENSD1_W {
         PEENSD1_W { w: self }
     }
-    #[doc = "Bit 24 - Parity Error Enable for ECAT0 Memory"]
-    #[inline(always)]
-    pub fn peenecat0(&mut self) -> PEENECAT0_W {
-        PEENECAT0_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
