@@ -38,9 +38,9 @@ impl From<crate::W<PEFLAG_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFPS_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEFPS_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl PEFPS_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFPS_A {
         match self.bits {
-            false => PEFPS_A::CONST_0,
-            true => PEFPS_A::CONST_1,
+            false => PEFPS_A::VALUE1,
+            true => PEFPS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEFPS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEFPS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEFPS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEFPS_A::VALUE2
     }
 }
 impl core::ops::Deref for PEFPS_R {
@@ -92,13 +92,13 @@ impl<'a> PEFPS_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEFPS_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEFPS_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEFPS_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEFPS_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> PEFPS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFDS1_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEFDS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl PEFDS1_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFDS1_A {
         match self.bits {
-            false => PEFDS1_A::CONST_0,
-            true => PEFDS1_A::CONST_1,
+            false => PEFDS1_A::VALUE1,
+            true => PEFDS1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEFDS1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEFDS1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEFDS1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEFDS1_A::VALUE2
     }
 }
 impl core::ops::Deref for PEFDS1_R {
@@ -175,13 +175,13 @@ impl<'a> PEFDS1_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEFDS1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEFDS1_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEFDS1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEFDS1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -200,13 +200,96 @@ impl<'a> PEFDS1_W<'a> {
         self.w
     }
 }
+#[doc = "Parity Error Flag for DSRAM2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PEFDS2_A {
+    #[doc = "0: No parity error detected"]
+    VALUE1 = 0,
+    #[doc = "1: Parity error detected"]
+    VALUE2 = 1,
+}
+impl From<PEFDS2_A> for bool {
+    #[inline(always)]
+    fn from(variant: PEFDS2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PEFDS2` reader - Parity Error Flag for DSRAM2"]
+pub struct PEFDS2_R(crate::FieldReader<bool, PEFDS2_A>);
+impl PEFDS2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PEFDS2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PEFDS2_A {
+        match self.bits {
+            false => PEFDS2_A::VALUE1,
+            true => PEFDS2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == PEFDS2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == PEFDS2_A::VALUE2
+    }
+}
+impl core::ops::Deref for PEFDS2_R {
+    type Target = crate::FieldReader<bool, PEFDS2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PEFDS2` writer - Parity Error Flag for DSRAM2"]
+pub struct PEFDS2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PEFDS2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PEFDS2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No parity error detected"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEFDS2_A::VALUE1)
+    }
+    #[doc = "Parity error detected"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEFDS2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w
+    }
+}
 #[doc = "Parity Error Flag for USIC0 Memory\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFU0_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEFU0_A> for bool {
     #[inline(always)]
@@ -224,19 +307,19 @@ impl PEFU0_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFU0_A {
         match self.bits {
-            false => PEFU0_A::CONST_0,
-            true => PEFU0_A::CONST_1,
+            false => PEFU0_A::VALUE1,
+            true => PEFU0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEFU0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEFU0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEFU0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEFU0_A::VALUE2
     }
 }
 impl core::ops::Deref for PEFU0_R {
@@ -258,13 +341,13 @@ impl<'a> PEFU0_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEFU0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEFU0_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEFU0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEFU0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +370,9 @@ impl<'a> PEFU0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFU1_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEFU1_A> for bool {
     #[inline(always)]
@@ -307,19 +390,19 @@ impl PEFU1_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFU1_A {
         match self.bits {
-            false => PEFU1_A::CONST_0,
-            true => PEFU1_A::CONST_1,
+            false => PEFU1_A::VALUE1,
+            true => PEFU1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEFU1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEFU1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEFU1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEFU1_A::VALUE2
     }
 }
 impl core::ops::Deref for PEFU1_R {
@@ -341,13 +424,13 @@ impl<'a> PEFU1_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEFU1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEFU1_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEFU1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEFU1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -366,13 +449,96 @@ impl<'a> PEFU1_W<'a> {
         self.w
     }
 }
+#[doc = "Parity Error Flag for USIC2 Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PEFU2_A {
+    #[doc = "0: No parity error detected"]
+    VALUE1 = 0,
+    #[doc = "1: Parity error detected"]
+    VALUE2 = 1,
+}
+impl From<PEFU2_A> for bool {
+    #[inline(always)]
+    fn from(variant: PEFU2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PEFU2` reader - Parity Error Flag for USIC2 Memory"]
+pub struct PEFU2_R(crate::FieldReader<bool, PEFU2_A>);
+impl PEFU2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PEFU2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PEFU2_A {
+        match self.bits {
+            false => PEFU2_A::VALUE1,
+            true => PEFU2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == PEFU2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == PEFU2_A::VALUE2
+    }
+}
+impl core::ops::Deref for PEFU2_R {
+    type Target = crate::FieldReader<bool, PEFU2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PEFU2` writer - Parity Error Flag for USIC2 Memory"]
+pub struct PEFU2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PEFU2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PEFU2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No parity error detected"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEFU2_A::VALUE1)
+    }
+    #[doc = "Parity error detected"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEFU2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w
+    }
+}
 #[doc = "Parity Error Flag for MultiCAN Memory\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFMC_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEFMC_A> for bool {
     #[inline(always)]
@@ -390,19 +556,19 @@ impl PEFMC_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFMC_A {
         match self.bits {
-            false => PEFMC_A::CONST_0,
-            true => PEFMC_A::CONST_1,
+            false => PEFMC_A::VALUE1,
+            true => PEFMC_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEFMC_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEFMC_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEFMC_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEFMC_A::VALUE2
     }
 }
 impl core::ops::Deref for PEFMC_R {
@@ -424,13 +590,13 @@ impl<'a> PEFMC_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEFMC_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEFMC_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEFMC_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEFMC_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +619,9 @@ impl<'a> PEFMC_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEFPPRF_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEFPPRF_A> for bool {
     #[inline(always)]
@@ -473,19 +639,19 @@ impl PEFPPRF_R {
     #[inline(always)]
     pub fn variant(&self) -> PEFPPRF_A {
         match self.bits {
-            false => PEFPPRF_A::CONST_0,
-            true => PEFPPRF_A::CONST_1,
+            false => PEFPPRF_A::VALUE1,
+            true => PEFPPRF_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEFPPRF_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEFPPRF_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEFPPRF_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEFPPRF_A::VALUE2
     }
 }
 impl core::ops::Deref for PEFPPRF_R {
@@ -507,13 +673,13 @@ impl<'a> PEFPPRF_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEFPPRF_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEFPPRF_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEFPPRF_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEFPPRF_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +702,9 @@ impl<'a> PEFPPRF_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEUSB_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEUSB_A> for bool {
     #[inline(always)]
@@ -556,19 +722,19 @@ impl PEUSB_R {
     #[inline(always)]
     pub fn variant(&self) -> PEUSB_A {
         match self.bits {
-            false => PEUSB_A::CONST_0,
-            true => PEUSB_A::CONST_1,
+            false => PEUSB_A::VALUE1,
+            true => PEUSB_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEUSB_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEUSB_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEUSB_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEUSB_A::VALUE2
     }
 }
 impl core::ops::Deref for PEUSB_R {
@@ -590,13 +756,13 @@ impl<'a> PEUSB_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEUSB_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEUSB_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEUSB_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEUSB_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +785,9 @@ impl<'a> PEUSB_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEETH0TX_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEETH0TX_A> for bool {
     #[inline(always)]
@@ -639,19 +805,19 @@ impl PEETH0TX_R {
     #[inline(always)]
     pub fn variant(&self) -> PEETH0TX_A {
         match self.bits {
-            false => PEETH0TX_A::CONST_0,
-            true => PEETH0TX_A::CONST_1,
+            false => PEETH0TX_A::VALUE1,
+            true => PEETH0TX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEETH0TX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEETH0TX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEETH0TX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEETH0TX_A::VALUE2
     }
 }
 impl core::ops::Deref for PEETH0TX_R {
@@ -673,13 +839,13 @@ impl<'a> PEETH0TX_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEETH0TX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEETH0TX_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEETH0TX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEETH0TX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +868,9 @@ impl<'a> PEETH0TX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PEETH0RX_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PEETH0RX_A> for bool {
     #[inline(always)]
@@ -722,19 +888,19 @@ impl PEETH0RX_R {
     #[inline(always)]
     pub fn variant(&self) -> PEETH0RX_A {
         match self.bits {
-            false => PEETH0RX_A::CONST_0,
-            true => PEETH0RX_A::CONST_1,
+            false => PEETH0RX_A::VALUE1,
+            true => PEETH0RX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEETH0RX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PEETH0RX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEETH0RX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PEETH0RX_A::VALUE2
     }
 }
 impl core::ops::Deref for PEETH0RX_R {
@@ -756,13 +922,13 @@ impl<'a> PEETH0RX_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEETH0RX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PEETH0RX_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEETH0RX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PEETH0RX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +951,9 @@ impl<'a> PEETH0RX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PESD0_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PESD0_A> for bool {
     #[inline(always)]
@@ -805,19 +971,19 @@ impl PESD0_R {
     #[inline(always)]
     pub fn variant(&self) -> PESD0_A {
         match self.bits {
-            false => PESD0_A::CONST_0,
-            true => PESD0_A::CONST_1,
+            false => PESD0_A::VALUE1,
+            true => PESD0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PESD0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PESD0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PESD0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PESD0_A::VALUE2
     }
 }
 impl core::ops::Deref for PESD0_R {
@@ -839,13 +1005,13 @@ impl<'a> PESD0_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PESD0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PESD0_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PESD0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PESD0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +1034,9 @@ impl<'a> PESD0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PESD1_A {
     #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PESD1_A> for bool {
     #[inline(always)]
@@ -888,19 +1054,19 @@ impl PESD1_R {
     #[inline(always)]
     pub fn variant(&self) -> PESD1_A {
         match self.bits {
-            false => PESD1_A::CONST_0,
-            true => PESD1_A::CONST_1,
+            false => PESD1_A::VALUE1,
+            true => PESD1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PESD1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PESD1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PESD1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PESD1_A::VALUE2
     }
 }
 impl core::ops::Deref for PESD1_R {
@@ -922,13 +1088,13 @@ impl<'a> PESD1_W<'a> {
     }
     #[doc = "No parity error detected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PESD1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PESD1_A::VALUE1)
     }
     #[doc = "Parity error detected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PESD1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PESD1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -947,89 +1113,6 @@ impl<'a> PESD1_W<'a> {
         self.w
     }
 }
-#[doc = "Parity Error Flag for ECAT0 Memory\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum PEECAT0_A {
-    #[doc = "0: No parity error detected"]
-    CONST_0 = 0,
-    #[doc = "1: Parity error detected"]
-    CONST_1 = 1,
-}
-impl From<PEECAT0_A> for bool {
-    #[inline(always)]
-    fn from(variant: PEECAT0_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `PEECAT0` reader - Parity Error Flag for ECAT0 Memory"]
-pub struct PEECAT0_R(crate::FieldReader<bool, PEECAT0_A>);
-impl PEECAT0_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        PEECAT0_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> PEECAT0_A {
-        match self.bits {
-            false => PEECAT0_A::CONST_0,
-            true => PEECAT0_A::CONST_1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
-    #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PEECAT0_A::CONST_0
-    }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
-    #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PEECAT0_A::CONST_1
-    }
-}
-impl core::ops::Deref for PEECAT0_R {
-    type Target = crate::FieldReader<bool, PEECAT0_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `PEECAT0` writer - Parity Error Flag for ECAT0 Memory"]
-pub struct PEECAT0_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PEECAT0_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PEECAT0_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No parity error detected"]
-    #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PEECAT0_A::CONST_0)
-    }
-    #[doc = "Parity error detected"]
-    #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PEECAT0_A::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
-        self.w
-    }
-}
 impl R {
     #[doc = "Bit 0 - Parity Error Flag for PSRAM"]
     #[inline(always)]
@@ -1041,6 +1124,11 @@ impl R {
     pub fn pefds1(&self) -> PEFDS1_R {
         PEFDS1_R::new(((self.bits >> 1) & 0x01) != 0)
     }
+    #[doc = "Bit 2 - Parity Error Flag for DSRAM2"]
+    #[inline(always)]
+    pub fn pefds2(&self) -> PEFDS2_R {
+        PEFDS2_R::new(((self.bits >> 2) & 0x01) != 0)
+    }
     #[doc = "Bit 8 - Parity Error Flag for USIC0 Memory"]
     #[inline(always)]
     pub fn pefu0(&self) -> PEFU0_R {
@@ -1051,6 +1139,11 @@ impl R {
     pub fn pefu1(&self) -> PEFU1_R {
         PEFU1_R::new(((self.bits >> 9) & 0x01) != 0)
     }
+    #[doc = "Bit 10 - Parity Error Flag for USIC2 Memory"]
+    #[inline(always)]
+    pub fn pefu2(&self) -> PEFU2_R {
+        PEFU2_R::new(((self.bits >> 10) & 0x01) != 0)
+    }
     #[doc = "Bit 12 - Parity Error Flag for MultiCAN Memory"]
     #[inline(always)]
     pub fn pefmc(&self) -> PEFMC_R {
@@ -1086,11 +1179,6 @@ impl R {
     pub fn pesd1(&self) -> PESD1_R {
         PESD1_R::new(((self.bits >> 20) & 0x01) != 0)
     }
-    #[doc = "Bit 24 - Parity Error Flag for ECAT0 Memory"]
-    #[inline(always)]
-    pub fn peecat0(&self) -> PEECAT0_R {
-        PEECAT0_R::new(((self.bits >> 24) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bit 0 - Parity Error Flag for PSRAM"]
@@ -1103,6 +1191,11 @@ impl W {
     pub fn pefds1(&mut self) -> PEFDS1_W {
         PEFDS1_W { w: self }
     }
+    #[doc = "Bit 2 - Parity Error Flag for DSRAM2"]
+    #[inline(always)]
+    pub fn pefds2(&mut self) -> PEFDS2_W {
+        PEFDS2_W { w: self }
+    }
     #[doc = "Bit 8 - Parity Error Flag for USIC0 Memory"]
     #[inline(always)]
     pub fn pefu0(&mut self) -> PEFU0_W {
@@ -1113,6 +1206,11 @@ impl W {
     pub fn pefu1(&mut self) -> PEFU1_W {
         PEFU1_W { w: self }
     }
+    #[doc = "Bit 10 - Parity Error Flag for USIC2 Memory"]
+    #[inline(always)]
+    pub fn pefu2(&mut self) -> PEFU2_W {
+        PEFU2_W { w: self }
+    }
     #[doc = "Bit 12 - Parity Error Flag for MultiCAN Memory"]
     #[inline(always)]
     pub fn pefmc(&mut self) -> PEFMC_W {
@@ -1148,11 +1246,6 @@ impl W {
     pub fn pesd1(&mut self) -> PESD1_W {
         PESD1_W { w: self }
     }
-    #[doc = "Bit 24 - Parity Error Flag for ECAT0 Memory"]
-    #[inline(always)]
-    pub fn peecat0(&mut self) -> PEECAT0_W {
-        PEECAT0_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
