@@ -38,9 +38,9 @@ impl From<crate::W<PETE_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEPS_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEPS_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl PETEPS_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEPS_A {
         match self.bits {
-            false => PETEPS_A::CONST_0,
-            true => PETEPS_A::CONST_1,
+            false => PETEPS_A::VALUE1,
+            true => PETEPS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEPS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEPS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEPS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEPS_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEPS_R {
@@ -92,13 +92,13 @@ impl<'a> PETEPS_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEPS_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEPS_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEPS_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEPS_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> PETEPS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEDS1_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEDS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl PETEDS1_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEDS1_A {
         match self.bits {
-            false => PETEDS1_A::CONST_0,
-            true => PETEDS1_A::CONST_1,
+            false => PETEDS1_A::VALUE1,
+            true => PETEDS1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEDS1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEDS1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEDS1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEDS1_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEDS1_R {
@@ -175,13 +175,13 @@ impl<'a> PETEDS1_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEDS1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEDS1_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEDS1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEDS1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -200,13 +200,96 @@ impl<'a> PETEDS1_W<'a> {
         self.w
     }
 }
+#[doc = "Parity Error Trap Enable for DSRAM2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PETEDS2_A {
+    #[doc = "0: Disabled"]
+    VALUE1 = 0,
+    #[doc = "1: Enabled"]
+    VALUE2 = 1,
+}
+impl From<PETEDS2_A> for bool {
+    #[inline(always)]
+    fn from(variant: PETEDS2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PETEDS2` reader - Parity Error Trap Enable for DSRAM2"]
+pub struct PETEDS2_R(crate::FieldReader<bool, PETEDS2_A>);
+impl PETEDS2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PETEDS2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PETEDS2_A {
+        match self.bits {
+            false => PETEDS2_A::VALUE1,
+            true => PETEDS2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == PETEDS2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == PETEDS2_A::VALUE2
+    }
+}
+impl core::ops::Deref for PETEDS2_R {
+    type Target = crate::FieldReader<bool, PETEDS2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PETEDS2` writer - Parity Error Trap Enable for DSRAM2"]
+pub struct PETEDS2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PETEDS2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PETEDS2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disabled"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEDS2_A::VALUE1)
+    }
+    #[doc = "Enabled"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEDS2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w
+    }
+}
 #[doc = "Parity Error Trap Enable for USIC0 Memory\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEU0_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEU0_A> for bool {
     #[inline(always)]
@@ -224,19 +307,19 @@ impl PETEU0_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEU0_A {
         match self.bits {
-            false => PETEU0_A::CONST_0,
-            true => PETEU0_A::CONST_1,
+            false => PETEU0_A::VALUE1,
+            true => PETEU0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEU0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEU0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEU0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEU0_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEU0_R {
@@ -258,13 +341,13 @@ impl<'a> PETEU0_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEU0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEU0_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEU0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEU0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +370,9 @@ impl<'a> PETEU0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEU1_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEU1_A> for bool {
     #[inline(always)]
@@ -307,19 +390,19 @@ impl PETEU1_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEU1_A {
         match self.bits {
-            false => PETEU1_A::CONST_0,
-            true => PETEU1_A::CONST_1,
+            false => PETEU1_A::VALUE1,
+            true => PETEU1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEU1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEU1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEU1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEU1_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEU1_R {
@@ -341,13 +424,13 @@ impl<'a> PETEU1_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEU1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEU1_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEU1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEU1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -366,13 +449,96 @@ impl<'a> PETEU1_W<'a> {
         self.w
     }
 }
+#[doc = "Parity Error Trap Enable for USIC2 Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PETEU2_A {
+    #[doc = "0: Disabled"]
+    VALUE1 = 0,
+    #[doc = "1: Enabled"]
+    VALUE2 = 1,
+}
+impl From<PETEU2_A> for bool {
+    #[inline(always)]
+    fn from(variant: PETEU2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PETEU2` reader - Parity Error Trap Enable for USIC2 Memory"]
+pub struct PETEU2_R(crate::FieldReader<bool, PETEU2_A>);
+impl PETEU2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PETEU2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PETEU2_A {
+        match self.bits {
+            false => PETEU2_A::VALUE1,
+            true => PETEU2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == PETEU2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == PETEU2_A::VALUE2
+    }
+}
+impl core::ops::Deref for PETEU2_R {
+    type Target = crate::FieldReader<bool, PETEU2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `PETEU2` writer - Parity Error Trap Enable for USIC2 Memory"]
+pub struct PETEU2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> PETEU2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: PETEU2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Disabled"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEU2_A::VALUE1)
+    }
+    #[doc = "Enabled"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEU2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w
+    }
+}
 #[doc = "Parity Error Trap Enable for MultiCAN Memory\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEMC_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEMC_A> for bool {
     #[inline(always)]
@@ -390,19 +556,19 @@ impl PETEMC_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEMC_A {
         match self.bits {
-            false => PETEMC_A::CONST_0,
-            true => PETEMC_A::CONST_1,
+            false => PETEMC_A::VALUE1,
+            true => PETEMC_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEMC_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEMC_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEMC_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEMC_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEMC_R {
@@ -424,13 +590,13 @@ impl<'a> PETEMC_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEMC_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEMC_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEMC_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEMC_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +619,9 @@ impl<'a> PETEMC_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEPPRF_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEPPRF_A> for bool {
     #[inline(always)]
@@ -473,19 +639,19 @@ impl PETEPPRF_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEPPRF_A {
         match self.bits {
-            false => PETEPPRF_A::CONST_0,
-            true => PETEPPRF_A::CONST_1,
+            false => PETEPPRF_A::VALUE1,
+            true => PETEPPRF_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEPPRF_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEPPRF_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEPPRF_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEPPRF_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEPPRF_R {
@@ -507,13 +673,13 @@ impl<'a> PETEPPRF_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEPPRF_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEPPRF_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEPPRF_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEPPRF_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +702,9 @@ impl<'a> PETEPPRF_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEUSB_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEUSB_A> for bool {
     #[inline(always)]
@@ -556,19 +722,19 @@ impl PETEUSB_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEUSB_A {
         match self.bits {
-            false => PETEUSB_A::CONST_0,
-            true => PETEUSB_A::CONST_1,
+            false => PETEUSB_A::VALUE1,
+            true => PETEUSB_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEUSB_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEUSB_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEUSB_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEUSB_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEUSB_R {
@@ -590,13 +756,13 @@ impl<'a> PETEUSB_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEUSB_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEUSB_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEUSB_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEUSB_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +785,9 @@ impl<'a> PETEUSB_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEETH0TX_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEETH0TX_A> for bool {
     #[inline(always)]
@@ -639,19 +805,19 @@ impl PETEETH0TX_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEETH0TX_A {
         match self.bits {
-            false => PETEETH0TX_A::CONST_0,
-            true => PETEETH0TX_A::CONST_1,
+            false => PETEETH0TX_A::VALUE1,
+            true => PETEETH0TX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEETH0TX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEETH0TX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEETH0TX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEETH0TX_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEETH0TX_R {
@@ -673,13 +839,13 @@ impl<'a> PETEETH0TX_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEETH0TX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEETH0TX_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEETH0TX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEETH0TX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +868,9 @@ impl<'a> PETEETH0TX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETEETH0RX_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETEETH0RX_A> for bool {
     #[inline(always)]
@@ -722,19 +888,19 @@ impl PETEETH0RX_R {
     #[inline(always)]
     pub fn variant(&self) -> PETEETH0RX_A {
         match self.bits {
-            false => PETEETH0RX_A::CONST_0,
-            true => PETEETH0RX_A::CONST_1,
+            false => PETEETH0RX_A::VALUE1,
+            true => PETEETH0RX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEETH0RX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETEETH0RX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEETH0RX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETEETH0RX_A::VALUE2
     }
 }
 impl core::ops::Deref for PETEETH0RX_R {
@@ -756,13 +922,13 @@ impl<'a> PETEETH0RX_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEETH0RX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETEETH0RX_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEETH0RX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETEETH0RX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +951,9 @@ impl<'a> PETEETH0RX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETESD0_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETESD0_A> for bool {
     #[inline(always)]
@@ -805,19 +971,19 @@ impl PETESD0_R {
     #[inline(always)]
     pub fn variant(&self) -> PETESD0_A {
         match self.bits {
-            false => PETESD0_A::CONST_0,
-            true => PETESD0_A::CONST_1,
+            false => PETESD0_A::VALUE1,
+            true => PETESD0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETESD0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETESD0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETESD0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETESD0_A::VALUE2
     }
 }
 impl core::ops::Deref for PETESD0_R {
@@ -839,13 +1005,13 @@ impl<'a> PETESD0_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETESD0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETESD0_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETESD0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETESD0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +1034,9 @@ impl<'a> PETESD0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PETESD1_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PETESD1_A> for bool {
     #[inline(always)]
@@ -888,19 +1054,19 @@ impl PETESD1_R {
     #[inline(always)]
     pub fn variant(&self) -> PETESD1_A {
         match self.bits {
-            false => PETESD1_A::CONST_0,
-            true => PETESD1_A::CONST_1,
+            false => PETESD1_A::VALUE1,
+            true => PETESD1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETESD1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PETESD1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETESD1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PETESD1_A::VALUE2
     }
 }
 impl core::ops::Deref for PETESD1_R {
@@ -922,13 +1088,13 @@ impl<'a> PETESD1_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETESD1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PETESD1_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETESD1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PETESD1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -947,89 +1113,6 @@ impl<'a> PETESD1_W<'a> {
         self.w
     }
 }
-#[doc = "Parity Error Trap Enable for ECAT0 SRAM Memory\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum PETEECAT0_A {
-    #[doc = "0: Disabled"]
-    CONST_0 = 0,
-    #[doc = "1: Enabled"]
-    CONST_1 = 1,
-}
-impl From<PETEECAT0_A> for bool {
-    #[inline(always)]
-    fn from(variant: PETEECAT0_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `PETEECAT0` reader - Parity Error Trap Enable for ECAT0 SRAM Memory"]
-pub struct PETEECAT0_R(crate::FieldReader<bool, PETEECAT0_A>);
-impl PETEECAT0_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        PETEECAT0_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> PETEECAT0_A {
-        match self.bits {
-            false => PETEECAT0_A::CONST_0,
-            true => PETEECAT0_A::CONST_1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
-    #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PETEECAT0_A::CONST_0
-    }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
-    #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PETEECAT0_A::CONST_1
-    }
-}
-impl core::ops::Deref for PETEECAT0_R {
-    type Target = crate::FieldReader<bool, PETEECAT0_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `PETEECAT0` writer - Parity Error Trap Enable for ECAT0 SRAM Memory"]
-pub struct PETEECAT0_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PETEECAT0_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PETEECAT0_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "Disabled"]
-    #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PETEECAT0_A::CONST_0)
-    }
-    #[doc = "Enabled"]
-    #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PETEECAT0_A::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
-        self.w
-    }
-}
 impl R {
     #[doc = "Bit 0 - Parity Error Trap Enable for PSRAM"]
     #[inline(always)]
@@ -1041,6 +1124,11 @@ impl R {
     pub fn peteds1(&self) -> PETEDS1_R {
         PETEDS1_R::new(((self.bits >> 1) & 0x01) != 0)
     }
+    #[doc = "Bit 2 - Parity Error Trap Enable for DSRAM2"]
+    #[inline(always)]
+    pub fn peteds2(&self) -> PETEDS2_R {
+        PETEDS2_R::new(((self.bits >> 2) & 0x01) != 0)
+    }
     #[doc = "Bit 8 - Parity Error Trap Enable for USIC0 Memory"]
     #[inline(always)]
     pub fn peteu0(&self) -> PETEU0_R {
@@ -1051,6 +1139,11 @@ impl R {
     pub fn peteu1(&self) -> PETEU1_R {
         PETEU1_R::new(((self.bits >> 9) & 0x01) != 0)
     }
+    #[doc = "Bit 10 - Parity Error Trap Enable for USIC2 Memory"]
+    #[inline(always)]
+    pub fn peteu2(&self) -> PETEU2_R {
+        PETEU2_R::new(((self.bits >> 10) & 0x01) != 0)
+    }
     #[doc = "Bit 12 - Parity Error Trap Enable for MultiCAN Memory"]
     #[inline(always)]
     pub fn petemc(&self) -> PETEMC_R {
@@ -1086,11 +1179,6 @@ impl R {
     pub fn petesd1(&self) -> PETESD1_R {
         PETESD1_R::new(((self.bits >> 20) & 0x01) != 0)
     }
-    #[doc = "Bit 24 - Parity Error Trap Enable for ECAT0 SRAM Memory"]
-    #[inline(always)]
-    pub fn peteecat0(&self) -> PETEECAT0_R {
-        PETEECAT0_R::new(((self.bits >> 24) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bit 0 - Parity Error Trap Enable for PSRAM"]
@@ -1103,6 +1191,11 @@ impl W {
     pub fn peteds1(&mut self) -> PETEDS1_W {
         PETEDS1_W { w: self }
     }
+    #[doc = "Bit 2 - Parity Error Trap Enable for DSRAM2"]
+    #[inline(always)]
+    pub fn peteds2(&mut self) -> PETEDS2_W {
+        PETEDS2_W { w: self }
+    }
     #[doc = "Bit 8 - Parity Error Trap Enable for USIC0 Memory"]
     #[inline(always)]
     pub fn peteu0(&mut self) -> PETEU0_W {
@@ -1113,6 +1206,11 @@ impl W {
     pub fn peteu1(&mut self) -> PETEU1_W {
         PETEU1_W { w: self }
     }
+    #[doc = "Bit 10 - Parity Error Trap Enable for USIC2 Memory"]
+    #[inline(always)]
+    pub fn peteu2(&mut self) -> PETEU2_W {
+        PETEU2_W { w: self }
+    }
     #[doc = "Bit 12 - Parity Error Trap Enable for MultiCAN Memory"]
     #[inline(always)]
     pub fn petemc(&mut self) -> PETEMC_W {
@@ -1148,11 +1246,6 @@ impl W {
     pub fn petesd1(&mut self) -> PETESD1_W {
         PETESD1_W { w: self }
     }
-    #[doc = "Bit 24 - Parity Error Trap Enable for ECAT0 SRAM Memory"]
-    #[inline(always)]
-    pub fn peteecat0(&mut self) -> PETEECAT0_W {
-        PETEECAT0_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
