@@ -38,9 +38,9 @@ impl From<crate::W<PMTSR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTENPS_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTENPS_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl MTENPS_R {
     #[inline(always)]
     pub fn variant(&self) -> MTENPS_A {
         match self.bits {
-            false => MTENPS_A::CONST_0,
-            true => MTENPS_A::CONST_1,
+            false => MTENPS_A::VALUE1,
+            true => MTENPS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTENPS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTENPS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTENPS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTENPS_A::VALUE2
     }
 }
 impl core::ops::Deref for MTENPS_R {
@@ -92,13 +92,13 @@ impl<'a> MTENPS_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTENPS_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTENPS_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTENPS_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTENPS_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> MTENPS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTENDS1_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTENDS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl MTENDS1_R {
     #[inline(always)]
     pub fn variant(&self) -> MTENDS1_A {
         match self.bits {
-            false => MTENDS1_A::CONST_0,
-            true => MTENDS1_A::CONST_1,
+            false => MTENDS1_A::VALUE1,
+            true => MTENDS1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTENDS1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTENDS1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTENDS1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTENDS1_A::VALUE2
     }
 }
 impl core::ops::Deref for MTENDS1_R {
@@ -175,13 +175,13 @@ impl<'a> MTENDS1_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTENDS1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTENDS1_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTENDS1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTENDS1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -200,13 +200,96 @@ impl<'a> MTENDS1_W<'a> {
         self.w
     }
 }
+#[doc = "Test Enable Control for DSRAM2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTENDS2_A {
+    #[doc = "0: Standard operation"]
+    VALUE1 = 0,
+    #[doc = "1: Parity bits under test"]
+    VALUE2 = 1,
+}
+impl From<MTENDS2_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTENDS2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `MTENDS2` reader - Test Enable Control for DSRAM2"]
+pub struct MTENDS2_R(crate::FieldReader<bool, MTENDS2_A>);
+impl MTENDS2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTENDS2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTENDS2_A {
+        match self.bits {
+            false => MTENDS2_A::VALUE1,
+            true => MTENDS2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == MTENDS2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == MTENDS2_A::VALUE2
+    }
+}
+impl core::ops::Deref for MTENDS2_R {
+    type Target = crate::FieldReader<bool, MTENDS2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MTENDS2` writer - Test Enable Control for DSRAM2"]
+pub struct MTENDS2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> MTENDS2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: MTENDS2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Standard operation"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTENDS2_A::VALUE1)
+    }
+    #[doc = "Parity bits under test"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTENDS2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w
+    }
+}
 #[doc = "Test Enable Control for USIC0 Memory\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTEU0_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTEU0_A> for bool {
     #[inline(always)]
@@ -224,19 +307,19 @@ impl MTEU0_R {
     #[inline(always)]
     pub fn variant(&self) -> MTEU0_A {
         match self.bits {
-            false => MTEU0_A::CONST_0,
-            true => MTEU0_A::CONST_1,
+            false => MTEU0_A::VALUE1,
+            true => MTEU0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTEU0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTEU0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTEU0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTEU0_A::VALUE2
     }
 }
 impl core::ops::Deref for MTEU0_R {
@@ -258,13 +341,13 @@ impl<'a> MTEU0_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTEU0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTEU0_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTEU0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTEU0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +370,9 @@ impl<'a> MTEU0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTEU1_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTEU1_A> for bool {
     #[inline(always)]
@@ -307,19 +390,19 @@ impl MTEU1_R {
     #[inline(always)]
     pub fn variant(&self) -> MTEU1_A {
         match self.bits {
-            false => MTEU1_A::CONST_0,
-            true => MTEU1_A::CONST_1,
+            false => MTEU1_A::VALUE1,
+            true => MTEU1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTEU1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTEU1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTEU1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTEU1_A::VALUE2
     }
 }
 impl core::ops::Deref for MTEU1_R {
@@ -341,13 +424,13 @@ impl<'a> MTEU1_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTEU1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTEU1_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTEU1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTEU1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -366,13 +449,96 @@ impl<'a> MTEU1_W<'a> {
         self.w
     }
 }
+#[doc = "Test Enable Control for USIC2 Memory\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum MTEU2_A {
+    #[doc = "0: Standard operation"]
+    VALUE1 = 0,
+    #[doc = "1: Parity bits under test"]
+    VALUE2 = 1,
+}
+impl From<MTEU2_A> for bool {
+    #[inline(always)]
+    fn from(variant: MTEU2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `MTEU2` reader - Test Enable Control for USIC2 Memory"]
+pub struct MTEU2_R(crate::FieldReader<bool, MTEU2_A>);
+impl MTEU2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        MTEU2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> MTEU2_A {
+        match self.bits {
+            false => MTEU2_A::VALUE1,
+            true => MTEU2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == MTEU2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == MTEU2_A::VALUE2
+    }
+}
+impl core::ops::Deref for MTEU2_R {
+    type Target = crate::FieldReader<bool, MTEU2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MTEU2` writer - Test Enable Control for USIC2 Memory"]
+pub struct MTEU2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> MTEU2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: MTEU2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Standard operation"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTEU2_A::VALUE1)
+    }
+    #[doc = "Parity bits under test"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTEU2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w
+    }
+}
 #[doc = "Test Enable Control for MultiCAN Memory\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTEMC_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTEMC_A> for bool {
     #[inline(always)]
@@ -390,19 +556,19 @@ impl MTEMC_R {
     #[inline(always)]
     pub fn variant(&self) -> MTEMC_A {
         match self.bits {
-            false => MTEMC_A::CONST_0,
-            true => MTEMC_A::CONST_1,
+            false => MTEMC_A::VALUE1,
+            true => MTEMC_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTEMC_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTEMC_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTEMC_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTEMC_A::VALUE2
     }
 }
 impl core::ops::Deref for MTEMC_R {
@@ -424,13 +590,13 @@ impl<'a> MTEMC_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTEMC_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTEMC_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTEMC_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTEMC_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +619,9 @@ impl<'a> MTEMC_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTEPPRF_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTEPPRF_A> for bool {
     #[inline(always)]
@@ -473,19 +639,19 @@ impl MTEPPRF_R {
     #[inline(always)]
     pub fn variant(&self) -> MTEPPRF_A {
         match self.bits {
-            false => MTEPPRF_A::CONST_0,
-            true => MTEPPRF_A::CONST_1,
+            false => MTEPPRF_A::VALUE1,
+            true => MTEPPRF_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTEPPRF_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTEPPRF_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTEPPRF_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTEPPRF_A::VALUE2
     }
 }
 impl core::ops::Deref for MTEPPRF_R {
@@ -507,13 +673,13 @@ impl<'a> MTEPPRF_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTEPPRF_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTEPPRF_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTEPPRF_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTEPPRF_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +702,9 @@ impl<'a> MTEPPRF_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTUSB_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTUSB_A> for bool {
     #[inline(always)]
@@ -556,19 +722,19 @@ impl MTUSB_R {
     #[inline(always)]
     pub fn variant(&self) -> MTUSB_A {
         match self.bits {
-            false => MTUSB_A::CONST_0,
-            true => MTUSB_A::CONST_1,
+            false => MTUSB_A::VALUE1,
+            true => MTUSB_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTUSB_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTUSB_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTUSB_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTUSB_A::VALUE2
     }
 }
 impl core::ops::Deref for MTUSB_R {
@@ -590,13 +756,13 @@ impl<'a> MTUSB_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTUSB_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTUSB_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTUSB_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTUSB_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +785,9 @@ impl<'a> MTUSB_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTETH0TX_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTETH0TX_A> for bool {
     #[inline(always)]
@@ -639,19 +805,19 @@ impl MTETH0TX_R {
     #[inline(always)]
     pub fn variant(&self) -> MTETH0TX_A {
         match self.bits {
-            false => MTETH0TX_A::CONST_0,
-            true => MTETH0TX_A::CONST_1,
+            false => MTETH0TX_A::VALUE1,
+            true => MTETH0TX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTETH0TX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTETH0TX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTETH0TX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTETH0TX_A::VALUE2
     }
 }
 impl core::ops::Deref for MTETH0TX_R {
@@ -673,13 +839,13 @@ impl<'a> MTETH0TX_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTETH0TX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTETH0TX_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTETH0TX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTETH0TX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +868,9 @@ impl<'a> MTETH0TX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTETH0RX_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTETH0RX_A> for bool {
     #[inline(always)]
@@ -722,19 +888,19 @@ impl MTETH0RX_R {
     #[inline(always)]
     pub fn variant(&self) -> MTETH0RX_A {
         match self.bits {
-            false => MTETH0RX_A::CONST_0,
-            true => MTETH0RX_A::CONST_1,
+            false => MTETH0RX_A::VALUE1,
+            true => MTETH0RX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTETH0RX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTETH0RX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTETH0RX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTETH0RX_A::VALUE2
     }
 }
 impl core::ops::Deref for MTETH0RX_R {
@@ -756,13 +922,13 @@ impl<'a> MTETH0RX_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTETH0RX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTETH0RX_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTETH0RX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTETH0RX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +951,9 @@ impl<'a> MTETH0RX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTSD0_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTSD0_A> for bool {
     #[inline(always)]
@@ -805,19 +971,19 @@ impl MTSD0_R {
     #[inline(always)]
     pub fn variant(&self) -> MTSD0_A {
         match self.bits {
-            false => MTSD0_A::CONST_0,
-            true => MTSD0_A::CONST_1,
+            false => MTSD0_A::VALUE1,
+            true => MTSD0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTSD0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTSD0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTSD0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTSD0_A::VALUE2
     }
 }
 impl core::ops::Deref for MTSD0_R {
@@ -839,13 +1005,13 @@ impl<'a> MTSD0_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTSD0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTSD0_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTSD0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTSD0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +1034,9 @@ impl<'a> MTSD0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MTSD1_A {
     #[doc = "0: Standard operation"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MTSD1_A> for bool {
     #[inline(always)]
@@ -888,19 +1054,19 @@ impl MTSD1_R {
     #[inline(always)]
     pub fn variant(&self) -> MTSD1_A {
         match self.bits {
-            false => MTSD1_A::CONST_0,
-            true => MTSD1_A::CONST_1,
+            false => MTSD1_A::VALUE1,
+            true => MTSD1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTSD1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MTSD1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTSD1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MTSD1_A::VALUE2
     }
 }
 impl core::ops::Deref for MTSD1_R {
@@ -922,13 +1088,13 @@ impl<'a> MTSD1_W<'a> {
     }
     #[doc = "Standard operation"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTSD1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MTSD1_A::VALUE1)
     }
     #[doc = "Parity bits under test"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTSD1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MTSD1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -947,89 +1113,6 @@ impl<'a> MTSD1_W<'a> {
         self.w
     }
 }
-#[doc = "Test Enable Control for ECAT0 Memory\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum MTECAT0_A {
-    #[doc = "0: Standard operation"]
-    CONST_0 = 0,
-    #[doc = "1: Parity bits under test"]
-    CONST_1 = 1,
-}
-impl From<MTECAT0_A> for bool {
-    #[inline(always)]
-    fn from(variant: MTECAT0_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `MTECAT0` reader - Test Enable Control for ECAT0 Memory"]
-pub struct MTECAT0_R(crate::FieldReader<bool, MTECAT0_A>);
-impl MTECAT0_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        MTECAT0_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> MTECAT0_A {
-        match self.bits {
-            false => MTECAT0_A::CONST_0,
-            true => MTECAT0_A::CONST_1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
-    #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MTECAT0_A::CONST_0
-    }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
-    #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MTECAT0_A::CONST_1
-    }
-}
-impl core::ops::Deref for MTECAT0_R {
-    type Target = crate::FieldReader<bool, MTECAT0_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `MTECAT0` writer - Test Enable Control for ECAT0 Memory"]
-pub struct MTECAT0_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> MTECAT0_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: MTECAT0_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "Standard operation"]
-    #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MTECAT0_A::CONST_0)
-    }
-    #[doc = "Parity bits under test"]
-    #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MTECAT0_A::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
-        self.w
-    }
-}
 impl R {
     #[doc = "Bit 0 - Test Enable Control for PSRAM"]
     #[inline(always)]
@@ -1041,6 +1124,11 @@ impl R {
     pub fn mtends1(&self) -> MTENDS1_R {
         MTENDS1_R::new(((self.bits >> 1) & 0x01) != 0)
     }
+    #[doc = "Bit 2 - Test Enable Control for DSRAM2"]
+    #[inline(always)]
+    pub fn mtends2(&self) -> MTENDS2_R {
+        MTENDS2_R::new(((self.bits >> 2) & 0x01) != 0)
+    }
     #[doc = "Bit 8 - Test Enable Control for USIC0 Memory"]
     #[inline(always)]
     pub fn mteu0(&self) -> MTEU0_R {
@@ -1051,6 +1139,11 @@ impl R {
     pub fn mteu1(&self) -> MTEU1_R {
         MTEU1_R::new(((self.bits >> 9) & 0x01) != 0)
     }
+    #[doc = "Bit 10 - Test Enable Control for USIC2 Memory"]
+    #[inline(always)]
+    pub fn mteu2(&self) -> MTEU2_R {
+        MTEU2_R::new(((self.bits >> 10) & 0x01) != 0)
+    }
     #[doc = "Bit 12 - Test Enable Control for MultiCAN Memory"]
     #[inline(always)]
     pub fn mtemc(&self) -> MTEMC_R {
@@ -1086,11 +1179,6 @@ impl R {
     pub fn mtsd1(&self) -> MTSD1_R {
         MTSD1_R::new(((self.bits >> 20) & 0x01) != 0)
     }
-    #[doc = "Bit 24 - Test Enable Control for ECAT0 Memory"]
-    #[inline(always)]
-    pub fn mtecat0(&self) -> MTECAT0_R {
-        MTECAT0_R::new(((self.bits >> 24) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bit 0 - Test Enable Control for PSRAM"]
@@ -1103,6 +1191,11 @@ impl W {
     pub fn mtends1(&mut self) -> MTENDS1_W {
         MTENDS1_W { w: self }
     }
+    #[doc = "Bit 2 - Test Enable Control for DSRAM2"]
+    #[inline(always)]
+    pub fn mtends2(&mut self) -> MTENDS2_W {
+        MTENDS2_W { w: self }
+    }
     #[doc = "Bit 8 - Test Enable Control for USIC0 Memory"]
     #[inline(always)]
     pub fn mteu0(&mut self) -> MTEU0_W {
@@ -1113,6 +1206,11 @@ impl W {
     pub fn mteu1(&mut self) -> MTEU1_W {
         MTEU1_W { w: self }
     }
+    #[doc = "Bit 10 - Test Enable Control for USIC2 Memory"]
+    #[inline(always)]
+    pub fn mteu2(&mut self) -> MTEU2_W {
+        MTEU2_W { w: self }
+    }
     #[doc = "Bit 12 - Test Enable Control for MultiCAN Memory"]
     #[inline(always)]
     pub fn mtemc(&mut self) -> MTEMC_W {
@@ -1148,11 +1246,6 @@ impl W {
     pub fn mtsd1(&mut self) -> MTSD1_W {
         MTSD1_W { w: self }
     }
-    #[doc = "Bit 24 - Test Enable Control for ECAT0 Memory"]
-    #[inline(always)]
-    pub fn mtecat0(&mut self) -> MTECAT0_W {
-        MTECAT0_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
