@@ -18,9 +18,9 @@ impl From<crate::R<CLKMXSTAT_SPEC>> for R {
 #[repr(u8)]
 pub enum SYSCLKMUX_A {
     #[doc = "1: fOFI clock active"]
-    CONST_X1 = 1,
+    VALUE1 = 1,
     #[doc = "2: fPLL clock active"]
-    CONST_1X = 2,
+    VALUE2 = 2,
 }
 impl From<SYSCLKMUX_A> for u8 {
     #[inline(always)]
@@ -38,20 +38,20 @@ impl SYSCLKMUX_R {
     #[inline(always)]
     pub fn variant(&self) -> Option<SYSCLKMUX_A> {
         match self.bits {
-            1 => Some(SYSCLKMUX_A::CONST_X1),
-            2 => Some(SYSCLKMUX_A::CONST_1X),
+            1 => Some(SYSCLKMUX_A::VALUE1),
+            2 => Some(SYSCLKMUX_A::VALUE2),
             _ => None,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_X1`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_x1(&self) -> bool {
-        **self == SYSCLKMUX_A::CONST_X1
+    pub fn is_value1(&self) -> bool {
+        **self == SYSCLKMUX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1X`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1x(&self) -> bool {
-        **self == SYSCLKMUX_A::CONST_1X
+    pub fn is_value2(&self) -> bool {
+        **self == SYSCLKMUX_A::VALUE2
     }
 }
 impl core::ops::Deref for SYSCLKMUX_R {
