@@ -23,9 +23,9 @@ impl From<crate::W<PRSET2_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDTRS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WDTRS_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> WDTRS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WDTRS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WDTRS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WDTRS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WDTRS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> WDTRS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0RS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ETH0RS_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> ETH0RS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ETH0RS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ETH0RS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ETH0RS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ETH0RS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> ETH0RS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DMA0RS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DMA0RS_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> DMA0RS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(DMA0RS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DMA0RS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(DMA0RS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DMA0RS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -172,13 +172,64 @@ impl<'a> DMA0RS_W<'a> {
         self.w
     }
 }
+#[doc = "DMA1 Reset Assert\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum DMA1RS_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Assert reset"]
+    VALUE2 = 1,
+}
+impl From<DMA1RS_AW> for bool {
+    #[inline(always)]
+    fn from(variant: DMA1RS_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `DMA1RS` writer - DMA1 Reset Assert"]
+pub struct DMA1RS_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> DMA1RS_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: DMA1RS_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DMA1RS_AW::VALUE1)
+    }
+    #[doc = "Assert reset"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DMA1RS_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w
+    }
+}
 #[doc = "FCE Reset Assert\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FCERS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<FCERS_AW> for bool {
     #[inline(always)]
@@ -198,13 +249,13 @@ impl<'a> FCERS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(FCERS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(FCERS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(FCERS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(FCERS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -227,9 +278,9 @@ impl<'a> FCERS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBRS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBRS_AW> for bool {
     #[inline(always)]
@@ -249,13 +300,13 @@ impl<'a> USBRS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USBRS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USBRS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USBRS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USBRS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -274,57 +325,6 @@ impl<'a> USBRS_W<'a> {
         self.w
     }
 }
-#[doc = "ECAT0 Reset Assert\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ECAT0RS_AW {
-    #[doc = "0: No effect"]
-    CONST_0 = 0,
-    #[doc = "1: Assert reset"]
-    CONST_1 = 1,
-}
-impl From<ECAT0RS_AW> for bool {
-    #[inline(always)]
-    fn from(variant: ECAT0RS_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `ECAT0RS` writer - ECAT0 Reset Assert"]
-pub struct ECAT0RS_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ECAT0RS_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ECAT0RS_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ECAT0RS_AW::CONST_0)
-    }
-    #[doc = "Assert reset"]
-    #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ECAT0RS_AW::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
-        self.w
-    }
-}
 impl W {
     #[doc = "Bit 1 - WDT Reset Assert"]
     #[inline(always)]
@@ -341,6 +341,11 @@ impl W {
     pub fn dma0rs(&mut self) -> DMA0RS_W {
         DMA0RS_W { w: self }
     }
+    #[doc = "Bit 5 - DMA1 Reset Assert"]
+    #[inline(always)]
+    pub fn dma1rs(&mut self) -> DMA1RS_W {
+        DMA1RS_W { w: self }
+    }
     #[doc = "Bit 6 - FCE Reset Assert"]
     #[inline(always)]
     pub fn fcers(&mut self) -> FCERS_W {
@@ -351,11 +356,6 @@ impl W {
     pub fn usbrs(&mut self) -> USBRS_W {
         USBRS_W { w: self }
     }
-    #[doc = "Bit 10 - ECAT0 Reset Assert"]
-    #[inline(always)]
-    pub fn ecat0rs(&mut self) -> ECAT0RS_W {
-        ECAT0RS_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
