@@ -13,13 +13,59 @@ impl From<crate::R<PRSTAT1_SPEC>> for R {
         R(reader)
     }
 }
+#[doc = "CCU43 Reset Status\n\nValue on reset: 1"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CCU43RS_A {
+    #[doc = "0: Reset de-asserted"]
+    VALUE1 = 0,
+    #[doc = "1: Reset asserted"]
+    VALUE2 = 1,
+}
+impl From<CCU43RS_A> for bool {
+    #[inline(always)]
+    fn from(variant: CCU43RS_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `CCU43RS` reader - CCU43 Reset Status"]
+pub struct CCU43RS_R(crate::FieldReader<bool, CCU43RS_A>);
+impl CCU43RS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CCU43RS_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> CCU43RS_A {
+        match self.bits {
+            false => CCU43RS_A::VALUE1,
+            true => CCU43RS_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == CCU43RS_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == CCU43RS_A::VALUE2
+    }
+}
+impl core::ops::Deref for CCU43RS_R {
+    type Target = crate::FieldReader<bool, CCU43RS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "LEDTS Reset Status\n\nValue on reset: 1"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LEDTSCU0RS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LEDTSCU0RS_A> for bool {
     #[inline(always)]
@@ -37,19 +83,19 @@ impl LEDTSCU0RS_R {
     #[inline(always)]
     pub fn variant(&self) -> LEDTSCU0RS_A {
         match self.bits {
-            false => LEDTSCU0RS_A::CONST_0,
-            true => LEDTSCU0RS_A::CONST_1,
+            false => LEDTSCU0RS_A::VALUE1,
+            true => LEDTSCU0RS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == LEDTSCU0RS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == LEDTSCU0RS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == LEDTSCU0RS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == LEDTSCU0RS_A::VALUE2
     }
 }
 impl core::ops::Deref for LEDTSCU0RS_R {
@@ -63,9 +109,9 @@ impl core::ops::Deref for LEDTSCU0RS_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MCAN0RS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MCAN0RS_A> for bool {
     #[inline(always)]
@@ -83,19 +129,19 @@ impl MCAN0RS_R {
     #[inline(always)]
     pub fn variant(&self) -> MCAN0RS_A {
         match self.bits {
-            false => MCAN0RS_A::CONST_0,
-            true => MCAN0RS_A::CONST_1,
+            false => MCAN0RS_A::VALUE1,
+            true => MCAN0RS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MCAN0RS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MCAN0RS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MCAN0RS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MCAN0RS_A::VALUE2
     }
 }
 impl core::ops::Deref for MCAN0RS_R {
@@ -109,9 +155,9 @@ impl core::ops::Deref for MCAN0RS_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DACRS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DACRS_A> for bool {
     #[inline(always)]
@@ -129,19 +175,19 @@ impl DACRS_R {
     #[inline(always)]
     pub fn variant(&self) -> DACRS_A {
         match self.bits {
-            false => DACRS_A::CONST_0,
-            true => DACRS_A::CONST_1,
+            false => DACRS_A::VALUE1,
+            true => DACRS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == DACRS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == DACRS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == DACRS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == DACRS_A::VALUE2
     }
 }
 impl core::ops::Deref for DACRS_R {
@@ -155,9 +201,9 @@ impl core::ops::Deref for DACRS_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MMCIRS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MMCIRS_A> for bool {
     #[inline(always)]
@@ -175,19 +221,19 @@ impl MMCIRS_R {
     #[inline(always)]
     pub fn variant(&self) -> MMCIRS_A {
         match self.bits {
-            false => MMCIRS_A::CONST_0,
-            true => MMCIRS_A::CONST_1,
+            false => MMCIRS_A::VALUE1,
+            true => MMCIRS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MMCIRS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MMCIRS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MMCIRS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MMCIRS_A::VALUE2
     }
 }
 impl core::ops::Deref for MMCIRS_R {
@@ -201,9 +247,9 @@ impl core::ops::Deref for MMCIRS_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USIC1RS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USIC1RS_A> for bool {
     #[inline(always)]
@@ -221,19 +267,19 @@ impl USIC1RS_R {
     #[inline(always)]
     pub fn variant(&self) -> USIC1RS_A {
         match self.bits {
-            false => USIC1RS_A::CONST_0,
-            true => USIC1RS_A::CONST_1,
+            false => USIC1RS_A::VALUE1,
+            true => USIC1RS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USIC1RS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USIC1RS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USIC1RS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USIC1RS_A::VALUE2
     }
 }
 impl core::ops::Deref for USIC1RS_R {
@@ -243,13 +289,59 @@ impl core::ops::Deref for USIC1RS_R {
         &self.0
     }
 }
+#[doc = "USIC2 Reset Status\n\nValue on reset: 1"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum USIC2RS_A {
+    #[doc = "0: Reset de-asserted"]
+    VALUE1 = 0,
+    #[doc = "1: Reset asserted"]
+    VALUE2 = 1,
+}
+impl From<USIC2RS_A> for bool {
+    #[inline(always)]
+    fn from(variant: USIC2RS_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `USIC2RS` reader - USIC2 Reset Status"]
+pub struct USIC2RS_R(crate::FieldReader<bool, USIC2RS_A>);
+impl USIC2RS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        USIC2RS_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> USIC2RS_A {
+        match self.bits {
+            false => USIC2RS_A::VALUE1,
+            true => USIC2RS_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == USIC2RS_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == USIC2RS_A::VALUE2
+    }
+}
+impl core::ops::Deref for USIC2RS_R {
+    type Target = crate::FieldReader<bool, USIC2RS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "PORTS Reset Status\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPORTSRS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPORTSRS_A> for bool {
     #[inline(always)]
@@ -267,19 +359,19 @@ impl PPORTSRS_R {
     #[inline(always)]
     pub fn variant(&self) -> PPORTSRS_A {
         match self.bits {
-            false => PPORTSRS_A::CONST_0,
-            true => PPORTSRS_A::CONST_1,
+            false => PPORTSRS_A::VALUE1,
+            true => PPORTSRS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPORTSRS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPORTSRS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPORTSRS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPORTSRS_A::VALUE2
     }
 }
 impl core::ops::Deref for PPORTSRS_R {
@@ -290,6 +382,11 @@ impl core::ops::Deref for PPORTSRS_R {
     }
 }
 impl R {
+    #[doc = "Bit 0 - CCU43 Reset Status"]
+    #[inline(always)]
+    pub fn ccu43rs(&self) -> CCU43RS_R {
+        CCU43RS_R::new((self.bits & 0x01) != 0)
+    }
     #[doc = "Bit 3 - LEDTS Reset Status"]
     #[inline(always)]
     pub fn ledtscu0rs(&self) -> LEDTSCU0RS_R {
@@ -315,6 +412,11 @@ impl R {
     pub fn usic1rs(&self) -> USIC1RS_R {
         USIC1RS_R::new(((self.bits >> 7) & 0x01) != 0)
     }
+    #[doc = "Bit 8 - USIC2 Reset Status"]
+    #[inline(always)]
+    pub fn usic2rs(&self) -> USIC2RS_R {
+        USIC2RS_R::new(((self.bits >> 8) & 0x01) != 0)
+    }
     #[doc = "Bit 9 - PORTS Reset Status"]
     #[inline(always)]
     pub fn pportsrs(&self) -> PPORTSRS_R {
