@@ -17,9 +17,9 @@ impl From<crate::R<PRSTAT2_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDTRS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WDTRS_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl WDTRS_R {
     #[inline(always)]
     pub fn variant(&self) -> WDTRS_A {
         match self.bits {
-            false => WDTRS_A::CONST_0,
-            true => WDTRS_A::CONST_1,
+            false => WDTRS_A::VALUE1,
+            true => WDTRS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == WDTRS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == WDTRS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == WDTRS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == WDTRS_A::VALUE2
     }
 }
 impl core::ops::Deref for WDTRS_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for WDTRS_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0RS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ETH0RS_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl ETH0RS_R {
     #[inline(always)]
     pub fn variant(&self) -> ETH0RS_A {
         match self.bits {
-            false => ETH0RS_A::CONST_0,
-            true => ETH0RS_A::CONST_1,
+            false => ETH0RS_A::VALUE1,
+            true => ETH0RS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ETH0RS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ETH0RS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ETH0RS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ETH0RS_A::VALUE2
     }
 }
 impl core::ops::Deref for ETH0RS_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for ETH0RS_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DMA0RS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DMA0RS_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl DMA0RS_R {
     #[inline(always)]
     pub fn variant(&self) -> DMA0RS_A {
         match self.bits {
-            false => DMA0RS_A::CONST_0,
-            true => DMA0RS_A::CONST_1,
+            false => DMA0RS_A::VALUE1,
+            true => DMA0RS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == DMA0RS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == DMA0RS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == DMA0RS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == DMA0RS_A::VALUE2
     }
 }
 impl core::ops::Deref for DMA0RS_R {
@@ -151,13 +151,59 @@ impl core::ops::Deref for DMA0RS_R {
         &self.0
     }
 }
+#[doc = "DMA1 Reset Status\n\nValue on reset: 1"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum DMA1RS_A {
+    #[doc = "0: Reset de-asserted"]
+    VALUE1 = 0,
+    #[doc = "1: Reset asserted"]
+    VALUE2 = 1,
+}
+impl From<DMA1RS_A> for bool {
+    #[inline(always)]
+    fn from(variant: DMA1RS_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `DMA1RS` reader - DMA1 Reset Status"]
+pub struct DMA1RS_R(crate::FieldReader<bool, DMA1RS_A>);
+impl DMA1RS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DMA1RS_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> DMA1RS_A {
+        match self.bits {
+            false => DMA1RS_A::VALUE1,
+            true => DMA1RS_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == DMA1RS_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == DMA1RS_A::VALUE2
+    }
+}
+impl core::ops::Deref for DMA1RS_R {
+    type Target = crate::FieldReader<bool, DMA1RS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "FCE Reset Status\n\nValue on reset: 1"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FCERS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<FCERS_A> for bool {
     #[inline(always)]
@@ -175,19 +221,19 @@ impl FCERS_R {
     #[inline(always)]
     pub fn variant(&self) -> FCERS_A {
         match self.bits {
-            false => FCERS_A::CONST_0,
-            true => FCERS_A::CONST_1,
+            false => FCERS_A::VALUE1,
+            true => FCERS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == FCERS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == FCERS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == FCERS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == FCERS_A::VALUE2
     }
 }
 impl core::ops::Deref for FCERS_R {
@@ -201,9 +247,9 @@ impl core::ops::Deref for FCERS_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBRS_A {
     #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBRS_A> for bool {
     #[inline(always)]
@@ -221,19 +267,19 @@ impl USBRS_R {
     #[inline(always)]
     pub fn variant(&self) -> USBRS_A {
         match self.bits {
-            false => USBRS_A::CONST_0,
-            true => USBRS_A::CONST_1,
+            false => USBRS_A::VALUE1,
+            true => USBRS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USBRS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USBRS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USBRS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USBRS_A::VALUE2
     }
 }
 impl core::ops::Deref for USBRS_R {
@@ -243,52 +289,6 @@ impl core::ops::Deref for USBRS_R {
         &self.0
     }
 }
-#[doc = "ECAT0 Reset Status\n\nValue on reset: 1"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ECAT0RS_A {
-    #[doc = "0: Reset de-asserted"]
-    CONST_0 = 0,
-    #[doc = "1: Reset asserted"]
-    CONST_1 = 1,
-}
-impl From<ECAT0RS_A> for bool {
-    #[inline(always)]
-    fn from(variant: ECAT0RS_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `ECAT0RS` reader - ECAT0 Reset Status"]
-pub struct ECAT0RS_R(crate::FieldReader<bool, ECAT0RS_A>);
-impl ECAT0RS_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ECAT0RS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ECAT0RS_A {
-        match self.bits {
-            false => ECAT0RS_A::CONST_0,
-            true => ECAT0RS_A::CONST_1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
-    #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ECAT0RS_A::CONST_0
-    }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
-    #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ECAT0RS_A::CONST_1
-    }
-}
-impl core::ops::Deref for ECAT0RS_R {
-    type Target = crate::FieldReader<bool, ECAT0RS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
 impl R {
     #[doc = "Bit 1 - WDT Reset Status"]
     #[inline(always)]
@@ -305,6 +305,11 @@ impl R {
     pub fn dma0rs(&self) -> DMA0RS_R {
         DMA0RS_R::new(((self.bits >> 4) & 0x01) != 0)
     }
+    #[doc = "Bit 5 - DMA1 Reset Status"]
+    #[inline(always)]
+    pub fn dma1rs(&self) -> DMA1RS_R {
+        DMA1RS_R::new(((self.bits >> 5) & 0x01) != 0)
+    }
     #[doc = "Bit 6 - FCE Reset Status"]
     #[inline(always)]
     pub fn fcers(&self) -> FCERS_R {
@@ -315,11 +320,6 @@ impl R {
     pub fn usbrs(&self) -> USBRS_R {
         USBRS_R::new(((self.bits >> 7) & 0x01) != 0)
     }
-    #[doc = "Bit 10 - ECAT0 Reset Status"]
-    #[inline(always)]
-    pub fn ecat0rs(&self) -> ECAT0RS_R {
-        ECAT0RS_R::new(((self.bits >> 10) & 0x01) != 0)
-    }
 }
 #[doc = "RCU Peripheral 2 Reset Status\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [prstat2](index.html) module"]
 pub struct PRSTAT2_SPEC;
@@ -330,10 +330,10 @@ impl crate::RegisterSpec for PRSTAT2_SPEC {
 impl crate::Readable for PRSTAT2_SPEC {
     type Reader = R;
 }
-#[doc = "`reset()` method sets PRSTAT2 to value 0x04f6"]
+#[doc = "`reset()` method sets PRSTAT2 to value 0xf6"]
 impl crate::Resettable for PRSTAT2_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x04f6
+        0xf6
     }
 }
