@@ -70,7 +70,7 @@ impl<'a> RMTWKUPSIG_W<'a> {
         self.w
     }
 }
-#[doc = "Soft Disconnect\n\nValue on reset: 1"]
+#[doc = "Soft Disconnect\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SFTDISCON_A {
     #[doc = "0: Normal operation. When this bit is cleared after a soft disconnect, the core drives a device connect event to the USB host. When the device is reconnected, the USB host restarts device enumeration."]
@@ -553,89 +553,6 @@ impl<'a> NAKONBBLE_W<'a> {
         self.w
     }
 }
-#[doc = "Enable continue on BNA\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ENCONTONBNA_A {
-    #[doc = "0: After receiving BNA interrupt, the core disables the endpoint. When the endpoint is re-enabled by the application, the core starts processing from the DOEPDMA descriptor."]
-    VALUE1 = 0,
-    #[doc = "1: After receiving BNA interrupt, the core disables the endpoint. When the endpoint is re-enabled by the application, the core starts processing from the descriptor that received the BNA interrupt."]
-    VALUE2 = 1,
-}
-impl From<ENCONTONBNA_A> for bool {
-    #[inline(always)]
-    fn from(variant: ENCONTONBNA_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `EnContOnBNA` reader - Enable continue on BNA"]
-pub struct ENCONTONBNA_R(crate::FieldReader<bool, ENCONTONBNA_A>);
-impl ENCONTONBNA_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ENCONTONBNA_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ENCONTONBNA_A {
-        match self.bits {
-            false => ENCONTONBNA_A::VALUE1,
-            true => ENCONTONBNA_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == ENCONTONBNA_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == ENCONTONBNA_A::VALUE2
-    }
-}
-impl core::ops::Deref for ENCONTONBNA_R {
-    type Target = crate::FieldReader<bool, ENCONTONBNA_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `EnContOnBNA` writer - Enable continue on BNA"]
-pub struct ENCONTONBNA_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ENCONTONBNA_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ENCONTONBNA_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "After receiving BNA interrupt, the core disables the endpoint. When the endpoint is re-enabled by the application, the core starts processing from the DOEPDMA descriptor."]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(ENCONTONBNA_A::VALUE1)
-    }
-    #[doc = "After receiving BNA interrupt, the core disables the endpoint. When the endpoint is re-enabled by the application, the core starts processing from the descriptor that received the BNA interrupt."]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(ENCONTONBNA_A::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
-        self.w
-    }
-}
 impl R {
     #[doc = "Bit 0 - Remote Wakeup Signaling"]
     #[inline(always)]
@@ -672,11 +589,6 @@ impl R {
     pub fn nak_on_bble(&self) -> NAKONBBLE_R {
         NAKONBBLE_R::new(((self.bits >> 16) & 0x01) != 0)
     }
-    #[doc = "Bit 17 - Enable continue on BNA"]
-    #[inline(always)]
-    pub fn en_cont_on_bna(&self) -> ENCONTONBNA_R {
-        ENCONTONBNA_R::new(((self.bits >> 17) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bit 0 - Remote Wakeup Signaling"]
@@ -724,11 +636,6 @@ impl W {
     pub fn nak_on_bble(&mut self) -> NAKONBBLE_W {
         NAKONBBLE_W { w: self }
     }
-    #[doc = "Bit 17 - Enable continue on BNA"]
-    #[inline(always)]
-    pub fn en_cont_on_bna(&mut self) -> ENCONTONBNA_W {
-        ENCONTONBNA_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
@@ -749,10 +656,10 @@ impl crate::Readable for DCTL_SPEC {
 impl crate::Writable for DCTL_SPEC {
     type Writer = W;
 }
-#[doc = "`reset()` method sets DCTL to value 0x02"]
+#[doc = "`reset()` method sets DCTL to value 0"]
 impl crate::Resettable for DCTL_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x02
+        0
     }
 }
