@@ -397,71 +397,71 @@ impl<'a> NPTXFEMPLVL_W<'a> {
         self.w
     }
 }
-#[doc = "AHB Single Support\n\nValue on reset: 0"]
+#[doc = "Periodic TxFIFO Empty Level\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
-pub enum AHBSINGLE_A {
-    #[doc = "0: The remaining data in a transfer is sent using INCR burst size. This is the default mode."]
+pub enum PTXFEMPLVL_A {
+    #[doc = "0: GINTSTS.PTxFEmp interrupt indicates that the Periodic TxFIFO is half empty"]
     VALUE1 = 0,
-    #[doc = "1: The remaining data in a transfer is sent using single burst size."]
+    #[doc = "1: GINTSTS.PTxFEmp interrupt indicates that the Periodic TxFIFO is completely empty"]
     VALUE2 = 1,
 }
-impl From<AHBSINGLE_A> for bool {
+impl From<PTXFEMPLVL_A> for bool {
     #[inline(always)]
-    fn from(variant: AHBSINGLE_A) -> Self {
+    fn from(variant: PTXFEMPLVL_A) -> Self {
         variant as u8 != 0
     }
 }
-#[doc = "Field `AHBSingle` reader - AHB Single Support"]
-pub struct AHBSINGLE_R(crate::FieldReader<bool, AHBSINGLE_A>);
-impl AHBSINGLE_R {
+#[doc = "Field `PTxFEmpLvl` reader - Periodic TxFIFO Empty Level"]
+pub struct PTXFEMPLVL_R(crate::FieldReader<bool, PTXFEMPLVL_A>);
+impl PTXFEMPLVL_R {
     pub(crate) fn new(bits: bool) -> Self {
-        AHBSINGLE_R(crate::FieldReader::new(bits))
+        PTXFEMPLVL_R(crate::FieldReader::new(bits))
     }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> AHBSINGLE_A {
+    pub fn variant(&self) -> PTXFEMPLVL_A {
         match self.bits {
-            false => AHBSINGLE_A::VALUE1,
-            true => AHBSINGLE_A::VALUE2,
+            false => PTXFEMPLVL_A::VALUE1,
+            true => PTXFEMPLVL_A::VALUE2,
         }
     }
     #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
     pub fn is_value1(&self) -> bool {
-        **self == AHBSINGLE_A::VALUE1
+        **self == PTXFEMPLVL_A::VALUE1
     }
     #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
     pub fn is_value2(&self) -> bool {
-        **self == AHBSINGLE_A::VALUE2
+        **self == PTXFEMPLVL_A::VALUE2
     }
 }
-impl core::ops::Deref for AHBSINGLE_R {
-    type Target = crate::FieldReader<bool, AHBSINGLE_A>;
+impl core::ops::Deref for PTXFEMPLVL_R {
+    type Target = crate::FieldReader<bool, PTXFEMPLVL_A>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Field `AHBSingle` writer - AHB Single Support"]
-pub struct AHBSINGLE_W<'a> {
+#[doc = "Field `PTxFEmpLvl` writer - Periodic TxFIFO Empty Level"]
+pub struct PTXFEMPLVL_W<'a> {
     w: &'a mut W,
 }
-impl<'a> AHBSINGLE_W<'a> {
+impl<'a> PTXFEMPLVL_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
-    pub fn variant(self, variant: AHBSINGLE_A) -> &'a mut W {
+    pub fn variant(self, variant: PTXFEMPLVL_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "The remaining data in a transfer is sent using INCR burst size. This is the default mode."]
+    #[doc = "GINTSTS.PTxFEmp interrupt indicates that the Periodic TxFIFO is half empty"]
     #[inline(always)]
     pub fn value1(self) -> &'a mut W {
-        self.variant(AHBSINGLE_A::VALUE1)
+        self.variant(PTXFEMPLVL_A::VALUE1)
     }
-    #[doc = "The remaining data in a transfer is sent using single burst size."]
+    #[doc = "GINTSTS.PTxFEmp interrupt indicates that the Periodic TxFIFO is completely empty"]
     #[inline(always)]
     pub fn value2(self) -> &'a mut W {
-        self.variant(AHBSINGLE_A::VALUE2)
+        self.variant(PTXFEMPLVL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -476,7 +476,7 @@ impl<'a> AHBSINGLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
@@ -501,10 +501,10 @@ impl R {
     pub fn nptx_femp_lvl(&self) -> NPTXFEMPLVL_R {
         NPTXFEMPLVL_R::new(((self.bits >> 7) & 0x01) != 0)
     }
-    #[doc = "Bit 23 - AHB Single Support"]
+    #[doc = "Bit 8 - Periodic TxFIFO Empty Level"]
     #[inline(always)]
-    pub fn ahbsingle(&self) -> AHBSINGLE_R {
-        AHBSINGLE_R::new(((self.bits >> 23) & 0x01) != 0)
+    pub fn ptx_femp_lvl(&self) -> PTXFEMPLVL_R {
+        PTXFEMPLVL_R::new(((self.bits >> 8) & 0x01) != 0)
     }
 }
 impl W {
@@ -528,10 +528,10 @@ impl W {
     pub fn nptx_femp_lvl(&mut self) -> NPTXFEMPLVL_W {
         NPTXFEMPLVL_W { w: self }
     }
-    #[doc = "Bit 23 - AHB Single Support"]
+    #[doc = "Bit 8 - Periodic TxFIFO Empty Level"]
     #[inline(always)]
-    pub fn ahbsingle(&mut self) -> AHBSINGLE_W {
-        AHBSINGLE_W { w: self }
+    pub fn ptx_femp_lvl(&mut self) -> PTXFEMPLVL_W {
+        PTXFEMPLVL_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
