@@ -926,89 +926,6 @@ impl<'a> TIWEN_W<'a> {
         self.w
     }
 }
-#[doc = "Slave Mode Clock Phase Select\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum SLPHSEL_A {
-    #[doc = "0: Data bits are shifted out with the leading edge of the shift clock signal and latched in with the trailing edge."]
-    VALUE1 = 0,
-    #[doc = "1: The first data bit is shifted out when the data shift unit receives a low to high transition from the DX2 stage. Subsequent bits are shifted out with the trailing edge of the shift clock signal. Data bits are always latched in with the leading edge."]
-    VALUE2 = 1,
-}
-impl From<SLPHSEL_A> for bool {
-    #[inline(always)]
-    fn from(variant: SLPHSEL_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `SLPHSEL` reader - Slave Mode Clock Phase Select"]
-pub struct SLPHSEL_R(crate::FieldReader<bool, SLPHSEL_A>);
-impl SLPHSEL_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        SLPHSEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> SLPHSEL_A {
-        match self.bits {
-            false => SLPHSEL_A::VALUE1,
-            true => SLPHSEL_A::VALUE2,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == SLPHSEL_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == SLPHSEL_A::VALUE2
-    }
-}
-impl core::ops::Deref for SLPHSEL_R {
-    type Target = crate::FieldReader<bool, SLPHSEL_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `SLPHSEL` writer - Slave Mode Clock Phase Select"]
-pub struct SLPHSEL_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> SLPHSEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SLPHSEL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "Data bits are shifted out with the leading edge of the shift clock signal and latched in with the trailing edge."]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(SLPHSEL_A::VALUE1)
-    }
-    #[doc = "The first data bit is shifted out when the data shift unit receives a low to high transition from the DX2 stage. Subsequent bits are shifted out with the trailing edge of the shift clock signal. Data bits are always latched in with the leading edge."]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(SLPHSEL_A::VALUE2)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
-        self.w
-    }
-}
 #[doc = "Master Clock Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MCLK_A {
@@ -1153,11 +1070,6 @@ impl R {
     pub fn tiwen(&self) -> TIWEN_R {
         TIWEN_R::new(((self.bits >> 24) & 0x01) != 0)
     }
-    #[doc = "Bit 25 - Slave Mode Clock Phase Select"]
-    #[inline(always)]
-    pub fn slphsel(&self) -> SLPHSEL_R {
-        SLPHSEL_R::new(((self.bits >> 25) & 0x01) != 0)
-    }
     #[doc = "Bit 31 - Master Clock Enable"]
     #[inline(always)]
     pub fn mclk(&self) -> MCLK_R {
@@ -1225,11 +1137,6 @@ impl W {
     pub fn tiwen(&mut self) -> TIWEN_W {
         TIWEN_W { w: self }
     }
-    #[doc = "Bit 25 - Slave Mode Clock Phase Select"]
-    #[inline(always)]
-    pub fn slphsel(&mut self) -> SLPHSEL_W {
-        SLPHSEL_W { w: self }
-    }
     #[doc = "Bit 31 - Master Clock Enable"]
     #[inline(always)]
     pub fn mclk(&mut self) -> MCLK_W {
