@@ -271,49 +271,15 @@ impl core::ops::Deref for DS0_R {
         &self.0
     }
 }
-#[doc = "Received Data Word Length in RBUF1\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum WLEN1_A {
-    #[doc = "0: One bit has been received."]
-    VALUE1 = 0,
-    #[doc = "15: Sixteen bits have been received."]
-    VALUE2 = 15,
-}
-impl From<WLEN1_A> for u8 {
-    #[inline(always)]
-    fn from(variant: WLEN1_A) -> Self {
-        variant as _
-    }
-}
 #[doc = "Field `WLEN1` reader - Received Data Word Length in RBUF1"]
-pub struct WLEN1_R(crate::FieldReader<u8, WLEN1_A>);
+pub struct WLEN1_R(crate::FieldReader<u8, u8>);
 impl WLEN1_R {
     pub(crate) fn new(bits: u8) -> Self {
         WLEN1_R(crate::FieldReader::new(bits))
     }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> Option<WLEN1_A> {
-        match self.bits {
-            0 => Some(WLEN1_A::VALUE1),
-            15 => Some(WLEN1_A::VALUE2),
-            _ => None,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == WLEN1_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == WLEN1_A::VALUE2
-    }
 }
 impl core::ops::Deref for WLEN1_R {
-    type Target = crate::FieldReader<u8, WLEN1_A>;
+    type Target = crate::FieldReader<u8, u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
