@@ -1158,7 +1158,7 @@ impl core::ops::Deref for TVC_R {
 pub enum TE_A {
     #[doc = "0: The trigger event has not yet been detected. A transmission of the data word in TBUF can not be started."]
     VALUE1 = 0,
-    #[doc = "1: The trigger event has been detected (or the trigger mechanism is switched off) and a transmission of the data word in TBUF can not be started."]
+    #[doc = "1: The trigger event has been detected (or the trigger mechanism is switched off) and a transmission of the data word in TBUF can be started."]
     VALUE2 = 1,
 }
 impl From<TE_A> for bool {
