@@ -34,94 +34,6 @@ impl From<crate::W<ASCTRL_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Source-specific Result Register\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum SRCRESREG_A {
-    #[doc = "0: Use GxCHCTRy.RESREG to select a group result register"]
-    VALUE1 = 0,
-    #[doc = "1: Store result in group result register GxRES1"]
-    VALUE2 = 1,
-    #[doc = "15: Store result in group result register GxRES15"]
-    VALUE3 = 15,
-}
-impl From<SRCRESREG_A> for u8 {
-    #[inline(always)]
-    fn from(variant: SRCRESREG_A) -> Self {
-        variant as _
-    }
-}
-#[doc = "Field `SRCRESREG` reader - Source-specific Result Register"]
-pub struct SRCRESREG_R(crate::FieldReader<u8, SRCRESREG_A>);
-impl SRCRESREG_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        SRCRESREG_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> Option<SRCRESREG_A> {
-        match self.bits {
-            0 => Some(SRCRESREG_A::VALUE1),
-            1 => Some(SRCRESREG_A::VALUE2),
-            15 => Some(SRCRESREG_A::VALUE3),
-            _ => None,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == SRCRESREG_A::VALUE1
-    }
-    #[doc = "Checks if the value of the field is `VALUE2`"]
-    #[inline(always)]
-    pub fn is_value2(&self) -> bool {
-        **self == SRCRESREG_A::VALUE2
-    }
-    #[doc = "Checks if the value of the field is `VALUE3`"]
-    #[inline(always)]
-    pub fn is_value3(&self) -> bool {
-        **self == SRCRESREG_A::VALUE3
-    }
-}
-impl core::ops::Deref for SRCRESREG_R {
-    type Target = crate::FieldReader<u8, SRCRESREG_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `SRCRESREG` writer - Source-specific Result Register"]
-pub struct SRCRESREG_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> SRCRESREG_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SRCRESREG_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
-    #[doc = "Use GxCHCTRy.RESREG to select a group result register"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(SRCRESREG_A::VALUE1)
-    }
-    #[doc = "Store result in group result register GxRES1"]
-    #[inline(always)]
-    pub fn value2(self) -> &'a mut W {
-        self.variant(SRCRESREG_A::VALUE2)
-    }
-    #[doc = "Store result in group result register GxRES15"]
-    #[inline(always)]
-    pub fn value3(self) -> &'a mut W {
-        self.variant(SRCRESREG_A::VALUE3)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x0f) | (value as u32 & 0x0f);
-        self.w
-    }
-}
 #[doc = "Field `XTSEL` reader - External Trigger Input Selection"]
 pub struct XTSEL_R(crate::FieldReader<u8, u8>);
 impl XTSEL_R {
@@ -540,11 +452,6 @@ impl<'a> TMWC_W<'a> {
     }
 }
 impl R {
-    #[doc = "Bits 0:3 - Source-specific Result Register"]
-    #[inline(always)]
-    pub fn srcresreg(&self) -> SRCRESREG_R {
-        SRCRESREG_R::new((self.bits & 0x0f) as u8)
-    }
     #[doc = "Bits 8:11 - External Trigger Input Selection"]
     #[inline(always)]
     pub fn xtsel(&self) -> XTSEL_R {
@@ -577,11 +484,6 @@ impl R {
     }
 }
 impl W {
-    #[doc = "Bits 0:3 - Source-specific Result Register"]
-    #[inline(always)]
-    pub fn srcresreg(&mut self) -> SRCRESREG_W {
-        SRCRESREG_W { w: self }
-    }
     #[doc = "Bits 8:11 - External Trigger Input Selection"]
     #[inline(always)]
     pub fn xtsel(&mut self) -> XTSEL_W {
